# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from envoy.config.core.v4alpha import http_uri_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto',
  package='envoy.extensions.filters.http.ext_authz.v4alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.http.ext_authz.v4alphaB\rExtAuthzProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?envoy/extensions/filters/http/ext_authz/v4alpha/ext_authz.proto\x12/envoy.extensions.filters.http.ext_authz.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a(envoy/config/core/v4alpha/http_uri.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcf\x06\n\x08\x45xtAuthz\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcServiceH\x00\x12T\n\x0chttp_service\x18\x03 \x01(\x0b\x32<.envoy.extensions.filters.http.ext_authz.v4alpha.HttpServiceH\x00\x12N\n\x15transport_api_version\x18\x0c \x01(\x0e\x32%.envoy.config.core.v4alpha.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12Z\n\x11with_request_body\x18\x05 \x01(\x0b\x32?.envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12\x32\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12K\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32\x33.envoy.config.core.v4alpha.RuntimeFractionalPercent\x12L\n\x17\x66ilter_enabled_metadata\x18\x0e \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcher\x12\x46\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32-.envoy.config.core.v4alpha.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x12\x13\n\x0bstat_prefix\x18\r \x01(\t::\x9a\xc5\x88\x1e\x35\n3envoy.extensions.filters.http.ext_authz.v3.ExtAuthzB\n\n\x08servicesJ\x04\x08\x04\x10\x05R\tuse_alpha\"\xac\x01\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\x12\x15\n\rpack_as_bytes\x18\x03 \x01(\x08:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.ext_authz.v3.BufferSettings\"\xff\x02\n\x0bHttpService\x12\x36\n\nserver_uri\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12\x64\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32\x45.envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest\x12\x66\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32\x46.envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.http.ext_authz.v3.HttpServiceJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\xe6\x01\n\x14\x41uthorizationRequest\x12\x46\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12>\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32&.envoy.config.core.v4alpha.HeaderValue:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.http.ext_authz.v3.AuthorizationRequest\"\xdb\x02\n\x15\x41uthorizationResponse\x12O\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12Y\n\"allowed_upstream_headers_to_append\x18\x03 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher\x12M\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32-.envoy.type.matcher.v4alpha.ListStringMatcher:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.ext_authz.v3.AuthorizationResponse\"\xe8\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x62\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.http.ext_authz.v3.ExtAuthzPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xa5\x02\n\rCheckSettings\x12q\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32U.envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry\x12&\n\x1e\x64isable_request_body_buffering\x18\x02 \x01(\x08\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:?\x9a\xc5\x88\x1e:\n8envoy.extensions.filters.http.ext_authz.v3.CheckSettingsBX\n=io.envoyproxy.envoy.extensions.filters.http.ext_authz.v4alphaB\rExtAuthzProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_service', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.http_service', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_api_version', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.transport_api_version', index=2,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.failure_mode_allow', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_request_body', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.with_request_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.clear_route_cache', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_on_error', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.status_on_error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_context_namespaces', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.metadata_context_namespaces', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.filter_enabled', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled_metadata', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.filter_enabled_metadata', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_at_disable', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.deny_at_disable', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.include_peer_certificate', index=11,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.stat_prefix', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.extensions.filters.http.ext_authz.v3.ExtAuthz',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='services', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz.services',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=498,
  serialized_end=1345,
)


_BUFFERSETTINGS = _descriptor.Descriptor(
  name='BufferSettings',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.max_request_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_message', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.allow_partial_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_as_bytes', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings.pack_as_bytes', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.ext_authz.v3.BufferSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1348,
  serialized_end=1520,
)


_HTTPSERVICE = _descriptor.Descriptor(
  name='HttpService',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_uri', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.server_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefix', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.path_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_request', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.authorization_request', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_response', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.HttpService.authorization_response', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.http.ext_authz.v3.HttpService',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1906,
)


_AUTHORIZATIONREQUEST = _descriptor.Descriptor(
  name='AuthorizationRequest',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest.allowed_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest.headers_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.http.ext_authz.v3.AuthorizationRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=2139,
)


_AUTHORIZATIONRESPONSE = _descriptor.Descriptor(
  name='AuthorizationResponse',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_upstream_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers_to_append', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_upstream_headers_to_append', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_client_headers', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse.allowed_client_headers', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.ext_authz.v3.AuthorizationResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2142,
  serialized_end=2489,
)


_EXTAUTHZPERROUTE = _descriptor.Descriptor(
  name='ExtAuthzPerRoute',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_settings', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.check_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.http.ext_authz.v3.ExtAuthzPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2492,
  serialized_end=2724,
)


_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY = _descriptor.Descriptor(
  name='ContextExtensionsEntry',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2899,
  serialized_end=2955,
)

_CHECKSETTINGS = _descriptor.Descriptor(
  name='CheckSettings',
  full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_extensions', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.context_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_request_body_buffering', full_name='envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.disable_request_body_buffering', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.extensions.filters.http.ext_authz.v3.CheckSettings',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=3020,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_EXTAUTHZ.fields_by_name['http_service'].message_type = _HTTPSERVICE
_EXTAUTHZ.fields_by_name['transport_api_version'].enum_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._APIVERSION
_EXTAUTHZ.fields_by_name['with_request_body'].message_type = _BUFFERSETTINGS
_EXTAUTHZ.fields_by_name['status_on_error'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_EXTAUTHZ.fields_by_name['filter_enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_EXTAUTHZ.fields_by_name['filter_enabled_metadata'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_EXTAUTHZ.fields_by_name['deny_at_disable'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFEATUREFLAG
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['grpc_service'])
_EXTAUTHZ.fields_by_name['grpc_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['http_service'])
_EXTAUTHZ.fields_by_name['http_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_HTTPSERVICE.fields_by_name['server_uri'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2._HTTPURI
_HTTPSERVICE.fields_by_name['authorization_request'].message_type = _AUTHORIZATIONREQUEST
_HTTPSERVICE.fields_by_name['authorization_response'].message_type = _AUTHORIZATIONRESPONSE
_AUTHORIZATIONREQUEST.fields_by_name['allowed_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONREQUEST.fields_by_name['headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUE
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers_to_append'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_client_headers'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._LISTSTRINGMATCHER
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].message_type = _CHECKSETTINGS
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['disabled'])
_EXTAUTHZPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['check_settings'])
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY.containing_type = _CHECKSETTINGS
_CHECKSETTINGS.fields_by_name['context_extensions'].message_type = _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
DESCRIPTOR.message_types_by_name['BufferSettings'] = _BUFFERSETTINGS
DESCRIPTOR.message_types_by_name['HttpService'] = _HTTPSERVICE
DESCRIPTOR.message_types_by_name['AuthorizationRequest'] = _AUTHORIZATIONREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationResponse'] = _AUTHORIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtAuthzPerRoute'] = _EXTAUTHZPERROUTE
DESCRIPTOR.message_types_by_name['CheckSettings'] = _CHECKSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)

BufferSettings = _reflection.GeneratedProtocolMessageType('BufferSettings', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERSETTINGS,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.BufferSettings)
  })
_sym_db.RegisterMessage(BufferSettings)

HttpService = _reflection.GeneratedProtocolMessageType('HttpService', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSERVICE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.HttpService)
  })
_sym_db.RegisterMessage(HttpService)

AuthorizationRequest = _reflection.GeneratedProtocolMessageType('AuthorizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONREQUEST,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationRequest)
  })
_sym_db.RegisterMessage(AuthorizationRequest)

AuthorizationResponse = _reflection.GeneratedProtocolMessageType('AuthorizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONRESPONSE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.AuthorizationResponse)
  })
_sym_db.RegisterMessage(AuthorizationResponse)

ExtAuthzPerRoute = _reflection.GeneratedProtocolMessageType('ExtAuthzPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.ExtAuthzPerRoute)
  })
_sym_db.RegisterMessage(ExtAuthzPerRoute)

CheckSettings = _reflection.GeneratedProtocolMessageType('CheckSettings', (_message.Message,), {

  'ContextExtensionsEntry' : _reflection.GeneratedProtocolMessageType('ContextExtensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY,
    '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings.ContextExtensionsEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKSETTINGS,
  '__module__' : 'envoy.extensions.filters.http.ext_authz.v4alpha.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_authz.v4alpha.CheckSettings)
  })
_sym_db.RegisterMessage(CheckSettings)
_sym_db.RegisterMessage(CheckSettings.ContextExtensionsEntry)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['transport_api_version']._options = None
_EXTAUTHZ._options = None
_BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
_BUFFERSETTINGS._options = None
_HTTPSERVICE._options = None
_AUTHORIZATIONREQUEST._options = None
_AUTHORIZATIONRESPONSE._options = None
_EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
_EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
_EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
_EXTAUTHZPERROUTE._options = None
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
_CHECKSETTINGS._options = None
# @@protoc_insertion_point(module_scope)
