# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/route/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2

from envoy.api.v2.route.route_components_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/route/route.proto',
  package='envoy.api.v2.route',
  syntax='proto3',
  serialized_options=b'\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/route/route.proto\x12\x12\x65nvoy.api.v2.route\x1a)envoy/api/v2/route/route_components.protoB0\n io.envoyproxy.envoy.api.v2.routeB\nRouteProtoP\x01P\x00\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
