# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/core/address.proto',
  package='envoy.api.v2.core',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.coreB\014AddressProtoP\001\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/api/v2/core/address.proto\x12\x11\x65nvoy.api.v2.core\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"5\n\x04Pipe\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x04mode\x18\x02 \x01(\rB\x08\xfa\x42\x05*\x03\x18\xff\x03\"\x88\x02\n\rSocketAddress\x12\x45\n\x08protocol\x18\x01 \x01(\x0e\x32).envoy.api.v2.core.SocketAddress.ProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1f\n\nport_value\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12\x14\n\nnamed_port\x18\x04 \x01(\tH\x00\x12\x15\n\rresolver_name\x18\x05 \x01(\t\x12\x13\n\x0bipv4_compat\x18\x06 \x01(\x08\"\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x42\x15\n\x0eport_specifier\x12\x03\xf8\x42\x01\"\xb6\x01\n\x0cTcpKeepalive\x12\x36\n\x10keepalive_probes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0ekeepalive_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12keepalive_interval\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xb7\x01\n\nBindConfig\x12\x42\n\x0esource_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12,\n\x08\x66reebind\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\x03 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"~\n\x07\x41\x64\x64ress\x12:\n\x0esocket_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressH\x00\x12\'\n\x04pipe\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.PipeH\x00\x42\x0e\n\x07\x61\x64\x64ress\x12\x03\xf8\x42\x01\"h\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01\x42U\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0c\x41\x64\x64ressProtoP\x01\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_SOCKETADDRESS_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='envoy.api.v2.core.SocketAddress.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TCP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UDP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=510,
)
_sym_db.RegisterEnumDescriptor(_SOCKETADDRESS_PROTOCOL)


_PIPE = _descriptor.Descriptor(
  name='Pipe',
  full_name='envoy.api.v2.core.Pipe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.api.v2.core.Pipe.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='envoy.api.v2.core.Pipe.mode', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=266,
)


_SOCKETADDRESS = _descriptor.Descriptor(
  name='SocketAddress',
  full_name='envoy.api.v2.core.SocketAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.api.v2.core.SocketAddress.protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.core.SocketAddress.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.api.v2.core.SocketAddress.port_value', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_port', full_name='envoy.api.v2.core.SocketAddress.named_port', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolver_name', full_name='envoy.api.v2.core.SocketAddress.resolver_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipv4_compat', full_name='envoy.api.v2.core.SocketAddress.ipv4_compat', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOCKETADDRESS_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='port_specifier', full_name='envoy.api.v2.core.SocketAddress.port_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=269,
  serialized_end=533,
)


_TCPKEEPALIVE = _descriptor.Descriptor(
  name='TcpKeepalive',
  full_name='envoy.api.v2.core.TcpKeepalive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keepalive_probes', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_probes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalive_time', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keepalive_interval', full_name='envoy.api.v2.core.TcpKeepalive.keepalive_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=718,
)


_BINDCONFIG = _descriptor.Descriptor(
  name='BindConfig',
  full_name='envoy.api.v2.core.BindConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_address', full_name='envoy.api.v2.core.BindConfig.source_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freebind', full_name='envoy.api.v2.core.BindConfig.freebind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.api.v2.core.BindConfig.socket_options', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=904,
)


_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='envoy.api.v2.core.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket_address', full_name='envoy.api.v2.core.Address.socket_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipe', full_name='envoy.api.v2.core.Address.pipe', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='envoy.api.v2.core.Address.address',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=906,
  serialized_end=1032,
)


_CIDRRANGE = _descriptor.Descriptor(
  name='CidrRange',
  full_name='envoy.api.v2.core.CidrRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_prefix', full_name='envoy.api.v2.core.CidrRange.address_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_len', full_name='envoy.api.v2.core.CidrRange.prefix_len', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1138,
)

_SOCKETADDRESS.fields_by_name['protocol'].enum_type = _SOCKETADDRESS_PROTOCOL
_SOCKETADDRESS_PROTOCOL.containing_type = _SOCKETADDRESS
_SOCKETADDRESS.oneofs_by_name['port_specifier'].fields.append(
  _SOCKETADDRESS.fields_by_name['port_value'])
_SOCKETADDRESS.fields_by_name['port_value'].containing_oneof = _SOCKETADDRESS.oneofs_by_name['port_specifier']
_SOCKETADDRESS.oneofs_by_name['port_specifier'].fields.append(
  _SOCKETADDRESS.fields_by_name['named_port'])
_SOCKETADDRESS.fields_by_name['named_port'].containing_oneof = _SOCKETADDRESS.oneofs_by_name['port_specifier']
_TCPKEEPALIVE.fields_by_name['keepalive_probes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TCPKEEPALIVE.fields_by_name['keepalive_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_TCPKEEPALIVE.fields_by_name['keepalive_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BINDCONFIG.fields_by_name['source_address'].message_type = _SOCKETADDRESS
_BINDCONFIG.fields_by_name['freebind'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_BINDCONFIG.fields_by_name['socket_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2._SOCKETOPTION
_ADDRESS.fields_by_name['socket_address'].message_type = _SOCKETADDRESS
_ADDRESS.fields_by_name['pipe'].message_type = _PIPE
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['socket_address'])
_ADDRESS.fields_by_name['socket_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['pipe'])
_ADDRESS.fields_by_name['pipe'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_CIDRRANGE.fields_by_name['prefix_len'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Pipe'] = _PIPE
DESCRIPTOR.message_types_by_name['SocketAddress'] = _SOCKETADDRESS
DESCRIPTOR.message_types_by_name['TcpKeepalive'] = _TCPKEEPALIVE
DESCRIPTOR.message_types_by_name['BindConfig'] = _BINDCONFIG
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['CidrRange'] = _CIDRRANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pipe = _reflection.GeneratedProtocolMessageType('Pipe', (_message.Message,), {
  'DESCRIPTOR' : _PIPE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.Pipe)
  })
_sym_db.RegisterMessage(Pipe)

SocketAddress = _reflection.GeneratedProtocolMessageType('SocketAddress', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETADDRESS,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.SocketAddress)
  })
_sym_db.RegisterMessage(SocketAddress)

TcpKeepalive = _reflection.GeneratedProtocolMessageType('TcpKeepalive', (_message.Message,), {
  'DESCRIPTOR' : _TCPKEEPALIVE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.TcpKeepalive)
  })
_sym_db.RegisterMessage(TcpKeepalive)

BindConfig = _reflection.GeneratedProtocolMessageType('BindConfig', (_message.Message,), {
  'DESCRIPTOR' : _BINDCONFIG,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.BindConfig)
  })
_sym_db.RegisterMessage(BindConfig)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.Address)
  })
_sym_db.RegisterMessage(Address)

CidrRange = _reflection.GeneratedProtocolMessageType('CidrRange', (_message.Message,), {
  'DESCRIPTOR' : _CIDRRANGE,
  '__module__' : 'envoy.api.v2.core.address_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.CidrRange)
  })
_sym_db.RegisterMessage(CidrRange)


DESCRIPTOR._options = None
_PIPE.fields_by_name['path']._options = None
_PIPE.fields_by_name['mode']._options = None
_SOCKETADDRESS.oneofs_by_name['port_specifier']._options = None
_SOCKETADDRESS.fields_by_name['protocol']._options = None
_SOCKETADDRESS.fields_by_name['address']._options = None
_SOCKETADDRESS.fields_by_name['port_value']._options = None
_BINDCONFIG.fields_by_name['source_address']._options = None
_ADDRESS.oneofs_by_name['address']._options = None
_CIDRRANGE.fields_by_name['address_prefix']._options = None
_CIDRRANGE.fields_by_name['prefix_len']._options = None
# @@protoc_insertion_point(module_scope)
