# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto',
  package='envoy.extensions.filters.http.aws_request_signing.v3',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\026AwsRequestSigningProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nNenvoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto\x12\x34\x65nvoy.extensions.filters.http.aws_request_signing.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x01\n\x11\x41wsRequestSigning\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0chost_rewrite\x18\x03 \x01(\t:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigningBf\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\x16\x41wsRequestSigningProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_AWSREQUESTSIGNING = _descriptor.Descriptor(
  name='AwsRequestSigning',
  full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_rewrite', full_name='envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.host_rewrite', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=404,
)

DESCRIPTOR.message_types_by_name['AwsRequestSigning'] = _AWSREQUESTSIGNING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsRequestSigning = _reflection.GeneratedProtocolMessageType('AwsRequestSigning', (_message.Message,), {
  'DESCRIPTOR' : _AWSREQUESTSIGNING,
  '__module__' : 'envoy.extensions.filters.http.aws_request_signing.v3.aws_request_signing_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning)
  })
_sym_db.RegisterMessage(AwsRequestSigning)


DESCRIPTOR._options = None
_AWSREQUESTSIGNING.fields_by_name['service_name']._options = None
_AWSREQUESTSIGNING.fields_by_name['region']._options = None
_AWSREQUESTSIGNING._options = None
# @@protoc_insertion_point(module_scope)
