# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.extensions.filters.http.ext_proc.v3alpha import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto',
  package='envoy.extensions.filters.http.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\014ExtProcProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto\x12.envoy.extensions.filters.http.ext_proc.v3alpha\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x44\x65nvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd7\x02\n\x11\x45xternalProcessor\x12\x37\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12W\n\x0fprocessing_mode\x18\x03 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode\x12\x12\n\nasync_mode\x18\x04 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x05 \x03(\t\x12\x1b\n\x13response_attributes\x18\x06 \x03(\t\x12\x32\n\x0fmessage_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bstat_prefix\x18\x08 \x01(\t\"\x96\x01\n\x0f\x45xtProcPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12U\n\toverrides\x18\x02 \x01(\x0b\x32@.envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverridesH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xb8\x01\n\x10\x45xtProcOverrides\x12W\n\x0fprocessing_mode\x18\x01 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode\x12\x12\n\nasync_mode\x18\x02 \x01(\x08\x12\x1a\n\x12request_properties\x18\x03 \x03(\t\x12\x1b\n\x13response_properties\x18\x04 \x03(\tB^\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\x0c\x45xtProcProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTERNALPROCESSOR = _descriptor.Descriptor(
  name='ExternalProcessor',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.failure_mode_allow', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.processing_mode', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.async_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_attributes', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.request_attributes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_attributes', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.response_attributes', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_timeout', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.message_timeout', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.stat_prefix', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=656,
)


_EXTPROCPERROUTE = _descriptor.Descriptor(
  name='ExtProcPerRoute',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overrides', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.overrides', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=659,
  serialized_end=809,
)


_EXTPROCOVERRIDES = _descriptor.Descriptor(
  name='ExtProcOverrides',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.processing_mode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.async_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_properties', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.request_properties', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_properties', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.response_properties', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=996,
)

_EXTERNALPROCESSOR.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
_EXTERNALPROCESSOR.fields_by_name['processing_mode'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
_EXTERNALPROCESSOR.fields_by_name['message_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXTPROCPERROUTE.fields_by_name['overrides'].message_type = _EXTPROCOVERRIDES
_EXTPROCPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTPROCPERROUTE.fields_by_name['disabled'])
_EXTPROCPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTPROCPERROUTE.oneofs_by_name['override']
_EXTPROCPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTPROCPERROUTE.fields_by_name['overrides'])
_EXTPROCPERROUTE.fields_by_name['overrides'].containing_oneof = _EXTPROCPERROUTE.oneofs_by_name['override']
_EXTPROCOVERRIDES.fields_by_name['processing_mode'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
DESCRIPTOR.message_types_by_name['ExternalProcessor'] = _EXTERNALPROCESSOR
DESCRIPTOR.message_types_by_name['ExtProcPerRoute'] = _EXTPROCPERROUTE
DESCRIPTOR.message_types_by_name['ExtProcOverrides'] = _EXTPROCOVERRIDES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExternalProcessor = _reflection.GeneratedProtocolMessageType('ExternalProcessor', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALPROCESSOR,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor)
  })
_sym_db.RegisterMessage(ExternalProcessor)

ExtProcPerRoute = _reflection.GeneratedProtocolMessageType('ExtProcPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTPROCPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute)
  })
_sym_db.RegisterMessage(ExtProcPerRoute)

ExtProcOverrides = _reflection.GeneratedProtocolMessageType('ExtProcOverrides', (_message.Message,), {
  'DESCRIPTOR' : _EXTPROCOVERRIDES,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides)
  })
_sym_db.RegisterMessage(ExtProcOverrides)


DESCRIPTOR._options = None
_EXTPROCPERROUTE.oneofs_by_name['override']._options = None
_EXTPROCPERROUTE.fields_by_name['disabled']._options = None
# @@protoc_insertion_point(module_scope)
