# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/previous_priorities/previous_priorities_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/retry/previous_priorities/previous_priorities_config.proto',
  package='envoy.config.retry.previous_priorities',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\035PreviousPrioritiesConfigProtoP\001\362\230\376\217\0058\0226envoy.extensions.retry.priority.previous_priorities.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/config/retry/previous_priorities/previous_priorities_config.proto\x12&envoy.config.retry.previous_priorities\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"=\n\x18PreviousPrioritiesConfig\x12!\n\x10update_frequency\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02 \x00\x42\x9d\x01\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\x1dPreviousPrioritiesConfigProtoP\x01\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.retry.priority.previous_priorities.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PREVIOUSPRIORITIESCONFIG = _descriptor.Descriptor(
  name='PreviousPrioritiesConfig',
  full_name='envoy.config.retry.previous_priorities.PreviousPrioritiesConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_frequency', full_name='envoy.config.retry.previous_priorities.PreviousPrioritiesConfig.update_frequency', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004\032\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=264,
)

DESCRIPTOR.message_types_by_name['PreviousPrioritiesConfig'] = _PREVIOUSPRIORITIESCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PreviousPrioritiesConfig = _reflection.GeneratedProtocolMessageType('PreviousPrioritiesConfig', (_message.Message,), {
  'DESCRIPTOR' : _PREVIOUSPRIORITIESCONFIG,
  '__module__' : 'envoy.config.retry.previous_priorities.previous_priorities_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.retry.previous_priorities.PreviousPrioritiesConfig)
  })
_sym_db.RegisterMessage(PreviousPrioritiesConfig)


DESCRIPTOR._options = None
_PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._options = None
# @@protoc_insertion_point(module_scope)
