# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto',
  package='envoy.extensions.filters.http.cdn_loop.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.cdn_loop.v3alphaB\014CdnLoopProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto\x12.envoy.extensions.filters.http.cdn_loop.v3alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"I\n\rCdnLoopConfig\x12\x17\n\x06\x63\x64n_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1f\n\x17max_allowed_occurrences\x18\x02 \x01(\rB^\n<io.envoyproxy.envoy.extensions.filters.http.cdn_loop.v3alphaB\x0c\x43\x64nLoopProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CDNLOOPCONFIG = _descriptor.Descriptor(
  name='CdnLoopConfig',
  full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cdn_id', full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig.cdn_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_allowed_occurrences', full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig.max_allowed_occurrences', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=242,
)

DESCRIPTOR.message_types_by_name['CdnLoopConfig'] = _CDNLOOPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CdnLoopConfig = _reflection.GeneratedProtocolMessageType('CdnLoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _CDNLOOPCONFIG,
  '__module__' : 'envoy.extensions.filters.http.cdn_loop.v3alpha.cdn_loop_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig)
  })
_sym_db.RegisterMessage(CdnLoopConfig)


DESCRIPTOR._options = None
_CDNLOOPCONFIG.fields_by_name['cdn_id']._options = None
# @@protoc_insertion_point(module_scope)
