# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/wasm/v3/wasm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/wasm/v3/wasm.proto',
  package='envoy.extensions.wasm.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/extensions/wasm/v3/wasm.proto\x12\x18\x65nvoy.extensions.wasm.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\x1b\x43\x61pabilityRestrictionConfig\x12l\n\x14\x61llowed_capabilities\x18\x01 \x03(\x0b\x32N.envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry\x1ah\n\x18\x41llowedCapabilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.envoy.extensions.wasm.v3.SanitizationConfig:\x02\x38\x01\"\x14\n\x12SanitizationConfig\"\xd1\x01\n\x08VmConfig\x12\r\n\x05vm_id\x18\x01 \x01(\t\x12\x18\n\x07runtime\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x04\x63ode\x18\x03 \x01(\x0b\x32%.envoy.config.core.v3.AsyncDataSource\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x19\n\x11\x61llow_precompiled\x18\x05 \x01(\x08\x12\x1f\n\x17nack_on_code_cache_miss\x18\x06 \x01(\x08\"\x8a\x02\n\x0cPluginConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07root_id\x18\x02 \x01(\t\x12\x37\n\tvm_config\x18\x03 \x01(\x0b\x32\".envoy.extensions.wasm.v3.VmConfigH\x00\x12+\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tfail_open\x18\x05 \x01(\x08\x12\\\n\x1d\x63\x61pability_restriction_config\x18\x06 \x01(\x0b\x32\x35.envoy.extensions.wasm.v3.CapabilityRestrictionConfigB\x04\n\x02vm\"X\n\x0bWasmService\x12\x36\n\x06\x63onfig\x18\x01 \x01(\x0b\x32&.envoy.extensions.wasm.v3.PluginConfig\x12\x11\n\tsingleton\x18\x02 \x01(\x08\x42=\n&io.envoyproxy.envoy.extensions.wasm.v3B\tWasmProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY = _descriptor.Descriptor(
  name='AllowedCapabilitiesEntry',
  full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=427,
)

_CAPABILITYRESTRICTIONCONFIG = _descriptor.Descriptor(
  name='CapabilityRestrictionConfig',
  full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_capabilities', full_name='envoy.extensions.wasm.v3.CapabilityRestrictionConfig.allowed_capabilities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=427,
)


_SANITIZATIONCONFIG = _descriptor.Descriptor(
  name='SanitizationConfig',
  full_name='envoy.extensions.wasm.v3.SanitizationConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=449,
)


_VMCONFIG = _descriptor.Descriptor(
  name='VmConfig',
  full_name='envoy.extensions.wasm.v3.VmConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vm_id', full_name='envoy.extensions.wasm.v3.VmConfig.vm_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='envoy.extensions.wasm.v3.VmConfig.runtime', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='envoy.extensions.wasm.v3.VmConfig.code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='envoy.extensions.wasm.v3.VmConfig.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_precompiled', full_name='envoy.extensions.wasm.v3.VmConfig.allow_precompiled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nack_on_code_cache_miss', full_name='envoy.extensions.wasm.v3.VmConfig.nack_on_code_cache_miss', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=661,
)


_PLUGINCONFIG = _descriptor.Descriptor(
  name='PluginConfig',
  full_name='envoy.extensions.wasm.v3.PluginConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.wasm.v3.PluginConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_id', full_name='envoy.extensions.wasm.v3.PluginConfig.root_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vm_config', full_name='envoy.extensions.wasm.v3.PluginConfig.vm_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configuration', full_name='envoy.extensions.wasm.v3.PluginConfig.configuration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_open', full_name='envoy.extensions.wasm.v3.PluginConfig.fail_open', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capability_restriction_config', full_name='envoy.extensions.wasm.v3.PluginConfig.capability_restriction_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='vm', full_name='envoy.extensions.wasm.v3.PluginConfig.vm',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=664,
  serialized_end=930,
)


_WASMSERVICE = _descriptor.Descriptor(
  name='WasmService',
  full_name='envoy.extensions.wasm.v3.WasmService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.wasm.v3.WasmService.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='singleton', full_name='envoy.extensions.wasm.v3.WasmService.singleton', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1020,
)

_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY.fields_by_name['value'].message_type = _SANITIZATIONCONFIG
_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY.containing_type = _CAPABILITYRESTRICTIONCONFIG
_CAPABILITYRESTRICTIONCONFIG.fields_by_name['allowed_capabilities'].message_type = _CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY
_VMCONFIG.fields_by_name['code'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._ASYNCDATASOURCE
_VMCONFIG.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PLUGINCONFIG.fields_by_name['vm_config'].message_type = _VMCONFIG
_PLUGINCONFIG.fields_by_name['configuration'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PLUGINCONFIG.fields_by_name['capability_restriction_config'].message_type = _CAPABILITYRESTRICTIONCONFIG
_PLUGINCONFIG.oneofs_by_name['vm'].fields.append(
  _PLUGINCONFIG.fields_by_name['vm_config'])
_PLUGINCONFIG.fields_by_name['vm_config'].containing_oneof = _PLUGINCONFIG.oneofs_by_name['vm']
_WASMSERVICE.fields_by_name['config'].message_type = _PLUGINCONFIG
DESCRIPTOR.message_types_by_name['CapabilityRestrictionConfig'] = _CAPABILITYRESTRICTIONCONFIG
DESCRIPTOR.message_types_by_name['SanitizationConfig'] = _SANITIZATIONCONFIG
DESCRIPTOR.message_types_by_name['VmConfig'] = _VMCONFIG
DESCRIPTOR.message_types_by_name['PluginConfig'] = _PLUGINCONFIG
DESCRIPTOR.message_types_by_name['WasmService'] = _WASMSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CapabilityRestrictionConfig = _reflection.GeneratedProtocolMessageType('CapabilityRestrictionConfig', (_message.Message,), {

  'AllowedCapabilitiesEntry' : _reflection.GeneratedProtocolMessageType('AllowedCapabilitiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY,
    '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.CapabilityRestrictionConfig.AllowedCapabilitiesEntry)
    })
  ,
  'DESCRIPTOR' : _CAPABILITYRESTRICTIONCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.CapabilityRestrictionConfig)
  })
_sym_db.RegisterMessage(CapabilityRestrictionConfig)
_sym_db.RegisterMessage(CapabilityRestrictionConfig.AllowedCapabilitiesEntry)

SanitizationConfig = _reflection.GeneratedProtocolMessageType('SanitizationConfig', (_message.Message,), {
  'DESCRIPTOR' : _SANITIZATIONCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.SanitizationConfig)
  })
_sym_db.RegisterMessage(SanitizationConfig)

VmConfig = _reflection.GeneratedProtocolMessageType('VmConfig', (_message.Message,), {
  'DESCRIPTOR' : _VMCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.VmConfig)
  })
_sym_db.RegisterMessage(VmConfig)

PluginConfig = _reflection.GeneratedProtocolMessageType('PluginConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINCONFIG,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.PluginConfig)
  })
_sym_db.RegisterMessage(PluginConfig)

WasmService = _reflection.GeneratedProtocolMessageType('WasmService', (_message.Message,), {
  'DESCRIPTOR' : _WASMSERVICE,
  '__module__' : 'envoy.extensions.wasm.v3.wasm_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.wasm.v3.WasmService)
  })
_sym_db.RegisterMessage(WasmService)


DESCRIPTOR._options = None
_CAPABILITYRESTRICTIONCONFIG_ALLOWEDCAPABILITIESENTRY._options = None
_VMCONFIG.fields_by_name['runtime']._options = None
# @@protoc_insertion_point(module_scope)
