# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.ratelimit.v4alpha import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto',
  package='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha',
  syntax='proto3',
  serialized_options=b'\nUio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alphaB\016RateLimitProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nXenvoy/extensions/filters/network/thrift_proxy/filters/ratelimit/v4alpha/rate_limit.proto\x12Genvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha\x1a(envoy/config/ratelimit/v4alpha/rls.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb6\x02\n\tRateLimit\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05stage\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x04 \x01(\x08\x12\\\n\x12rate_limit_service\x18\x05 \x01(\x0b\x32\x36.envoy.config.ratelimit.v4alpha.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:S\x9a\xc5\x88\x1eN\nLenvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v3.RateLimitBq\nUio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alphaB\x0eRateLimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMIT = _descriptor.Descriptor(
  name='RateLimit',
  full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.domain', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.stage', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_deny', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.failure_mode_deny', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limit_service', full_name='envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit.rate_limit_service', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v3.RateLimit',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=641,
)

_RATELIMIT.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RATELIMIT.fields_by_name['rate_limit_service'].message_type = envoy_dot_config_dot_ratelimit_dot_v4alpha_dot_rls__pb2._RATELIMITSERVICECONFIG
DESCRIPTOR.message_types_by_name['RateLimit'] = _RATELIMIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimit = _reflection.GeneratedProtocolMessageType('RateLimit', (_message.Message,), {
  'DESCRIPTOR' : _RATELIMIT,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.filters.ratelimit.v4alpha.RateLimit)
  })
_sym_db.RegisterMessage(RateLimit)


DESCRIPTOR._options = None
_RATELIMIT.fields_by_name['domain']._options = None
_RATELIMIT.fields_by_name['stage']._options = None
_RATELIMIT.fields_by_name['rate_limit_service']._options = None
_RATELIMIT._options = None
# @@protoc_insertion_point(module_scope)
