# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/cel_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import conformance_service_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/cel_service.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\017CelServiceProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*google/api/expr/v1alpha1/cel_service.proto\x12\x18google.api.expr.v1alpha1\x1a\x32google/api/expr/v1alpha1/conformance_service.proto2\x9d\x02\n\nCelService\x12Z\n\x05Parse\x12&.google.api.expr.v1alpha1.ParseRequest\x1a\'.google.api.expr.v1alpha1.ParseResponse\"\x00\x12Z\n\x05\x43heck\x12&.google.api.expr.v1alpha1.CheckRequest\x1a\'.google.api.expr.v1alpha1.CheckResponse\"\x00\x12W\n\x04\x45val\x12%.google.api.expr.v1alpha1.EvalRequest\x1a&.google.api.expr.v1alpha1.EvalResponse\"\x00\x42r\n\x1c\x63om.google.api.expr.v1alpha1B\x0f\x43\x65lServiceProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_CELSERVICE = _descriptor.ServiceDescriptor(
  name='CelService',
  full_name='google.api.expr.v1alpha1.CelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=125,
  serialized_end=410,
  methods=[
  _descriptor.MethodDescriptor(
    name='Parse',
    full_name='google.api.expr.v1alpha1.CelService.Parse',
    index=0,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._PARSEREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._PARSERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='google.api.expr.v1alpha1.CelService.Check',
    index=1,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._CHECKREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Eval',
    full_name='google.api.expr.v1alpha1.CelService.Eval',
    index=2,
    containing_service=None,
    input_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._EVALREQUEST,
    output_type=google_dot_api_dot_expr_dot_v1alpha1_dot_conformance__service__pb2._EVALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CELSERVICE)

DESCRIPTOR.services_by_name['CelService'] = _CELSERVICE

# @@protoc_insertion_point(module_scope)
