# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import protocol_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto',
  package='envoy.extensions.upstreams.http.v4alpha',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.upstreams.http.v4alphaB\030HttpProtocolOptionsProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/upstreams/http/v4alpha/http_protocol_options.proto\x12\'envoy.extensions.upstreams.http.v4alpha\x1a(envoy/config/core/v4alpha/protocol.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe1\x0c\n\x13HttpProtocolOptions\x12T\n\x1c\x63ommon_http_protocol_options\x18\x01 \x01(\x0b\x32..envoy.config.core.v4alpha.HttpProtocolOptions\x12^\n\x1eupstream_http_protocol_options\x18\x02 \x01(\x0b\x32\x36.envoy.config.core.v4alpha.UpstreamHttpProtocolOptions\x12o\n\x14\x65xplicit_http_config\x18\x03 \x01(\x0b\x32O.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfigH\x00\x12~\n\x1euse_downstream_protocol_config\x18\x04 \x01(\x0b\x32T.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfigH\x00\x12\x62\n\x0b\x61uto_config\x18\x05 \x01(\x0b\x32K.envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfigH\x00\x1a\xf6\x02\n\x12\x45xplicitHttpConfig\x12P\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptionsH\x00\x12Q\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptionsH\x00\x12Q\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http3ProtocolOptionsH\x00:P\x9a\xc5\x88\x1eK\nIenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfigB\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xe2\x02\n\x17UseDownstreamHttpConfig\x12N\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptions\x12O\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptions\x12O\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http3ProtocolOptions:U\x9a\xc5\x88\x1eP\nNenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfig\x1a\xff\x01\n\x0e\x41utoHttpConfig\x12N\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http1ProtocolOptions\x12O\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.Http2ProtocolOptions:L\x9a\xc5\x88\x1eG\nEenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfig:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.upstreams.http.v3.HttpProtocolOptionsB \n\x19upstream_protocol_options\x12\x03\xf8\x42\x01\x42[\n5io.envoyproxy.envoy.extensions.upstreams.http.v4alphaB\x18HttpProtocolOptionsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG = _descriptor.Descriptor(
  name='ExplicitHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http3_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.http3_protocol_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036K\nIenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='protocol_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig.protocol_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=793,
  serialized_end=1167,
)

_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG = _descriptor.Descriptor(
  name='UseDownstreamHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http3_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig.http3_protocol_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036P\nNenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1170,
  serialized_end=1524,
)

_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG = _descriptor.Descriptor(
  name='AutoHttpConfig',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig.http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig.http2_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036G\nEenvoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1782,
)

_HTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='HttpProtocolOptions',
  full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.common_http_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_http_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.upstream_http_protocol_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_http_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.explicit_http_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_downstream_protocol_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.use_downstream_protocol_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_config', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.auto_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG, _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG, _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.upstreams.http.v3.HttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='upstream_protocol_options', full_name='envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.upstream_protocol_options',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=246,
  serialized_end=1879,
)

_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP3PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http2_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config'].fields.append(
  _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'])
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.fields_by_name['http3_protocol_options'].containing_oneof = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.fields_by_name['http3_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP3PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.fields_by_name['http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP1PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.fields_by_name['http2_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTP2PROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG.containing_type = _HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['common_http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._HTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['upstream_http_protocol_options'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_protocol__pb2._UPSTREAMHTTPPROTOCOLOPTIONS
_HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'].message_type = _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG
_HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'].message_type = _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG
_HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'].message_type = _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['explicit_http_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['use_downstream_protocol_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options'].fields.append(
  _HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'])
_HTTPPROTOCOLOPTIONS.fields_by_name['auto_config'].containing_oneof = _HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']
DESCRIPTOR.message_types_by_name['HttpProtocolOptions'] = _HTTPPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpProtocolOptions = _reflection.GeneratedProtocolMessageType('HttpProtocolOptions', (_message.Message,), {

  'ExplicitHttpConfig' : _reflection.GeneratedProtocolMessageType('ExplicitHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.ExplicitHttpConfig)
    })
  ,

  'UseDownstreamHttpConfig' : _reflection.GeneratedProtocolMessageType('UseDownstreamHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.UseDownstreamHttpConfig)
    })
  ,

  'AutoHttpConfig' : _reflection.GeneratedProtocolMessageType('AutoHttpConfig', (_message.Message,), {
    'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG,
    '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions.AutoHttpConfig)
    })
  ,
  'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.extensions.upstreams.http.v4alpha.http_protocol_options_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.v4alpha.HttpProtocolOptions)
  })
_sym_db.RegisterMessage(HttpProtocolOptions)
_sym_db.RegisterMessage(HttpProtocolOptions.ExplicitHttpConfig)
_sym_db.RegisterMessage(HttpProtocolOptions.UseDownstreamHttpConfig)
_sym_db.RegisterMessage(HttpProtocolOptions.AutoHttpConfig)


DESCRIPTOR._options = None
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG.oneofs_by_name['protocol_config']._options = None
_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG._options = None
_HTTPPROTOCOLOPTIONS.oneofs_by_name['upstream_protocol_options']._options = None
_HTTPPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)
