# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/eds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import endpoint_pb2 as envoy_dot_api_dot_v2_dot_endpoint__pb2

from envoy.api.v2.endpoint_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/eds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010EdsProtoP\001\210\001\001\362\230\376\217\005\033\022\031envoy.service.endpoint.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/eds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/endpoint.proto\"\n\n\x08\x45\x64sDummy2\x80\x03\n\x18\x45ndpointDiscoveryService\x12X\n\x0fStreamEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x61\n\x0e\x44\x65ltaEndpoints\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12{\n\x0e\x46\x65tchEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v2/discovery:endpoints\x82\xd3\xe4\x93\x02\x03:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.api.v2.ClusterLoadAssignmentBT\n\x1aio.envoyproxy.envoy.api.v2B\x08\x45\x64sProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_endpoint__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_endpoint__pb2.DESCRIPTOR,])




_EDSDUMMY = _descriptor.Descriptor(
  name='EdsDummy',
  full_name='envoy.api.v2.EdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=236,
)

DESCRIPTOR.message_types_by_name['EdsDummy'] = _EDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdsDummy = _reflection.GeneratedProtocolMessageType('EdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _EDSDUMMY,
  '__module__' : 'envoy.api.v2.eds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.EdsDummy)
  })
_sym_db.RegisterMessage(EdsDummy)


DESCRIPTOR._options = None

_ENDPOINTDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='EndpointDiscoveryService',
  full_name='envoy.api.v2.EndpointDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007$\n\"envoy.api.v2.ClusterLoadAssignment',
  create_key=_descriptor._internal_create_key,
  serialized_start=239,
  serialized_end=623,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.StreamEndpoints',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.DeltaEndpoints',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchEndpoints',
    full_name='envoy.api.v2.EndpointDiscoveryService.FetchEndpoints',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v2/discovery:endpoints\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENDPOINTDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['EndpointDiscoveryService'] = _ENDPOINTDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
