# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto',
  package='envoy.extensions.filters.http.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\023ProcessingModeProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDenvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x12.envoy.extensions.filters.http.ext_proc.v3alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd0\x06\n\x0eProcessingMode\x12t\n\x13request_header_mode\x18\x01 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12u\n\x14response_header_mode\x18\x02 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x11request_body_mode\x18\x03 \x01(\x0e\x32K.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x12response_body_mode\x18\x04 \x01(\x0e\x32K.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12u\n\x14request_trailer_mode\x18\x05 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12v\n\x15response_trailer_mode\x18\x06 \x01(\x0e\x32M.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"1\n\x0eHeaderSendMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x08\n\x04SEND\x10\x01\x12\x08\n\x04SKIP\x10\x02\"J\n\x0c\x42odySendMode\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08STREAMED\x10\x01\x12\x0c\n\x08\x42UFFERED\x10\x02\x12\x14\n\x10\x42UFFERED_PARTIAL\x10\x03\x42\x65\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\x13ProcessingModeProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_PROCESSINGMODE_HEADERSENDMODE = _descriptor.EnumDescriptor(
  name='HeaderSendMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.HeaderSendMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SKIP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=900,
  serialized_end=949,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODE_HEADERSENDMODE)

_PROCESSINGMODE_BODYSENDMODE = _descriptor.EnumDescriptor(
  name='BodySendMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.BodySendMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUFFERED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUFFERED_PARTIAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=951,
  serialized_end=1025,
)
_sym_db.RegisterEnumDescriptor(_PROCESSINGMODE_BODYSENDMODE)


_PROCESSINGMODE = _descriptor.Descriptor(
  name='ProcessingMode',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_header_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_header_mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_header_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_header_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_body_mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_body_mode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailer_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.request_trailer_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailer_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode.response_trailer_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROCESSINGMODE_HEADERSENDMODE,
    _PROCESSINGMODE_BODYSENDMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=177,
  serialized_end=1025,
)

_PROCESSINGMODE.fields_by_name['request_header_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['response_header_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['request_body_mode'].enum_type = _PROCESSINGMODE_BODYSENDMODE
_PROCESSINGMODE.fields_by_name['response_body_mode'].enum_type = _PROCESSINGMODE_BODYSENDMODE
_PROCESSINGMODE.fields_by_name['request_trailer_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE.fields_by_name['response_trailer_mode'].enum_type = _PROCESSINGMODE_HEADERSENDMODE
_PROCESSINGMODE_HEADERSENDMODE.containing_type = _PROCESSINGMODE
_PROCESSINGMODE_BODYSENDMODE.containing_type = _PROCESSINGMODE
DESCRIPTOR.message_types_by_name['ProcessingMode'] = _PROCESSINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingMode = _reflection.GeneratedProtocolMessageType('ProcessingMode', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGMODE,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.processing_mode_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode)
  })
_sym_db.RegisterMessage(ProcessingMode)


DESCRIPTOR._options = None
_PROCESSINGMODE.fields_by_name['request_header_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_header_mode']._options = None
_PROCESSINGMODE.fields_by_name['request_body_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_body_mode']._options = None
_PROCESSINGMODE.fields_by_name['request_trailer_mode']._options = None
_PROCESSINGMODE.fields_by_name['response_trailer_mode']._options = None
# @@protoc_insertion_point(module_scope)
