# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto',
  package='envoy.config.filter.network.redis_proxy.v2',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\017RedisProxyProtoP\001\362\230\376\217\0051\022/envoy.extensions.filters.network.redis_proxy.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/config/filter/network/redis_proxy/v2/redis_proxy.proto\x12*envoy.config.filter.network.redis_proxy.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xef\x0b\n\nRedisProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x19\n\x07\x63luster\x18\x02 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x63\n\x08settings\x18\x03 \x01(\x0b\x32G.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11latency_in_micros\x18\x04 \x01(\x08\x12Z\n\rprefix_routes\x18\x05 \x01(\x0b\x32\x43.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes\x12G\n\x18\x64ownstream_auth_password\x18\x06 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x1a\x92\x04\n\x10\x43onnPoolSettings\x12\x37\n\nop_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02\x08\x01\x12\x1a\n\x12\x65nable_hashtagging\x18\x02 \x01(\x08\x12\x1a\n\x12\x65nable_redirection\x18\x03 \x01(\x08\x12$\n\x1cmax_buffer_size_before_flush\x18\x04 \x01(\r\x12\x37\n\x14\x62uffer_flush_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x46\n max_upstream_unknown_connections\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14\x65nable_command_stats\x18\x08 \x01(\x08\x12q\n\x0bread_policy\x18\x07 \x01(\x0e\x32R.envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.ReadPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"U\n\nReadPolicy\x12\n\n\x06MASTER\x10\x00\x12\x11\n\rPREFER_MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\x12\x12\n\x0ePREFER_REPLICA\x10\x03\x12\x07\n\x03\x41NY\x10\x04\x1a\xed\x04\n\x0cPrefixRoutes\x12Y\n\x06routes\x18\x01 \x03(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x12\x18\n\x10\x63\x61se_insensitive\x18\x02 \x01(\x08\x12#\n\x11\x63\x61tch_all_cluster\x18\x03 \x01(\tB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x62\n\x0f\x63\x61tch_all_route\x18\x04 \x01(\x0b\x32I.envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route\x1a\xde\x02\n\x05Route\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x15\n\rremove_prefix\x18\x02 \x01(\x08\x12\x18\n\x07\x63luster\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12|\n\x15request_mirror_policy\x18\x04 \x03(\x0b\x32].envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy\x1a\x95\x01\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x45\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12\x1d\n\x15\x65xclude_read_commands\x18\x03 \x01(\x08\"T\n\x14RedisProtocolOptions\x12<\n\rauth_password\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x42\x8c\x01\n8io.envoyproxy.envoy.config.filter.network.redis_proxy.v2B\x0fRedisProxyProtoP\x01\xf2\x98\xfe\x8f\x05\x31\x12/envoy.extensions.filters.network.redis_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_REDISPROXY_CONNPOOLSETTINGS_READPOLICY = _descriptor.EnumDescriptor(
  name='ReadPolicy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.ReadPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MASTER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_MASTER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLICA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREFER_REPLICA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ANY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1172,
  serialized_end=1257,
)
_sym_db.RegisterEnumDescriptor(_REDISPROXY_CONNPOOLSETTINGS_READPOLICY)


_REDISPROXY_CONNPOOLSETTINGS = _descriptor.Descriptor(
  name='ConnPoolSettings',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_timeout', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.op_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_hashtagging', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_hashtagging', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_redirection', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_redirection', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_buffer_size_before_flush', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.max_buffer_size_before_flush', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_flush_timeout', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.buffer_flush_timeout', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_upstream_unknown_connections', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.max_upstream_unknown_connections', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_command_stats', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.enable_command_stats', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='read_policy', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings.read_policy', index=7,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REDISPROXY_CONNPOOLSETTINGS_READPOLICY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=1257,
)

_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY = _descriptor.Descriptor(
  name='RequestMirrorPolicy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_fraction', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.runtime_fraction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_read_commands', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy.exclude_read_commands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=1881,
)

_REDISPROXY_PREFIXROUTES_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.remove_prefix', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_mirror_policy', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.request_mirror_policy', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1531,
  serialized_end=1881,
)

_REDISPROXY_PREFIXROUTES = _descriptor.Descriptor(
  name='PrefixRoutes',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_insensitive', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.case_insensitive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catch_all_cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.catch_all_cluster', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='catch_all_route', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.catch_all_route', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_PREFIXROUTES_ROUTE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1881,
)

_REDISPROXY = _descriptor.Descriptor(
  name='RedisProxy',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.settings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_in_micros', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.latency_in_micros', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_routes', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.prefix_routes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downstream_auth_password', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProxy.downstream_auth_password', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REDISPROXY_CONNPOOLSETTINGS, _REDISPROXY_PREFIXROUTES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=362,
  serialized_end=1881,
)


_REDISPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='RedisProtocolOptions',
  full_name='envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_password', full_name='envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions.auth_password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1967,
)

_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['buffer_flush_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['max_upstream_unknown_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy'].enum_type = _REDISPROXY_CONNPOOLSETTINGS_READPOLICY
_REDISPROXY_CONNPOOLSETTINGS.containing_type = _REDISPROXY
_REDISPROXY_CONNPOOLSETTINGS_READPOLICY.containing_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['runtime_fraction'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.containing_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['request_mirror_policy'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY
_REDISPROXY_PREFIXROUTES_ROUTE.containing_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY_PREFIXROUTES.fields_by_name['routes'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_route'].message_type = _REDISPROXY_PREFIXROUTES_ROUTE
_REDISPROXY_PREFIXROUTES.containing_type = _REDISPROXY
_REDISPROXY.fields_by_name['settings'].message_type = _REDISPROXY_CONNPOOLSETTINGS
_REDISPROXY.fields_by_name['prefix_routes'].message_type = _REDISPROXY_PREFIXROUTES
_REDISPROXY.fields_by_name['downstream_auth_password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
DESCRIPTOR.message_types_by_name['RedisProxy'] = _REDISPROXY
DESCRIPTOR.message_types_by_name['RedisProtocolOptions'] = _REDISPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisProxy = _reflection.GeneratedProtocolMessageType('RedisProxy', (_message.Message,), {

  'ConnPoolSettings' : _reflection.GeneratedProtocolMessageType('ConnPoolSettings', (_message.Message,), {
    'DESCRIPTOR' : _REDISPROXY_CONNPOOLSETTINGS,
    '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.ConnPoolSettings)
    })
  ,

  'PrefixRoutes' : _reflection.GeneratedProtocolMessageType('PrefixRoutes', (_message.Message,), {

    'Route' : _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {

      'RequestMirrorPolicy' : _reflection.GeneratedProtocolMessageType('RequestMirrorPolicy', (_message.Message,), {
        'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY,
        '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)
        })
      ,
      'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES_ROUTE,
      '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes.Route)
      })
    ,
    'DESCRIPTOR' : _REDISPROXY_PREFIXROUTES,
    '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy.PrefixRoutes)
    })
  ,
  'DESCRIPTOR' : _REDISPROXY,
  '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProxy)
  })
_sym_db.RegisterMessage(RedisProxy)
_sym_db.RegisterMessage(RedisProxy.ConnPoolSettings)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route)
_sym_db.RegisterMessage(RedisProxy.PrefixRoutes.Route.RequestMirrorPolicy)

RedisProtocolOptions = _reflection.GeneratedProtocolMessageType('RedisProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _REDISPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.filter.network.redis_proxy.v2.redis_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.redis_proxy.v2.RedisProtocolOptions)
  })
_sym_db.RegisterMessage(RedisProtocolOptions)


DESCRIPTOR._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['op_timeout']._options = None
_REDISPROXY_CONNPOOLSETTINGS.fields_by_name['read_policy']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES_ROUTE.fields_by_name['cluster']._options = None
_REDISPROXY_PREFIXROUTES.fields_by_name['catch_all_cluster']._options = None
_REDISPROXY.fields_by_name['stat_prefix']._options = None
_REDISPROXY.fields_by_name['cluster']._options = None
_REDISPROXY.fields_by_name['settings']._options = None
_REDISPROXY.fields_by_name['downstream_auth_password']._options = None
_REDISPROTOCOLOPTIONS.fields_by_name['auth_password']._options = None
# @@protoc_insertion_point(module_scope)
