# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/cluster/v4alpha/outlier_detection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/cluster/v4alpha/outlier_detection.proto',
  package='envoy.config.cluster.v4alpha',
  syntax='proto3',
  serialized_options=b'\n*io.envoyproxy.envoy.config.cluster.v4alphaB\025OutlierDetectionProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/config/cluster/v4alpha/outlier_detection.proto\x12\x1c\x65nvoy.config.cluster.v4alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8f\x0c\n\x10OutlierDetection\x12\x35\n\x0f\x63onsecutive_5xx\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12\x62\x61se_ejection_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x43\n\x14max_ejection_percent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12H\n\x19\x65nforcing_consecutive_5xx\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x45\n\x16\x65nforcing_success_rate\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12@\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\x19success_rate_stdev_factor\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x41\n\x1b\x63onsecutive_gateway_failure\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12T\n%enforcing_consecutive_gateway_failure\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12*\n\"split_external_local_origin_errors\x18\x0c \x01(\x08\x12\x46\n consecutive_local_origin_failure\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12Y\n*enforcing_consecutive_local_origin_failure\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12R\n#enforcing_local_origin_success_rate\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x66\x61ilure_percentage_threshold\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12K\n\x1c\x65nforcing_failure_percentage\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12X\n)enforcing_failure_percentage_local_origin\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\x12\x46\n failure_percentage_minimum_hosts\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12G\n!failure_percentage_request_volume\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x11max_ejection_time\x18\x15 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00:/\x9a\xc5\x88\x1e*\n(envoy.config.cluster.v3.OutlierDetectionBM\n*io.envoyproxy.envoy.config.cluster.v4alphaB\x15OutlierDetectionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_OUTLIERDETECTION = _descriptor.Descriptor(
  name='OutlierDetection',
  full_name='envoy.config.cluster.v4alpha.OutlierDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consecutive_5xx', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_5xx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.cluster.v4alpha.OutlierDetection.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_ejection_time', full_name='envoy.config.cluster.v4alpha.OutlierDetection.base_ejection_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ejection_percent', full_name='envoy.config.cluster.v4alpha.OutlierDetection.max_ejection_percent', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_5xx', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_5xx', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_success_rate', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_success_rate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_minimum_hosts', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_minimum_hosts', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_request_volume', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_request_volume', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_rate_stdev_factor', full_name='envoy.config.cluster.v4alpha.OutlierDetection.success_rate_stdev_factor', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consecutive_gateway_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_gateway_failure', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_gateway_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_gateway_failure', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='split_external_local_origin_errors', full_name='envoy.config.cluster.v4alpha.OutlierDetection.split_external_local_origin_errors', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consecutive_local_origin_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.consecutive_local_origin_failure', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_consecutive_local_origin_failure', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_consecutive_local_origin_failure', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_local_origin_success_rate', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_local_origin_success_rate', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_threshold', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_threshold', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_failure_percentage', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_failure_percentage', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforcing_failure_percentage_local_origin', full_name='envoy.config.cluster.v4alpha.OutlierDetection.enforcing_failure_percentage_local_origin', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_minimum_hosts', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_minimum_hosts', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_percentage_request_volume', full_name='envoy.config.cluster.v4alpha.OutlierDetection.failure_percentage_request_volume', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_ejection_time', full_name='envoy.config.cluster.v4alpha.OutlierDetection.max_ejection_time', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.cluster.v3.OutlierDetection',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=1793,
)

_OUTLIERDETECTION.fields_by_name['consecutive_5xx'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OUTLIERDETECTION.fields_by_name['base_ejection_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OUTLIERDETECTION.fields_by_name['max_ejection_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_success_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_minimum_hosts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_request_volume'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['success_rate_stdev_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['consecutive_gateway_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['consecutive_local_origin_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_minimum_hosts'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['failure_percentage_request_volume'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_OUTLIERDETECTION.fields_by_name['max_ejection_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['OutlierDetection'] = _OUTLIERDETECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OutlierDetection = _reflection.GeneratedProtocolMessageType('OutlierDetection', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERDETECTION,
  '__module__' : 'envoy.config.cluster.v4alpha.outlier_detection_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.cluster.v4alpha.OutlierDetection)
  })
_sym_db.RegisterMessage(OutlierDetection)


DESCRIPTOR._options = None
_OUTLIERDETECTION.fields_by_name['interval']._options = None
_OUTLIERDETECTION.fields_by_name['base_ejection_time']._options = None
_OUTLIERDETECTION.fields_by_name['max_ejection_percent']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_5xx']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_success_rate']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_gateway_failure']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_consecutive_local_origin_failure']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_local_origin_success_rate']._options = None
_OUTLIERDETECTION.fields_by_name['failure_percentage_threshold']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage']._options = None
_OUTLIERDETECTION.fields_by_name['enforcing_failure_percentage_local_origin']._options = None
_OUTLIERDETECTION.fields_by_name['max_ejection_time']._options = None
_OUTLIERDETECTION._options = None
# @@protoc_insertion_point(module_scope)
