# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v2alpha/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/data/cluster/v2alpha/outlier_detection_event.proto',
  package='envoy.data.cluster.v2alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.data.cluster.v2alphaB\032OutlierDetectionEventProtoP\001\362\230\376\217\005\027\022\025envoy.data.cluster.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/data/cluster/v2alpha/outlier_detection_event.proto\x12\x1a\x65nvoy.data.cluster.v2alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x96\x05\n\x15OutlierDetectionEvent\x12G\n\x04type\x18\x01 \x01(\x0e\x32/.envoy.data.cluster.v2alpha.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12<\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\".envoy.data.cluster.v2alpha.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12W\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectSuccessRateH\x00\x12V\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32\x33.envoy.data.cluster.v2alpha.OutlierEjectConsecutiveH\x00\x12\x63\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x39.envoy.data.cluster.v2alpha.OutlierEjectFailurePercentageH\x00\x42\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xa6\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\"\x19\n\x17OutlierEjectConsecutive\"C\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42m\n(io.envoyproxy.envoy.data.cluster.v2alphaB\x1aOutlierDetectionEventProtoP\x01\xf2\x98\xfe\x8f\x05\x17\x12\x15\x65nvoy.data.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_OUTLIEREJECTIONTYPE = _descriptor.EnumDescriptor(
  name='OutlierEjectionType',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_5XX', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_GATEWAY_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_RATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONSECUTIVE_LOCAL_ORIGIN_FAILURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS_RATE_LOCAL_ORIGIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_PERCENTAGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILURE_PERCENTAGE_LOCAL_ORIGIN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1172,
  serialized_end=1395,
)
_sym_db.RegisterEnumDescriptor(_OUTLIEREJECTIONTYPE)

OutlierEjectionType = enum_type_wrapper.EnumTypeWrapper(_OUTLIEREJECTIONTYPE)
_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='envoy.data.cluster.v2alpha.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EJECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNEJECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1397,
  serialized_end=1429,
)
_sym_db.RegisterEnumDescriptor(_ACTION)

Action = enum_type_wrapper.EnumTypeWrapper(_ACTION)
CONSECUTIVE_5XX = 0
CONSECUTIVE_GATEWAY_FAILURE = 1
SUCCESS_RATE = 2
CONSECUTIVE_LOCAL_ORIGIN_FAILURE = 3
SUCCESS_RATE_LOCAL_ORIGIN = 4
FAILURE_PERCENTAGE = 5
FAILURE_PERCENTAGE_LOCAL_ORIGIN = 6
EJECT = 0
UNEJECT = 1



_OUTLIERDETECTIONEVENT = _descriptor.Descriptor(
  name='OutlierDetectionEvent',
  full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secs_since_last_action', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.secs_since_last_action', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.cluster_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_url', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.upstream_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.action', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_ejections', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.num_ejections', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enforced', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.enforced', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_success_rate_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_success_rate_event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_consecutive_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_consecutive_event', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eject_failure_percentage_event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.eject_failure_percentage_event', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='envoy.data.cluster.v2alpha.OutlierDetectionEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=242,
  serialized_end=904,
)


_OUTLIEREJECTSUCCESSRATE = _descriptor.Descriptor(
  name='OutlierEjectSuccessRate',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.host_success_rate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_average_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.cluster_average_success_rate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_success_rate_ejection_threshold', full_name='envoy.data.cluster.v2alpha.OutlierEjectSuccessRate.cluster_success_rate_ejection_threshold', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=907,
  serialized_end=1073,
)


_OUTLIEREJECTCONSECUTIVE = _descriptor.Descriptor(
  name='OutlierEjectConsecutive',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectConsecutive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1100,
)


_OUTLIEREJECTFAILUREPERCENTAGE = _descriptor.Descriptor(
  name='OutlierEjectFailurePercentage',
  full_name='envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_success_rate', full_name='envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage.host_success_rate', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030d', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1169,
)

_OUTLIERDETECTIONEVENT.fields_by_name['type'].enum_type = _OUTLIEREJECTIONTYPE
_OUTLIERDETECTIONEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OUTLIERDETECTIONEVENT.fields_by_name['secs_since_last_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_OUTLIERDETECTIONEVENT.fields_by_name['action'].enum_type = _ACTION
_OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'].message_type = _OUTLIEREJECTSUCCESSRATE
_OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'].message_type = _OUTLIEREJECTCONSECUTIVE
_OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'].message_type = _OUTLIEREJECTFAILUREPERCENTAGE
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_success_rate_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_consecutive_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
_OUTLIERDETECTIONEVENT.oneofs_by_name['event'].fields.append(
  _OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'])
_OUTLIERDETECTIONEVENT.fields_by_name['eject_failure_percentage_event'].containing_oneof = _OUTLIERDETECTIONEVENT.oneofs_by_name['event']
DESCRIPTOR.message_types_by_name['OutlierDetectionEvent'] = _OUTLIERDETECTIONEVENT
DESCRIPTOR.message_types_by_name['OutlierEjectSuccessRate'] = _OUTLIEREJECTSUCCESSRATE
DESCRIPTOR.message_types_by_name['OutlierEjectConsecutive'] = _OUTLIEREJECTCONSECUTIVE
DESCRIPTOR.message_types_by_name['OutlierEjectFailurePercentage'] = _OUTLIEREJECTFAILUREPERCENTAGE
DESCRIPTOR.enum_types_by_name['OutlierEjectionType'] = _OUTLIEREJECTIONTYPE
DESCRIPTOR.enum_types_by_name['Action'] = _ACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OutlierDetectionEvent = _reflection.GeneratedProtocolMessageType('OutlierDetectionEvent', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIERDETECTIONEVENT,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierDetectionEvent)
  })
_sym_db.RegisterMessage(OutlierDetectionEvent)

OutlierEjectSuccessRate = _reflection.GeneratedProtocolMessageType('OutlierEjectSuccessRate', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTSUCCESSRATE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectSuccessRate)
  })
_sym_db.RegisterMessage(OutlierEjectSuccessRate)

OutlierEjectConsecutive = _reflection.GeneratedProtocolMessageType('OutlierEjectConsecutive', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTCONSECUTIVE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectConsecutive)
  })
_sym_db.RegisterMessage(OutlierEjectConsecutive)

OutlierEjectFailurePercentage = _reflection.GeneratedProtocolMessageType('OutlierEjectFailurePercentage', (_message.Message,), {
  'DESCRIPTOR' : _OUTLIEREJECTFAILUREPERCENTAGE,
  '__module__' : 'envoy.data.cluster.v2alpha.outlier_detection_event_pb2'
  # @@protoc_insertion_point(class_scope:envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage)
  })
_sym_db.RegisterMessage(OutlierEjectFailurePercentage)


DESCRIPTOR._options = None
_OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
_OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
_OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
_OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
# @@protoc_insertion_point(module_scope)
