# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/protocol.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/config/core/v3/protocol.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"A\n\x12TcpProtocolOptions:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.core.TcpProtocolOptions\"\x82\x01\n\x1bUpstreamHttpProtocolOptions\x12\x10\n\x08\x61uto_sni\x18\x01 \x01(\x08\x12\x1b\n\x13\x61uto_san_validation\x18\x02 \x01(\x08:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions\"\xeb\x03\n\x13HttpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17max_connection_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x11max_headers_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x13max_stream_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12o\n\x1fheaders_with_underscores_action\x18\x05 \x01(\x0e\x32\x46.envoy.config.core.v3.HttpProtocolOptions.HeadersWithUnderscoresAction\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HttpProtocolOptions\"\xcc\x05\n\x14Http1ProtocolOptions\x12\x36\n\x12\x61llow_absolute_url\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x63\x63\x65pt_http_10\x18\x02 \x01(\x08\x12 \n\x18\x64\x65\x66\x61ult_host_for_http_10\x18\x03 \x01(\t\x12U\n\x11header_key_format\x18\x04 \x01(\x0b\x32:.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat\x12\x17\n\x0f\x65nable_trailers\x18\x05 \x01(\x08\x12\x1c\n\x14\x61llow_chunked_length\x18\x06 \x01(\x08\x12Q\n-override_stream_error_on_invalid_http_message\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\xb1\x02\n\x0fHeaderKeyFormat\x12g\n\x11proper_case_words\x18\x01 \x01(\x0b\x32J.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWordsH\x00\x1a`\n\x0fProperCaseWords:M\x9a\xc5\x88\x1eH\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords:=\x9a\xc5\x88\x1e\x38\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormatB\x14\n\rheader_format\x12\x03\xf8\x42\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http1ProtocolOptions\"\xbd\x01\n\x11KeepaliveSettings\x12;\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12:\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12/\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\"\xc4\n\n\x14Http2ProtocolOptions\x12\x36\n\x10hpack_table_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12K\n\x16max_concurrent_streams\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\r\xfa\x42\n*\x08\x18\xff\xff\xff\xff\x07(\x01\x12Q\n\x1ainitial_stream_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12U\n\x1einitial_connection_window_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12\x15\n\rallow_connect\x18\x05 \x01(\x08\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\x12\x42\n\x13max_outbound_frames\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12J\n\x1bmax_outbound_control_frames\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12W\n1max_consecutive_inbound_frames_with_empty_payload\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12L\n&max_inbound_priority_frames_per_stream\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x63\n4max_inbound_window_update_frames_per_data_frame_sent\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x32\n&stream_error_on_invalid_http_messaging\x18\x0c \x01(\x08\x42\x02\x18\x01\x12Q\n-override_stream_error_on_invalid_http_message\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x1a\x63ustom_settings_parameters\x18\r \x03(\x0b\x32<.envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter\x12\x45\n\x14\x63onnection_keepalive\x18\x0f \x01(\x0b\x32\'.envoy.config.core.v3.KeepaliveSettings\x1a\xd2\x01\n\x11SettingsParameter\x12\x45\n\nidentifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x13\xfa\x42\x08*\x06\x18\xff\xff\x03(\x00\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http2ProtocolOptions\"\x8f\x01\n\x13GrpcProtocolOptions\x12J\n\x16http2_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.GrpcProtocolOptions\"\x16\n\x14Http3ProtocolOptionsB=\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION = _descriptor.EnumDescriptor(
  name='HeadersWithUnderscoresAction',
  full_name='envoy.config.core.v3.HttpProtocolOptions.HeadersWithUnderscoresAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REJECT_REQUEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DROP_HEADER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=813,
  serialized_end=891,
)
_sym_db.RegisterEnumDescriptor(_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION)


_TCPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='TcpProtocolOptions',
  full_name='envoy.config.core.v3.TcpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036&\n$envoy.api.v2.core.TcpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=245,
  serialized_end=310,
)


_UPSTREAMHTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='UpstreamHttpProtocolOptions',
  full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auto_sni', full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions.auto_sni', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_san_validation', full_name='envoy.config.core.v3.UpstreamHttpProtocolOptions.auto_san_validation', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=443,
)


_HTTPPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='HttpProtocolOptions',
  full_name='envoy.config.core.v3.HttpProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.core.v3.HttpProtocolOptions.idle_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_connection_duration', full_name='envoy.config.core.v3.HttpProtocolOptions.max_connection_duration', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_headers_count', full_name='envoy.config.core.v3.HttpProtocolOptions.max_headers_count', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stream_duration', full_name='envoy.config.core.v3.HttpProtocolOptions.max_stream_duration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_with_underscores_action', full_name='envoy.config.core.v3.HttpProtocolOptions.headers_with_underscores_action', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION,
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.HttpProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=937,
)


_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS = _descriptor.Descriptor(
  name='ProperCaseWords',
  full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1428,
  serialized_end=1524,
)

_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT = _descriptor.Descriptor(
  name='HeaderKeyFormat',
  full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proper_case_words', full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.proper_case_words', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='header_format', full_name='envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.header_format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1304,
  serialized_end=1609,
)

_HTTP1PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http1ProtocolOptions',
  full_name='envoy.config.core.v3.Http1ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_absolute_url', full_name='envoy.config.core.v3.Http1ProtocolOptions.allow_absolute_url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_http_10', full_name='envoy.config.core.v3.Http1ProtocolOptions.accept_http_10', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_host_for_http_10', full_name='envoy.config.core.v3.Http1ProtocolOptions.default_host_for_http_10', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_key_format', full_name='envoy.config.core.v3.Http1ProtocolOptions.header_key_format', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_trailers', full_name='envoy.config.core.v3.Http1ProtocolOptions.enable_trailers', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_chunked_length', full_name='envoy.config.core.v3.Http1ProtocolOptions.allow_chunked_length', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_stream_error_on_invalid_http_message', full_name='envoy.config.core.v3.Http1ProtocolOptions.override_stream_error_on_invalid_http_message', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.core.Http1ProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1656,
)


_KEEPALIVESETTINGS = _descriptor.Descriptor(
  name='KeepaliveSettings',
  full_name='envoy.config.core.v3.KeepaliveSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.core.v3.KeepaliveSettings.interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\0012\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.core.v3.KeepaliveSettings.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\252\001\010\010\0012\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter', full_name='envoy.config.core.v3.KeepaliveSettings.interval_jitter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1848,
)


_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER = _descriptor.Descriptor(
  name='SettingsParameter',
  full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\030\377\377\003(\000\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2942,
  serialized_end=3152,
)

_HTTP2PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http2ProtocolOptions',
  full_name='envoy.config.core.v3.Http2ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hpack_table_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.hpack_table_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_concurrent_streams', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\n*\010\030\377\377\377\377\007(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_stream_window_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.initial_stream_window_size', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014*\n\030\377\377\377\377\007(\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_connection_window_size', full_name='envoy.config.core.v3.Http2ProtocolOptions.initial_connection_window_size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\014*\n\030\377\377\377\377\007(\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_connect', full_name='envoy.config.core.v3.Http2ProtocolOptions.allow_connect', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_metadata', full_name='envoy.config.core.v3.Http2ProtocolOptions.allow_metadata', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_outbound_frames', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_outbound_frames', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_outbound_control_frames', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_outbound_control_frames', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_consecutive_inbound_frames_with_empty_payload', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_consecutive_inbound_frames_with_empty_payload', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inbound_priority_frames_per_stream', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_inbound_priority_frames_per_stream', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_inbound_window_update_frames_per_data_frame_sent', full_name='envoy.config.core.v3.Http2ProtocolOptions.max_inbound_window_update_frames_per_data_frame_sent', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_error_on_invalid_http_messaging', full_name='envoy.config.core.v3.Http2ProtocolOptions.stream_error_on_invalid_http_messaging', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_stream_error_on_invalid_http_message', full_name='envoy.config.core.v3.Http2ProtocolOptions.override_stream_error_on_invalid_http_message', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_settings_parameters', full_name='envoy.config.core.v3.Http2ProtocolOptions.custom_settings_parameters', index=13,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_keepalive', full_name='envoy.config.core.v3.Http2ProtocolOptions.connection_keepalive', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.api.v2.core.Http2ProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1851,
  serialized_end=3199,
)


_GRPCPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='GrpcProtocolOptions',
  full_name='envoy.config.core.v3.GrpcProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http2_protocol_options', full_name='envoy.config.core.v3.GrpcProtocolOptions.http2_protocol_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.GrpcProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3202,
  serialized_end=3345,
)


_HTTP3PROTOCOLOPTIONS = _descriptor.Descriptor(
  name='Http3ProtocolOptions',
  full_name='envoy.config.core.v3.Http3ProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3347,
  serialized_end=3369,
)

_HTTPPROTOCOLOPTIONS.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['max_connection_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTPPROTOCOLOPTIONS.fields_by_name['max_stream_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HTTPPROTOCOLOPTIONS.fields_by_name['headers_with_underscores_action'].enum_type = _HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION
_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION.containing_type = _HTTPPROTOCOLOPTIONS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS.containing_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'].message_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.containing_type = _HTTP1PROTOCOLOPTIONS
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format'].fields.append(
  _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'])
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.fields_by_name['proper_case_words'].containing_oneof = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']
_HTTP1PROTOCOLOPTIONS.fields_by_name['allow_absolute_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTP1PROTOCOLOPTIONS.fields_by_name['header_key_format'].message_type = _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT
_HTTP1PROTOCOLOPTIONS.fields_by_name['override_stream_error_on_invalid_http_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_KEEPALIVESETTINGS.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KEEPALIVESETTINGS.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_KEEPALIVESETTINGS.fields_by_name['interval_jitter'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._PERCENT
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.containing_type = _HTTP2PROTOCOLOPTIONS
_HTTP2PROTOCOLOPTIONS.fields_by_name['hpack_table_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_consecutive_inbound_frames_with_empty_payload'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_priority_frames_per_stream'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['override_stream_error_on_invalid_http_message'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HTTP2PROTOCOLOPTIONS.fields_by_name['custom_settings_parameters'].message_type = _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER
_HTTP2PROTOCOLOPTIONS.fields_by_name['connection_keepalive'].message_type = _KEEPALIVESETTINGS
_GRPCPROTOCOLOPTIONS.fields_by_name['http2_protocol_options'].message_type = _HTTP2PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['TcpProtocolOptions'] = _TCPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['UpstreamHttpProtocolOptions'] = _UPSTREAMHTTPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['HttpProtocolOptions'] = _HTTPPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['Http1ProtocolOptions'] = _HTTP1PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['KeepaliveSettings'] = _KEEPALIVESETTINGS
DESCRIPTOR.message_types_by_name['Http2ProtocolOptions'] = _HTTP2PROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['GrpcProtocolOptions'] = _GRPCPROTOCOLOPTIONS
DESCRIPTOR.message_types_by_name['Http3ProtocolOptions'] = _HTTP3PROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TcpProtocolOptions = _reflection.GeneratedProtocolMessageType('TcpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _TCPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.TcpProtocolOptions)
  })
_sym_db.RegisterMessage(TcpProtocolOptions)

UpstreamHttpProtocolOptions = _reflection.GeneratedProtocolMessageType('UpstreamHttpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _UPSTREAMHTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.UpstreamHttpProtocolOptions)
  })
_sym_db.RegisterMessage(UpstreamHttpProtocolOptions)

HttpProtocolOptions = _reflection.GeneratedProtocolMessageType('HttpProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _HTTPPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HttpProtocolOptions)
  })
_sym_db.RegisterMessage(HttpProtocolOptions)

Http1ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http1ProtocolOptions', (_message.Message,), {

  'HeaderKeyFormat' : _reflection.GeneratedProtocolMessageType('HeaderKeyFormat', (_message.Message,), {

    'ProperCaseWords' : _reflection.GeneratedProtocolMessageType('ProperCaseWords', (_message.Message,), {
      'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS,
      '__module__' : 'envoy.config.core.v3.protocol_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords)
      })
    ,
    'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT,
    '__module__' : 'envoy.config.core.v3.protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat)
    })
  ,
  'DESCRIPTOR' : _HTTP1PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http1ProtocolOptions)
  })
_sym_db.RegisterMessage(Http1ProtocolOptions)
_sym_db.RegisterMessage(Http1ProtocolOptions.HeaderKeyFormat)
_sym_db.RegisterMessage(Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords)

KeepaliveSettings = _reflection.GeneratedProtocolMessageType('KeepaliveSettings', (_message.Message,), {
  'DESCRIPTOR' : _KEEPALIVESETTINGS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.KeepaliveSettings)
  })
_sym_db.RegisterMessage(KeepaliveSettings)

Http2ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http2ProtocolOptions', (_message.Message,), {

  'SettingsParameter' : _reflection.GeneratedProtocolMessageType('SettingsParameter', (_message.Message,), {
    'DESCRIPTOR' : _HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER,
    '__module__' : 'envoy.config.core.v3.protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter)
    })
  ,
  'DESCRIPTOR' : _HTTP2PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http2ProtocolOptions)
  })
_sym_db.RegisterMessage(Http2ProtocolOptions)
_sym_db.RegisterMessage(Http2ProtocolOptions.SettingsParameter)

GrpcProtocolOptions = _reflection.GeneratedProtocolMessageType('GrpcProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _GRPCPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.GrpcProtocolOptions)
  })
_sym_db.RegisterMessage(GrpcProtocolOptions)

Http3ProtocolOptions = _reflection.GeneratedProtocolMessageType('Http3ProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _HTTP3PROTOCOLOPTIONS,
  '__module__' : 'envoy.config.core.v3.protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.Http3ProtocolOptions)
  })
_sym_db.RegisterMessage(Http3ProtocolOptions)


DESCRIPTOR._options = None
_TCPPROTOCOLOPTIONS._options = None
_UPSTREAMHTTPPROTOCOLOPTIONS._options = None
_HTTPPROTOCOLOPTIONS.fields_by_name['max_headers_count']._options = None
_HTTPPROTOCOLOPTIONS._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT.oneofs_by_name['header_format']._options = None
_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT._options = None
_HTTP1PROTOCOLOPTIONS._options = None
_KEEPALIVESETTINGS.fields_by_name['interval']._options = None
_KEEPALIVESETTINGS.fields_by_name['timeout']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['identifier']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER.fields_by_name['value']._options = None
_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_concurrent_streams']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_stream_window_size']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['initial_connection_window_size']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_frames']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_outbound_control_frames']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._options = None
_HTTP2PROTOCOLOPTIONS.fields_by_name['stream_error_on_invalid_http_messaging']._options = None
_HTTP2PROTOCOLOPTIONS._options = None
_GRPCPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)
