# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/decl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import expr_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1beta1/decl.proto',
  package='google.api.expr.v1beta1',
  syntax='proto3',
  serialized_options=b'\n\033com.google.api.expr.v1beta1B\tDeclProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"google/api/expr/v1beta1/decl.proto\x12\x17google.api.expr.v1beta1\x1a\"google/api/expr/v1beta1/expr.proto\"\xa5\x01\n\x04\x44\x65\x63l\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x64oc\x18\x03 \x01(\t\x12\x33\n\x05ident\x18\x04 \x01(\x0b\x32\".google.api.expr.v1beta1.IdentDeclH\x00\x12\x39\n\x08\x66unction\x18\x05 \x01(\x0b\x32%.google.api.expr.v1beta1.FunctionDeclH\x00\x42\x06\n\x04kind\"\\\n\x08\x44\x65\x63lType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x36\n\x0btype_params\x18\x04 \x03(\x0b\x32!.google.api.expr.v1beta1.DeclType\"j\n\tIdentDecl\x12/\n\x04type\x18\x03 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12,\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\"\x93\x01\n\x0c\x46unctionDecl\x12\x30\n\x04\x61rgs\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.IdentDecl\x12\x36\n\x0breturn_type\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.DeclType\x12\x19\n\x11receiver_function\x18\x03 \x01(\x08\x42j\n\x1b\x63om.google.api.expr.v1beta1B\tDeclProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2.DESCRIPTOR,])




_DECL = _descriptor.Descriptor(
  name='Decl',
  full_name='google.api.expr.v1beta1.Decl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.Decl.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.expr.v1beta1.Decl.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doc', full_name='google.api.expr.v1beta1.Decl.doc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ident', full_name='google.api.expr.v1beta1.Decl.ident', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='google.api.expr.v1beta1.Decl.function', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='google.api.expr.v1beta1.Decl.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=100,
  serialized_end=265,
)


_DECLTYPE = _descriptor.Descriptor(
  name='DeclType',
  full_name='google.api.expr.v1beta1.DeclType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.DeclType.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1beta1.DeclType.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_params', full_name='google.api.expr.v1beta1.DeclType.type_params', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=359,
)


_IDENTDECL = _descriptor.Descriptor(
  name='IdentDecl',
  full_name='google.api.expr.v1beta1.IdentDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='google.api.expr.v1beta1.IdentDecl.type', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.IdentDecl.value', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=467,
)


_FUNCTIONDECL = _descriptor.Descriptor(
  name='FunctionDecl',
  full_name='google.api.expr.v1beta1.FunctionDecl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='google.api.expr.v1beta1.FunctionDecl.args', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_type', full_name='google.api.expr.v1beta1.FunctionDecl.return_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver_function', full_name='google.api.expr.v1beta1.FunctionDecl.receiver_function', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=617,
)

_DECL.fields_by_name['ident'].message_type = _IDENTDECL
_DECL.fields_by_name['function'].message_type = _FUNCTIONDECL
_DECL.oneofs_by_name['kind'].fields.append(
  _DECL.fields_by_name['ident'])
_DECL.fields_by_name['ident'].containing_oneof = _DECL.oneofs_by_name['kind']
_DECL.oneofs_by_name['kind'].fields.append(
  _DECL.fields_by_name['function'])
_DECL.fields_by_name['function'].containing_oneof = _DECL.oneofs_by_name['kind']
_DECLTYPE.fields_by_name['type_params'].message_type = _DECLTYPE
_IDENTDECL.fields_by_name['type'].message_type = _DECLTYPE
_IDENTDECL.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1beta1_dot_expr__pb2._EXPR
_FUNCTIONDECL.fields_by_name['args'].message_type = _IDENTDECL
_FUNCTIONDECL.fields_by_name['return_type'].message_type = _DECLTYPE
DESCRIPTOR.message_types_by_name['Decl'] = _DECL
DESCRIPTOR.message_types_by_name['DeclType'] = _DECLTYPE
DESCRIPTOR.message_types_by_name['IdentDecl'] = _IDENTDECL
DESCRIPTOR.message_types_by_name['FunctionDecl'] = _FUNCTIONDECL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Decl = _reflection.GeneratedProtocolMessageType('Decl', (_message.Message,), {
  'DESCRIPTOR' : _DECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.Decl)
  })
_sym_db.RegisterMessage(Decl)

DeclType = _reflection.GeneratedProtocolMessageType('DeclType', (_message.Message,), {
  'DESCRIPTOR' : _DECLTYPE,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.DeclType)
  })
_sym_db.RegisterMessage(DeclType)

IdentDecl = _reflection.GeneratedProtocolMessageType('IdentDecl', (_message.Message,), {
  'DESCRIPTOR' : _IDENTDECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.IdentDecl)
  })
_sym_db.RegisterMessage(IdentDecl)

FunctionDecl = _reflection.GeneratedProtocolMessageType('FunctionDecl', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONDECL,
  '__module__' : 'google.api.expr.v1beta1.decl_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.FunctionDecl)
  })
_sym_db.RegisterMessage(FunctionDecl)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
