# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.listener import listener_components_pb2 as envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2

from envoy.api.v2.listener.listener_components_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener/listener.proto',
  package='envoy.api.v2.listener',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\001\252\002\027Envoy.Api.V2.ListenerNS\352\002\027Envoy.Api.V2.ListenerNS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/api/v2/listener/listener.proto\x12\x15\x65nvoy.api.v2.listener\x1a/envoy/api/v2/listener/listener_components.protoBj\n#io.envoyproxy.envoy.api.v2.listenerB\rListenerProtoP\x01\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x17\x45nvoy.Api.V2.ListenerNSP\x00\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_listener_dot_listener__components__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
