# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/tap/v2alpha/tap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.tap.v2alpha import common_pb2 as envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/tap/v2alpha/tap.proto',
  package='envoy.config.filter.http.tap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.config.filter.http.tap.v2alphaB\010TapProtoP\001\362\230\376\217\005&\022$envoy.extensions.filters.http.tap.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.envoy/config/filter/http/tap/v2alpha/tap.proto\x12$envoy.config.filter.http.tap.v2alpha\x1a,envoy/config/common/tap/v2alpha/common.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"^\n\x03Tap\x12W\n\rcommon_config\x18\x01 \x01(\x0b\x32\x36.envoy.config.common.tap.v2alpha.CommonExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42t\n2io.envoyproxy.envoy.config.filter.http.tap.v2alphaB\x08TapProtoP\x01\xf2\x98\xfe\x8f\x05&\x12$envoy.extensions.filters.http.tap.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TAP = _descriptor.Descriptor(
  name='Tap',
  full_name='envoy.config.filter.http.tap.v2alpha.Tap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.config.filter.http.tap.v2alpha.Tap.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=316,
)

_TAP.fields_by_name['common_config'].message_type = envoy_dot_config_dot_common_dot_tap_dot_v2alpha_dot_common__pb2._COMMONEXTENSIONCONFIG
DESCRIPTOR.message_types_by_name['Tap'] = _TAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tap = _reflection.GeneratedProtocolMessageType('Tap', (_message.Message,), {
  'DESCRIPTOR' : _TAP,
  '__module__' : 'envoy.config.filter.http.tap.v2alpha.tap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.tap.v2alpha.Tap)
  })
_sym_db.RegisterMessage(Tap)


DESCRIPTOR._options = None
_TAP.fields_by_name['common_config']._options = None
# @@protoc_insertion_point(module_scope)
