# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.dns.v3 import dns_table_pb2 as envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto',
  package='envoy.extensions.filters.udp.dns_filter.v3alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3alphaB\016DnsFilterProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/udp/dns_filter/v3alpha/dns_filter.proto\x12/envoy.extensions.filters.udp.dns_filter.v3alpha\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a!envoy/data/dns/v3/dns_table.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xea\x04\n\x0f\x44nsFilterConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12k\n\rserver_config\x18\x02 \x01(\x0b\x32T.envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig\x12k\n\rclient_config\x18\x03 \x01(\x0b\x32T.envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig\x1a\xa4\x01\n\x13ServerContextConfig\x12\x37\n\x10inline_dns_table\x18\x01 \x01(\x0b\x32\x1b.envoy.data.dns.v3.DnsTableH\x00\x12>\n\x12\x65xternal_dns_table\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x14\n\rconfig_source\x12\x03\xf8\x42\x01\x1a\xb7\x01\n\x13\x43lientContextConfig\x12?\n\x10resolver_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12\x39\n\x12upstream_resolvers\x18\x02 \x03(\x0b\x32\x1d.envoy.config.core.v3.Address\x12$\n\x13max_pending_lookups\x18\x03 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x42\x61\n=io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3alphaB\x0e\x44nsFilterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DNSFILTERCONFIG_SERVERCONTEXTCONFIG = _descriptor.Descriptor(
  name='ServerContextConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inline_dns_table', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.inline_dns_table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_dns_table', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.external_dns_table', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_source', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig.config_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=578,
  serialized_end=742,
)

_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG = _descriptor.Descriptor(
  name='ClientContextConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolver_timeout', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.resolver_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\0042\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_resolvers', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.upstream_resolvers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_pending_lookups', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig.max_pending_lookups', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0042\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=928,
)

_DNSFILTERCONFIG = _descriptor.Descriptor(
  name='DnsFilterConfig',
  full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_config', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.server_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_config', full_name='envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.client_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DNSFILTERCONFIG_SERVERCONTEXTCONFIG, _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=928,
)

_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'].message_type = envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2._DNSTABLE
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._DATASOURCE
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.containing_type = _DNSFILTERCONFIG
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source'].fields.append(
  _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'])
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['inline_dns_table'].containing_oneof = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source'].fields.append(
  _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'])
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.fields_by_name['external_dns_table'].containing_oneof = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['resolver_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['upstream_resolvers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_address__pb2._ADDRESS
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.containing_type = _DNSFILTERCONFIG
_DNSFILTERCONFIG.fields_by_name['server_config'].message_type = _DNSFILTERCONFIG_SERVERCONTEXTCONFIG
_DNSFILTERCONFIG.fields_by_name['client_config'].message_type = _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG
DESCRIPTOR.message_types_by_name['DnsFilterConfig'] = _DNSFILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DnsFilterConfig = _reflection.GeneratedProtocolMessageType('DnsFilterConfig', (_message.Message,), {

  'ServerContextConfig' : _reflection.GeneratedProtocolMessageType('ServerContextConfig', (_message.Message,), {
    'DESCRIPTOR' : _DNSFILTERCONFIG_SERVERCONTEXTCONFIG,
    '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ServerContextConfig)
    })
  ,

  'ClientContextConfig' : _reflection.GeneratedProtocolMessageType('ClientContextConfig', (_message.Message,), {
    'DESCRIPTOR' : _DNSFILTERCONFIG_CLIENTCONTEXTCONFIG,
    '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig.ClientContextConfig)
    })
  ,
  'DESCRIPTOR' : _DNSFILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.udp.dns_filter.v3alpha.dns_filter_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.dns_filter.v3alpha.DnsFilterConfig)
  })
_sym_db.RegisterMessage(DnsFilterConfig)
_sym_db.RegisterMessage(DnsFilterConfig.ServerContextConfig)
_sym_db.RegisterMessage(DnsFilterConfig.ClientContextConfig)


DESCRIPTOR._options = None
_DNSFILTERCONFIG_SERVERCONTEXTCONFIG.oneofs_by_name['config_source']._options = None
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['resolver_timeout']._options = None
_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG.fields_by_name['max_pending_lookups']._options = None
_DNSFILTERCONFIG.fields_by_name['stat_prefix']._options = None
# @@protoc_insertion_point(module_scope)
