# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v2/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/metrics/v2/metrics_service.proto',
  package='envoy.config.metrics.v2',
  syntax='proto3',
  serialized_options=b'\n%io.envoyproxy.envoy.config.metrics.v2B\023MetricsServiceProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-envoy/config/metrics/v2/metrics_service.proto\x12\x17\x65nvoy.config.metrics.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"V\n\x14MetricsServiceConfig\x12>\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\x46\n%io.envoyproxy.envoy.config.metrics.v2B\x13MetricsServiceProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_METRICSSERVICECONFIG = _descriptor.Descriptor(
  name='MetricsServiceConfig',
  full_name='envoy.config.metrics.v2.MetricsServiceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.metrics.v2.MetricsServiceConfig.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=254,
)

_METRICSSERVICECONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
DESCRIPTOR.message_types_by_name['MetricsServiceConfig'] = _METRICSSERVICECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MetricsServiceConfig = _reflection.GeneratedProtocolMessageType('MetricsServiceConfig', (_message.Message,), {
  'DESCRIPTOR' : _METRICSSERVICECONFIG,
  '__module__' : 'envoy.config.metrics.v2.metrics_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.metrics.v2.MetricsServiceConfig)
  })
_sym_db.RegisterMessage(MetricsServiceConfig)


DESCRIPTOR._options = None
_METRICSSERVICECONFIG.fields_by_name['grpc_service']._options = None
# @@protoc_insertion_point(module_scope)
