# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto',
  package='envoy.extensions.rate_limit_descriptors.expr.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:envoy/extensions/rate_limit_descriptors/expr/v3/expr.proto\x12/envoy.extensions.rate_limit_descriptors.expr.v3\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa1\x01\n\nDescriptor\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\rskip_if_error\x18\x02 \x01(\x08\x12\x17\n\x04text\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x30\n\x06parsed\x18\x04 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x42\x10\n\x0e\x65xpr_specifierBT\n=io.envoyproxy.envoy.extensions.rate_limit_descriptors.expr.v3B\tExprProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_DESCRIPTOR = _descriptor.Descriptor(
  name='Descriptor',
  full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptor_key', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.descriptor_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_if_error', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.skip_if_error', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parsed', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.parsed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expr_specifier', full_name='envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor.expr_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=207,
  serialized_end=368,
)

_DESCRIPTOR.fields_by_name['parsed'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._EXPR
_DESCRIPTOR.oneofs_by_name['expr_specifier'].fields.append(
  _DESCRIPTOR.fields_by_name['text'])
_DESCRIPTOR.fields_by_name['text'].containing_oneof = _DESCRIPTOR.oneofs_by_name['expr_specifier']
_DESCRIPTOR.oneofs_by_name['expr_specifier'].fields.append(
  _DESCRIPTOR.fields_by_name['parsed'])
_DESCRIPTOR.fields_by_name['parsed'].containing_oneof = _DESCRIPTOR.oneofs_by_name['expr_specifier']
DESCRIPTOR.message_types_by_name['Descriptor'] = _DESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Descriptor = _reflection.GeneratedProtocolMessageType('Descriptor', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIPTOR,
  '__module__' : 'envoy.extensions.rate_limit_descriptors.expr.v3.expr_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.rate_limit_descriptors.expr.v3.Descriptor)
  })
_sym_db.RegisterMessage(Descriptor)


DESCRIPTOR._options = None
_DESCRIPTOR.fields_by_name['descriptor_key']._options = None
_DESCRIPTOR.fields_by_name['text']._options = None
# @@protoc_insertion_point(module_scope)
