# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/overload/v2alpha/overload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/overload/v2alpha/overload.proto',
  package='envoy.config.overload.v2alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.overload.v2alphaB\rOverloadProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,envoy/config/overload/v2alpha/overload.proto\x12\x1d\x65nvoy.config.overload.v2alpha\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x94\x01\n\x0fResourceMonitor\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\":\n\x10ThresholdTrigger\x12&\n\x05value\x18\x01 \x01(\x01\x42\x17\xfa\x42\x14\x12\x12\x19\x00\x00\x00\x00\x00\x00\xf0?)\x00\x00\x00\x00\x00\x00\x00\x00\"|\n\x07Trigger\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x44\n\tthreshold\x18\x02 \x01(\x0b\x32/.envoy.config.overload.v2alpha.ThresholdTriggerH\x00\x42\x14\n\rtrigger_oneof\x12\x03\xf8\x42\x01\"k\n\x0eOverloadAction\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x42\n\x08triggers\x18\x02 \x03(\x0b\x32&.envoy.config.overload.v2alpha.TriggerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\"\xdb\x01\n\x0fOverloadManager\x12\x33\n\x10refresh_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12S\n\x11resource_monitors\x18\x02 \x03(\x0b\x32..envoy.config.overload.v2alpha.ResourceMonitorB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12>\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32-.envoy.config.overload.v2alpha.OverloadActionBF\n+io.envoyproxy.envoy.config.overload.v2alphaB\rOverloadProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RESOURCEMONITOR = _descriptor.Descriptor(
  name='ResourceMonitor',
  full_name='envoy.config.overload.v2alpha.ResourceMonitor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v2alpha.ResourceMonitor.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.config.overload.v2alpha.ResourceMonitor.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.overload.v2alpha.ResourceMonitor.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.overload.v2alpha.ResourceMonitor.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=225,
  serialized_end=373,
)


_THRESHOLDTRIGGER = _descriptor.Descriptor(
  name='ThresholdTrigger',
  full_name='envoy.config.overload.v2alpha.ThresholdTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.overload.v2alpha.ThresholdTrigger.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\024\022\022\031\000\000\000\000\000\000\360?)\000\000\000\000\000\000\000\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=433,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='envoy.config.overload.v2alpha.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v2alpha.Trigger.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='envoy.config.overload.v2alpha.Trigger.threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='trigger_oneof', full_name='envoy.config.overload.v2alpha.Trigger.trigger_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=435,
  serialized_end=559,
)


_OVERLOADACTION = _descriptor.Descriptor(
  name='OverloadAction',
  full_name='envoy.config.overload.v2alpha.OverloadAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.overload.v2alpha.OverloadAction.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggers', full_name='envoy.config.overload.v2alpha.OverloadAction.triggers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=668,
)


_OVERLOADMANAGER = _descriptor.Descriptor(
  name='OverloadManager',
  full_name='envoy.config.overload.v2alpha.OverloadManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='refresh_interval', full_name='envoy.config.overload.v2alpha.OverloadManager.refresh_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_monitors', full_name='envoy.config.overload.v2alpha.OverloadManager.resource_monitors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='envoy.config.overload.v2alpha.OverloadManager.actions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=671,
  serialized_end=890,
)

_RESOURCEMONITOR.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RESOURCEMONITOR.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RESOURCEMONITOR.oneofs_by_name['config_type'].fields.append(
  _RESOURCEMONITOR.fields_by_name['config'])
_RESOURCEMONITOR.fields_by_name['config'].containing_oneof = _RESOURCEMONITOR.oneofs_by_name['config_type']
_RESOURCEMONITOR.oneofs_by_name['config_type'].fields.append(
  _RESOURCEMONITOR.fields_by_name['typed_config'])
_RESOURCEMONITOR.fields_by_name['typed_config'].containing_oneof = _RESOURCEMONITOR.oneofs_by_name['config_type']
_TRIGGER.fields_by_name['threshold'].message_type = _THRESHOLDTRIGGER
_TRIGGER.oneofs_by_name['trigger_oneof'].fields.append(
  _TRIGGER.fields_by_name['threshold'])
_TRIGGER.fields_by_name['threshold'].containing_oneof = _TRIGGER.oneofs_by_name['trigger_oneof']
_OVERLOADACTION.fields_by_name['triggers'].message_type = _TRIGGER
_OVERLOADMANAGER.fields_by_name['refresh_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_OVERLOADMANAGER.fields_by_name['resource_monitors'].message_type = _RESOURCEMONITOR
_OVERLOADMANAGER.fields_by_name['actions'].message_type = _OVERLOADACTION
DESCRIPTOR.message_types_by_name['ResourceMonitor'] = _RESOURCEMONITOR
DESCRIPTOR.message_types_by_name['ThresholdTrigger'] = _THRESHOLDTRIGGER
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['OverloadAction'] = _OVERLOADACTION
DESCRIPTOR.message_types_by_name['OverloadManager'] = _OVERLOADMANAGER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResourceMonitor = _reflection.GeneratedProtocolMessageType('ResourceMonitor', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMONITOR,
  '__module__' : 'envoy.config.overload.v2alpha.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v2alpha.ResourceMonitor)
  })
_sym_db.RegisterMessage(ResourceMonitor)

ThresholdTrigger = _reflection.GeneratedProtocolMessageType('ThresholdTrigger', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDTRIGGER,
  '__module__' : 'envoy.config.overload.v2alpha.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v2alpha.ThresholdTrigger)
  })
_sym_db.RegisterMessage(ThresholdTrigger)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'envoy.config.overload.v2alpha.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v2alpha.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

OverloadAction = _reflection.GeneratedProtocolMessageType('OverloadAction', (_message.Message,), {
  'DESCRIPTOR' : _OVERLOADACTION,
  '__module__' : 'envoy.config.overload.v2alpha.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v2alpha.OverloadAction)
  })
_sym_db.RegisterMessage(OverloadAction)

OverloadManager = _reflection.GeneratedProtocolMessageType('OverloadManager', (_message.Message,), {
  'DESCRIPTOR' : _OVERLOADMANAGER,
  '__module__' : 'envoy.config.overload.v2alpha.overload_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.overload.v2alpha.OverloadManager)
  })
_sym_db.RegisterMessage(OverloadManager)


DESCRIPTOR._options = None
_RESOURCEMONITOR.fields_by_name['name']._options = None
_RESOURCEMONITOR.fields_by_name['config']._options = None
_THRESHOLDTRIGGER.fields_by_name['value']._options = None
_TRIGGER.oneofs_by_name['trigger_oneof']._options = None
_TRIGGER.fields_by_name['name']._options = None
_OVERLOADACTION.fields_by_name['name']._options = None
_OVERLOADACTION.fields_by_name['triggers']._options = None
_OVERLOADMANAGER.fields_by_name['resource_monitors']._options = None
# @@protoc_insertion_point(module_scope)
