# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/stats/v1/stats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencensus/proto/stats/v1/stats.proto',
  package='opencensus.proto.stats.v1',
  syntax='proto3',
  serialized_options=b'\n\034io.opencensus.proto.stats.v1B\nStatsProtoP\001ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/stats/v1\352\002\031OpenCensus.Proto.Stats.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%opencensus/proto/stats/v1/stats.proto\x12\x19opencensus.proto.stats.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa6\x01\n\x07Measure\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\x12\x35\n\x04type\x18\x04 \x01(\x0e\x32\'.opencensus.proto.stats.v1.Measure.Type\"3\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05INT64\x10\x01\x12\n\n\x06\x44OUBLE\x10\x02\"\xb9\x03\n\x04View\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x33\n\x07measure\x18\x03 \x01(\x0b\x32\".opencensus.proto.stats.v1.Measure\x12\x0f\n\x07\x63olumns\x18\x04 \x03(\t\x12H\n\x11\x63ount_aggregation\x18\x05 \x01(\x0b\x32+.opencensus.proto.stats.v1.CountAggregationH\x00\x12\x44\n\x0fsum_aggregation\x18\x06 \x01(\x0b\x32).opencensus.proto.stats.v1.SumAggregationH\x00\x12Q\n\x16last_value_aggregation\x18\x07 \x01(\x0b\x32/.opencensus.proto.stats.v1.LastValueAggregationH\x00\x12V\n\x18\x64istribution_aggregation\x18\x08 \x01(\x0b\x32\x32.opencensus.proto.stats.v1.DistributionAggregationH\x00\x42\r\n\x0b\x61ggregation\"\x12\n\x10\x43ountAggregation\"\x10\n\x0eSumAggregation\"\x16\n\x14LastValueAggregation\"0\n\x17\x44istributionAggregation\x12\x15\n\rbucket_bounds\x18\x01 \x03(\x01\"\xb1\x01\n\x0bMeasurement\x12,\n\x04tags\x18\x01 \x03(\x0b\x32\x1e.opencensus.proto.stats.v1.Tag\x12\x14\n\x0cmeasure_name\x18\x02 \x01(\t\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12(\n\x04time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x07\n\x05valueB\x8c\x01\n\x1cio.opencensus.proto.stats.v1B\nStatsProtoP\x01ZBgithub.com/census-instrumentation/opencensus-proto/gen-go/stats/v1\xea\x02\x19OpenCensus.Proto.Stats.V1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_MEASURE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencensus.proto.stats.v1.Measure.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INT64', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=252,
  serialized_end=303,
)
_sym_db.RegisterEnumDescriptor(_MEASURE_TYPE)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='opencensus.proto.stats.v1.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencensus.proto.stats.v1.Tag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencensus.proto.stats.v1.Tag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=134,
)


_MEASURE = _descriptor.Descriptor(
  name='Measure',
  full_name='opencensus.proto.stats.v1.Measure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencensus.proto.stats.v1.Measure.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='opencensus.proto.stats.v1.Measure.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencensus.proto.stats.v1.Measure.unit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencensus.proto.stats.v1.Measure.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEASURE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=303,
)


_VIEW = _descriptor.Descriptor(
  name='View',
  full_name='opencensus.proto.stats.v1.View',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencensus.proto.stats.v1.View.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='opencensus.proto.stats.v1.View.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measure', full_name='opencensus.proto.stats.v1.View.measure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='opencensus.proto.stats.v1.View.columns', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_aggregation', full_name='opencensus.proto.stats.v1.View.count_aggregation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sum_aggregation', full_name='opencensus.proto.stats.v1.View.sum_aggregation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_value_aggregation', full_name='opencensus.proto.stats.v1.View.last_value_aggregation', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_aggregation', full_name='opencensus.proto.stats.v1.View.distribution_aggregation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='aggregation', full_name='opencensus.proto.stats.v1.View.aggregation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=306,
  serialized_end=747,
)


_COUNTAGGREGATION = _descriptor.Descriptor(
  name='CountAggregation',
  full_name='opencensus.proto.stats.v1.CountAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=749,
  serialized_end=767,
)


_SUMAGGREGATION = _descriptor.Descriptor(
  name='SumAggregation',
  full_name='opencensus.proto.stats.v1.SumAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=785,
)


_LASTVALUEAGGREGATION = _descriptor.Descriptor(
  name='LastValueAggregation',
  full_name='opencensus.proto.stats.v1.LastValueAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=787,
  serialized_end=809,
)


_DISTRIBUTIONAGGREGATION = _descriptor.Descriptor(
  name='DistributionAggregation',
  full_name='opencensus.proto.stats.v1.DistributionAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_bounds', full_name='opencensus.proto.stats.v1.DistributionAggregation.bucket_bounds', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=859,
)


_MEASUREMENT = _descriptor.Descriptor(
  name='Measurement',
  full_name='opencensus.proto.stats.v1.Measurement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='opencensus.proto.stats.v1.Measurement.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measure_name', full_name='opencensus.proto.stats.v1.Measurement.measure_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='opencensus.proto.stats.v1.Measurement.double_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='opencensus.proto.stats.v1.Measurement.int_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='opencensus.proto.stats.v1.Measurement.time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='opencensus.proto.stats.v1.Measurement.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=862,
  serialized_end=1039,
)

_MEASURE.fields_by_name['type'].enum_type = _MEASURE_TYPE
_MEASURE_TYPE.containing_type = _MEASURE
_VIEW.fields_by_name['measure'].message_type = _MEASURE
_VIEW.fields_by_name['count_aggregation'].message_type = _COUNTAGGREGATION
_VIEW.fields_by_name['sum_aggregation'].message_type = _SUMAGGREGATION
_VIEW.fields_by_name['last_value_aggregation'].message_type = _LASTVALUEAGGREGATION
_VIEW.fields_by_name['distribution_aggregation'].message_type = _DISTRIBUTIONAGGREGATION
_VIEW.oneofs_by_name['aggregation'].fields.append(
  _VIEW.fields_by_name['count_aggregation'])
_VIEW.fields_by_name['count_aggregation'].containing_oneof = _VIEW.oneofs_by_name['aggregation']
_VIEW.oneofs_by_name['aggregation'].fields.append(
  _VIEW.fields_by_name['sum_aggregation'])
_VIEW.fields_by_name['sum_aggregation'].containing_oneof = _VIEW.oneofs_by_name['aggregation']
_VIEW.oneofs_by_name['aggregation'].fields.append(
  _VIEW.fields_by_name['last_value_aggregation'])
_VIEW.fields_by_name['last_value_aggregation'].containing_oneof = _VIEW.oneofs_by_name['aggregation']
_VIEW.oneofs_by_name['aggregation'].fields.append(
  _VIEW.fields_by_name['distribution_aggregation'])
_VIEW.fields_by_name['distribution_aggregation'].containing_oneof = _VIEW.oneofs_by_name['aggregation']
_MEASUREMENT.fields_by_name['tags'].message_type = _TAG
_MEASUREMENT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MEASUREMENT.oneofs_by_name['value'].fields.append(
  _MEASUREMENT.fields_by_name['double_value'])
_MEASUREMENT.fields_by_name['double_value'].containing_oneof = _MEASUREMENT.oneofs_by_name['value']
_MEASUREMENT.oneofs_by_name['value'].fields.append(
  _MEASUREMENT.fields_by_name['int_value'])
_MEASUREMENT.fields_by_name['int_value'].containing_oneof = _MEASUREMENT.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.message_types_by_name['Measure'] = _MEASURE
DESCRIPTOR.message_types_by_name['View'] = _VIEW
DESCRIPTOR.message_types_by_name['CountAggregation'] = _COUNTAGGREGATION
DESCRIPTOR.message_types_by_name['SumAggregation'] = _SUMAGGREGATION
DESCRIPTOR.message_types_by_name['LastValueAggregation'] = _LASTVALUEAGGREGATION
DESCRIPTOR.message_types_by_name['DistributionAggregation'] = _DISTRIBUTIONAGGREGATION
DESCRIPTOR.message_types_by_name['Measurement'] = _MEASUREMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.Tag)
  })
_sym_db.RegisterMessage(Tag)

Measure = _reflection.GeneratedProtocolMessageType('Measure', (_message.Message,), {
  'DESCRIPTOR' : _MEASURE,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.Measure)
  })
_sym_db.RegisterMessage(Measure)

View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.View)
  })
_sym_db.RegisterMessage(View)

CountAggregation = _reflection.GeneratedProtocolMessageType('CountAggregation', (_message.Message,), {
  'DESCRIPTOR' : _COUNTAGGREGATION,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.CountAggregation)
  })
_sym_db.RegisterMessage(CountAggregation)

SumAggregation = _reflection.GeneratedProtocolMessageType('SumAggregation', (_message.Message,), {
  'DESCRIPTOR' : _SUMAGGREGATION,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.SumAggregation)
  })
_sym_db.RegisterMessage(SumAggregation)

LastValueAggregation = _reflection.GeneratedProtocolMessageType('LastValueAggregation', (_message.Message,), {
  'DESCRIPTOR' : _LASTVALUEAGGREGATION,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.LastValueAggregation)
  })
_sym_db.RegisterMessage(LastValueAggregation)

DistributionAggregation = _reflection.GeneratedProtocolMessageType('DistributionAggregation', (_message.Message,), {
  'DESCRIPTOR' : _DISTRIBUTIONAGGREGATION,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.DistributionAggregation)
  })
_sym_db.RegisterMessage(DistributionAggregation)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREMENT,
  '__module__' : 'opencensus.proto.stats.v1.stats_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.stats.v1.Measurement)
  })
_sym_db.RegisterMessage(Measurement)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
