# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto',
  package='envoy.extensions.upstreams.http.tcp.v3',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.extensions.upstreams.http.tcp.v3B TcpConnectionPoolProtoOuterClassP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/upstreams/http/tcp/v3/tcp_connection_pool.proto\x12&envoy.extensions.upstreams.http.tcp.v3\x1a\x1dudpa/annotations/status.proto\"\x18\n\x16TcpConnectionPoolProtoBb\n4io.envoyproxy.envoy.extensions.upstreams.http.tcp.v3B TcpConnectionPoolProtoOuterClassP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_TCPCONNECTIONPOOLPROTO = _descriptor.Descriptor(
  name='TcpConnectionPoolProto',
  full_name='envoy.extensions.upstreams.http.tcp.v3.TcpConnectionPoolProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=163,
)

DESCRIPTOR.message_types_by_name['TcpConnectionPoolProto'] = _TCPCONNECTIONPOOLPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TcpConnectionPoolProto = _reflection.GeneratedProtocolMessageType('TcpConnectionPoolProto', (_message.Message,), {
  'DESCRIPTOR' : _TCPCONNECTIONPOOLPROTO,
  '__module__' : 'envoy.extensions.upstreams.http.tcp.v3.tcp_connection_pool_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.http.tcp.v3.TcpConnectionPoolProto)
  })
_sym_db.RegisterMessage(TcpConnectionPoolProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
