# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/eval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import value_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1beta1/eval.proto',
  package='google.api.expr.v1beta1',
  syntax='proto3',
  serialized_options=b'\n\033com.google.api.expr.v1beta1B\tEvalProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"google/api/expr/v1beta1/eval.proto\x12\x17google.api.expr.v1beta1\x1a#google/api/expr/v1beta1/value.proto\x1a\x17google/rpc/status.proto\"\xc2\x01\n\tEvalState\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".google.api.expr.v1beta1.ExprValue\x12:\n\x07results\x18\x03 \x03(\x0b\x32).google.api.expr.v1beta1.EvalState.Result\x1a\x45\n\x06Result\x12,\n\x04\x65xpr\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.IdRef\x12\r\n\x05value\x18\x02 \x01(\x05\"\xb0\x01\n\tExprValue\x12/\n\x05value\x18\x01 \x01(\x0b\x32\x1e.google.api.expr.v1beta1.ValueH\x00\x12\x32\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.google.api.expr.v1beta1.ErrorSetH\x00\x12\x36\n\x07unknown\x18\x03 \x01(\x0b\x32#.google.api.expr.v1beta1.UnknownSetH\x00\x42\x06\n\x04kind\".\n\x08\x45rrorSet\x12\"\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x12.google.rpc.Status\";\n\nUnknownSet\x12-\n\x05\x65xprs\x18\x01 \x03(\x0b\x32\x1e.google.api.expr.v1beta1.IdRef\"\x13\n\x05IdRef\x12\n\n\x02id\x18\x01 \x01(\x05\x42j\n\x1b\x63om.google.api.expr.v1beta1B\tEvalProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_EVALSTATE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='google.api.expr.v1beta1.EvalState.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='expr', full_name='google.api.expr.v1beta1.EvalState.Result.expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.EvalState.Result.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=320,
)

_EVALSTATE = _descriptor.Descriptor(
  name='EvalState',
  full_name='google.api.expr.v1beta1.EvalState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='google.api.expr.v1beta1.EvalState.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.api.expr.v1beta1.EvalState.results', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVALSTATE_RESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=320,
)


_EXPRVALUE = _descriptor.Descriptor(
  name='ExprValue',
  full_name='google.api.expr.v1beta1.ExprValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.ExprValue.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='google.api.expr.v1beta1.ExprValue.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown', full_name='google.api.expr.v1beta1.ExprValue.unknown', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='google.api.expr.v1beta1.ExprValue.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=323,
  serialized_end=499,
)


_ERRORSET = _descriptor.Descriptor(
  name='ErrorSet',
  full_name='google.api.expr.v1beta1.ErrorSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='google.api.expr.v1beta1.ErrorSet.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=547,
)


_UNKNOWNSET = _descriptor.Descriptor(
  name='UnknownSet',
  full_name='google.api.expr.v1beta1.UnknownSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exprs', full_name='google.api.expr.v1beta1.UnknownSet.exprs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=608,
)


_IDREF = _descriptor.Descriptor(
  name='IdRef',
  full_name='google.api.expr.v1beta1.IdRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1beta1.IdRef.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=610,
  serialized_end=629,
)

_EVALSTATE_RESULT.fields_by_name['expr'].message_type = _IDREF
_EVALSTATE_RESULT.containing_type = _EVALSTATE
_EVALSTATE.fields_by_name['values'].message_type = _EXPRVALUE
_EVALSTATE.fields_by_name['results'].message_type = _EVALSTATE_RESULT
_EXPRVALUE.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1beta1_dot_value__pb2._VALUE
_EXPRVALUE.fields_by_name['error'].message_type = _ERRORSET
_EXPRVALUE.fields_by_name['unknown'].message_type = _UNKNOWNSET
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['value'])
_EXPRVALUE.fields_by_name['value'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['error'])
_EXPRVALUE.fields_by_name['error'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_EXPRVALUE.oneofs_by_name['kind'].fields.append(
  _EXPRVALUE.fields_by_name['unknown'])
_EXPRVALUE.fields_by_name['unknown'].containing_oneof = _EXPRVALUE.oneofs_by_name['kind']
_ERRORSET.fields_by_name['errors'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_UNKNOWNSET.fields_by_name['exprs'].message_type = _IDREF
DESCRIPTOR.message_types_by_name['EvalState'] = _EVALSTATE
DESCRIPTOR.message_types_by_name['ExprValue'] = _EXPRVALUE
DESCRIPTOR.message_types_by_name['ErrorSet'] = _ERRORSET
DESCRIPTOR.message_types_by_name['UnknownSet'] = _UNKNOWNSET
DESCRIPTOR.message_types_by_name['IdRef'] = _IDREF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EvalState = _reflection.GeneratedProtocolMessageType('EvalState', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _EVALSTATE_RESULT,
    '__module__' : 'google.api.expr.v1beta1.eval_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.EvalState.Result)
    })
  ,
  'DESCRIPTOR' : _EVALSTATE,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.EvalState)
  })
_sym_db.RegisterMessage(EvalState)
_sym_db.RegisterMessage(EvalState.Result)

ExprValue = _reflection.GeneratedProtocolMessageType('ExprValue', (_message.Message,), {
  'DESCRIPTOR' : _EXPRVALUE,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.ExprValue)
  })
_sym_db.RegisterMessage(ExprValue)

ErrorSet = _reflection.GeneratedProtocolMessageType('ErrorSet', (_message.Message,), {
  'DESCRIPTOR' : _ERRORSET,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.ErrorSet)
  })
_sym_db.RegisterMessage(ErrorSet)

UnknownSet = _reflection.GeneratedProtocolMessageType('UnknownSet', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNSET,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.UnknownSet)
  })
_sym_db.RegisterMessage(UnknownSet)

IdRef = _reflection.GeneratedProtocolMessageType('IdRef', (_message.Message,), {
  'DESCRIPTOR' : _IDREF,
  '__module__' : 'google.api.expr.v1beta1.eval_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.IdRef)
  })
_sym_db.RegisterMessage(IdRef)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
