# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v2alpha/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v2alpha/metrics.proto',
  package='envoy.admin.v2alpha',
  syntax='proto3',
  serialized_options=b'\n!io.envoyproxy.envoy.admin.v2alphaB\014MetricsProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/admin/v2alpha/metrics.proto\x12\x13\x65nvoy.admin.v2alpha\x1a\x1dudpa/annotations/status.proto\"\x81\x01\n\x0cSimpleMetric\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.envoy.admin.v2alpha.SimpleMetric.Type\x12\r\n\x05value\x18\x02 \x01(\x04\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x1e\n\x04Type\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x42;\n!io.envoyproxy.envoy.admin.v2alphaB\x0cMetricsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_SIMPLEMETRIC_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='envoy.admin.v2alpha.SimpleMetric.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=189,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_SIMPLEMETRIC_TYPE)


_SIMPLEMETRIC = _descriptor.Descriptor(
  name='SimpleMetric',
  full_name='envoy.admin.v2alpha.SimpleMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.admin.v2alpha.SimpleMetric.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.admin.v2alpha.SimpleMetric.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v2alpha.SimpleMetric.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SIMPLEMETRIC_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=219,
)

_SIMPLEMETRIC.fields_by_name['type'].enum_type = _SIMPLEMETRIC_TYPE
_SIMPLEMETRIC_TYPE.containing_type = _SIMPLEMETRIC
DESCRIPTOR.message_types_by_name['SimpleMetric'] = _SIMPLEMETRIC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimpleMetric = _reflection.GeneratedProtocolMessageType('SimpleMetric', (_message.Message,), {
  'DESCRIPTOR' : _SIMPLEMETRIC,
  '__module__' : 'envoy.admin.v2alpha.metrics_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v2alpha.SimpleMetric)
  })
_sym_db.RegisterMessage(SimpleMetric)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
