# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/route/v4alpha/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import config_source_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/route/v4alpha/route.proto',
  package='envoy.config.route.v4alpha',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.config.route.v4alphaB\nRouteProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/config/route/v4alpha/route.proto\x12\x1a\x65nvoy.config.route.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a-envoy/config/core/v4alpha/config_source.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc1\x05\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\rvirtual_hosts\x18\x02 \x03(\x0b\x32\'.envoy.config.route.v4alpha.VirtualHost\x12.\n\x04vhds\x18\t \x01(\x0b\x32 .envoy.config.route.v4alpha.Vhds\x12/\n\x15internal_only_headers\x18\x03 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12X\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x34\n\x1aresponse_headers_to_remove\x18\x05 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12W\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32,.envoy.config.core.v4alpha.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12+\n#most_specific_header_mutations_wins\x18\n \x01(\x08\x12\x35\n\x11validate_clusters\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n#max_direct_response_body_size_bytes\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:/\x9a\xc5\x88\x1e*\n(envoy.config.route.v3.RouteConfiguration\"s\n\x04Vhds\x12H\n\rconfig_source\x18\x01 \x01(\x0b\x32\'.envoy.config.core.v4alpha.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:!\x9a\xc5\x88\x1e\x1c\n\x1a\x65nvoy.config.route.v3.VhdsB@\n(io.envoyproxy.envoy.config.route.v4alphaB\nRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTECONFIGURATION = _descriptor.Descriptor(
  name='RouteConfiguration',
  full_name='envoy.config.route.v4alpha.RouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.route.v4alpha.RouteConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='virtual_hosts', full_name='envoy.config.route.v4alpha.RouteConfiguration.virtual_hosts', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vhds', full_name='envoy.config.route.v4alpha.RouteConfiguration.vhds', index=2,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_only_headers', full_name='envoy.config.route.v4alpha.RouteConfiguration.internal_only_headers', index=3,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_add', full_name='envoy.config.route.v4alpha.RouteConfiguration.response_headers_to_add', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers_to_remove', full_name='envoy.config.route.v4alpha.RouteConfiguration.response_headers_to_remove', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.route.v4alpha.RouteConfiguration.request_headers_to_add', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.route.v4alpha.RouteConfiguration.request_headers_to_remove', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_specific_header_mutations_wins', full_name='envoy.config.route.v4alpha.RouteConfiguration.most_specific_header_mutations_wins', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validate_clusters', full_name='envoy.config.route.v4alpha.RouteConfiguration.validate_clusters', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_direct_response_body_size_bytes', full_name='envoy.config.route.v4alpha.RouteConfiguration.max_direct_response_body_size_bytes', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.config.route.v3.RouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=1035,
)


_VHDS = _descriptor.Descriptor(
  name='Vhds',
  full_name='envoy.config.route.v4alpha.Vhds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_source', full_name='envoy.config.route.v4alpha.Vhds.config_source', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\034\n\032envoy.config.route.v3.Vhds',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1152,
)

_ROUTECONFIGURATION.fields_by_name['virtual_hosts'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._VIRTUALHOST
_ROUTECONFIGURATION.fields_by_name['vhds'].message_type = _VHDS
_ROUTECONFIGURATION.fields_by_name['response_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTECONFIGURATION.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._HEADERVALUEOPTION
_ROUTECONFIGURATION.fields_by_name['validate_clusters'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ROUTECONFIGURATION.fields_by_name['max_direct_response_body_size_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_VHDS.fields_by_name['config_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_config__source__pb2._CONFIGSOURCE
DESCRIPTOR.message_types_by_name['RouteConfiguration'] = _ROUTECONFIGURATION
DESCRIPTOR.message_types_by_name['Vhds'] = _VHDS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RouteConfiguration = _reflection.GeneratedProtocolMessageType('RouteConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROUTECONFIGURATION,
  '__module__' : 'envoy.config.route.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.RouteConfiguration)
  })
_sym_db.RegisterMessage(RouteConfiguration)

Vhds = _reflection.GeneratedProtocolMessageType('Vhds', (_message.Message,), {
  'DESCRIPTOR' : _VHDS,
  '__module__' : 'envoy.config.route.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.route.v4alpha.Vhds)
  })
_sym_db.RegisterMessage(Vhds)


DESCRIPTOR._options = None
_ROUTECONFIGURATION.fields_by_name['internal_only_headers']._options = None
_ROUTECONFIGURATION.fields_by_name['response_headers_to_add']._options = None
_ROUTECONFIGURATION.fields_by_name['response_headers_to_remove']._options = None
_ROUTECONFIGURATION.fields_by_name['request_headers_to_add']._options = None
_ROUTECONFIGURATION.fields_by_name['request_headers_to_remove']._options = None
_ROUTECONFIGURATION._options = None
_VHDS.fields_by_name['config_source']._options = None
_VHDS._options = None
# @@protoc_insertion_point(module_scope)
