# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/brotli/decompressor/v3/brotli.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/compression/brotli/decompressor/v3/brotli.proto',
  package='envoy.extensions.compression.brotli.decompressor.v3',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\013BrotliProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/compression/brotli/decompressor/v3/brotli.proto\x12\x33\x65nvoy.extensions.compression.brotli.decompressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"r\n\x06\x42rotli\x12(\n disable_ring_buffer_reallocation\x18\x01 \x01(\x08\x12>\n\nchunk_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 BZ\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\x0b\x42rotliProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BROTLI = _descriptor.Descriptor(
  name='Brotli',
  full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disable_ring_buffer_reallocation', full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli.disable_ring_buffer_reallocation', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.compression.brotli.decompressor.v3.Brotli.chunk_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=323,
)

_BROTLI.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Brotli'] = _BROTLI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Brotli = _reflection.GeneratedProtocolMessageType('Brotli', (_message.Message,), {
  'DESCRIPTOR' : _BROTLI,
  '__module__' : 'envoy.extensions.compression.brotli.decompressor.v3.brotli_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.compression.brotli.decompressor.v3.Brotli)
  })
_sym_db.RegisterMessage(Brotli)


DESCRIPTOR._options = None
_BROTLI.fields_by_name['chunk_size']._options = None
# @@protoc_insertion_point(module_scope)
