# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.rocketmq_proxy.v4alpha import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto',
  package='envoy.extensions.filters.network.rocketmq_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\022RocketmqProxyProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nLenvoy/extensions/filters/network/rocketmq_proxy/v4alpha/rocketmq_proxy.proto\x12\x37\x65nvoy.extensions.filters.network.rocketmq_proxy.v4alpha\x1a\x43\x65nvoy/extensions/filters/network/rocketmq_proxy/v4alpha/route.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xae\x02\n\rRocketmqProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x61\n\x0croute_config\x18\x02 \x01(\x0b\x32K.envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration\x12=\n\x1atransient_object_life_span\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x14\n\x0c\x64\x65velop_mode\x18\x04 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.network.rocketmq_proxy.v3.RocketmqProxyBe\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\x12RocketmqProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROCKETMQPROXY = _descriptor.Descriptor(
  name='RocketmqProxy',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.route_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transient_object_life_span', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.transient_object_life_span', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='develop_mode', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy.develop_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.network.rocketmq_proxy.v3.RocketmqProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=632,
)

_ROCKETMQPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_rocketmq__proxy_dot_v4alpha_dot_route__pb2._ROUTECONFIGURATION
_ROCKETMQPROXY.fields_by_name['transient_object_life_span'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['RocketmqProxy'] = _ROCKETMQPROXY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RocketmqProxy = _reflection.GeneratedProtocolMessageType('RocketmqProxy', (_message.Message,), {
  'DESCRIPTOR' : _ROCKETMQPROXY,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.rocketmq_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RocketmqProxy)
  })
_sym_db.RegisterMessage(RocketmqProxy)


DESCRIPTOR._options = None
_ROCKETMQPROXY.fields_by_name['stat_prefix']._options = None
_ROCKETMQPROXY._options = None
# @@protoc_insertion_point(module_scope)
