# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/context_params.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xds/core/v3/context_params.proto',
  package='xds.core.v3',
  syntax='proto3',
  serialized_options=b'\n\033com.github.udpa.xds.core.v3B\022ContextParamsProtoP\001\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n xds/core/v3/context_params.proto\x12\x0bxds.core.v3\x1a\x1dudpa/annotations/status.proto\"v\n\rContextParams\x12\x36\n\x06params\x18\x01 \x03(\x0b\x32&.xds.core.v3.ContextParams.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42;\n\x1b\x63om.github.udpa.xds.core.v3B\x12\x43ontextParamsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_CONTEXTPARAMS_PARAMSENTRY = _descriptor.Descriptor(
  name='ParamsEntry',
  full_name='xds.core.v3.ContextParams.ParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='xds.core.v3.ContextParams.ParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='xds.core.v3.ContextParams.ParamsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=198,
)

_CONTEXTPARAMS = _descriptor.Descriptor(
  name='ContextParams',
  full_name='xds.core.v3.ContextParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='xds.core.v3.ContextParams.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTEXTPARAMS_PARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=198,
)

_CONTEXTPARAMS_PARAMSENTRY.containing_type = _CONTEXTPARAMS
_CONTEXTPARAMS.fields_by_name['params'].message_type = _CONTEXTPARAMS_PARAMSENTRY
DESCRIPTOR.message_types_by_name['ContextParams'] = _CONTEXTPARAMS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContextParams = _reflection.GeneratedProtocolMessageType('ContextParams', (_message.Message,), {

  'ParamsEntry' : _reflection.GeneratedProtocolMessageType('ParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTEXTPARAMS_PARAMSENTRY,
    '__module__' : 'xds.core.v3.context_params_pb2'
    # @@protoc_insertion_point(class_scope:xds.core.v3.ContextParams.ParamsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTEXTPARAMS,
  '__module__' : 'xds.core.v3.context_params_pb2'
  # @@protoc_insertion_point(class_scope:xds.core.v3.ContextParams)
  })
_sym_db.RegisterMessage(ContextParams)
_sym_db.RegisterMessage(ContextParams.ParamsEntry)


DESCRIPTOR._options = None
_CONTEXTPARAMS_PARAMSENTRY._options = None
# @@protoc_insertion_point(module_scope)
