# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto',
  package='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha',
  syntax='proto3',
  serialized_options=b'\nPio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alphaB\033SniDynamicForwardProxyProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nbenvoy/extensions/filters/network/sni_dynamic_forward_proxy/v3alpha/sni_dynamic_forward_proxy.proto\x12\x42\x65nvoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa9\x01\n\x0c\x46ilterConfig\x12\x64\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12!\n\nport_value\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00H\x00\x42\x10\n\x0eport_specifierB\x81\x01\nPio.envoyproxy.envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alphaB\x1bSniDynamicForwardProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_cache_config', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.dns_cache_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.port_value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010*\006\030\377\377\003 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='port_specifier', full_name='envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig.port_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=293,
  serialized_end=462,
)

_FILTERCONFIG.fields_by_name['dns_cache_config'].message_type = envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2._DNSCACHECONFIG
_FILTERCONFIG.oneofs_by_name['port_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['port_value'])
_FILTERCONFIG.fields_by_name['port_value'].containing_oneof = _FILTERCONFIG.oneofs_by_name['port_specifier']
DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.sni_dynamic_forward_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.sni_dynamic_forward_proxy.v3alpha.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)


DESCRIPTOR._options = None
_FILTERCONFIG.fields_by_name['dns_cache_config']._options = None
_FILTERCONFIG.fields_by_name['port_value']._options = None
# @@protoc_insertion_point(module_scope)
