# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto',
  package='envoy.extensions.filters.listener.proxy_protocol.v3',
  syntax='proto3',
  serialized_options=b'\nAio.envoyproxy.envoy.extensions.filters.listener.proxy_protocol.v3B\022ProxyProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHenvoy/extensions/filters/listener/proxy_protocol/v3/proxy_protocol.proto\x12\x33\x65nvoy.extensions.filters.listener.proxy_protocol.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x02\n\rProxyProtocol\x12V\n\x05rules\x18\x01 \x03(\x0b\x32G.envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule\x1a@\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x8b\x01\n\x04Rule\x12\x1a\n\x08tlv_type\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x10\x80\x02\x12g\n\x0eon_tlv_present\x18\x02 \x01(\x0b\x32O.envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.listener.proxy_protocol.v2.ProxyProtocolBa\nAio.envoyproxy.envoy.extensions.filters.listener.proxy_protocol.v3B\x12ProxyProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PROXYPROTOCOL_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_namespace', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair.metadata_namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=390,
)

_PROXYPROTOCOL_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tlv_type', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule.tlv_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\020\200\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_tlv_present', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule.on_tlv_present', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=532,
)

_PROXYPROTOCOL = _descriptor.Descriptor(
  name='ProxyProtocol',
  full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PROXYPROTOCOL_KEYVALUEPAIR, _PROXYPROTOCOL_RULE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.filter.listener.proxy_protocol.v2.ProxyProtocol',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=601,
)

_PROXYPROTOCOL_KEYVALUEPAIR.containing_type = _PROXYPROTOCOL
_PROXYPROTOCOL_RULE.fields_by_name['on_tlv_present'].message_type = _PROXYPROTOCOL_KEYVALUEPAIR
_PROXYPROTOCOL_RULE.containing_type = _PROXYPROTOCOL
_PROXYPROTOCOL.fields_by_name['rules'].message_type = _PROXYPROTOCOL_RULE
DESCRIPTOR.message_types_by_name['ProxyProtocol'] = _PROXYPROTOCOL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProxyProtocol = _reflection.GeneratedProtocolMessageType('ProxyProtocol', (_message.Message,), {

  'KeyValuePair' : _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
    'DESCRIPTOR' : _PROXYPROTOCOL_KEYVALUEPAIR,
    '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.KeyValuePair)
    })
  ,

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _PROXYPROTOCOL_RULE,
    '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol.Rule)
    })
  ,
  'DESCRIPTOR' : _PROXYPROTOCOL,
  '__module__' : 'envoy.extensions.filters.listener.proxy_protocol.v3.proxy_protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.listener.proxy_protocol.v3.ProxyProtocol)
  })
_sym_db.RegisterMessage(ProxyProtocol)
_sym_db.RegisterMessage(ProxyProtocol.KeyValuePair)
_sym_db.RegisterMessage(ProxyProtocol.Rule)


DESCRIPTOR._options = None
_PROXYPROTOCOL_KEYVALUEPAIR.fields_by_name['key']._options = None
_PROXYPROTOCOL_RULE.fields_by_name['tlv_type']._options = None
_PROXYPROTOCOL._options = None
# @@protoc_insertion_point(module_scope)
