# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto',
  package='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3',
  syntax='proto3',
  serialized_options=b'\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\013ConfigProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto\x12:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9c\x01\n\x0c\x46ilterConfig\x12\x1d\n\x0c\x63ontent_type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14withhold_grpc_frames\x18\x02 \x01(\x08:O\x9a\xc5\x88\x1eJ\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig\"\x81\x01\n\x14\x46ilterConfigPerRoute\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08:W\x9a\xc5\x88\x1eR\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRouteBa\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\x0b\x43onfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.content_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withhold_grpc_frames', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig.withhold_grpc_frames', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036J\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=383,
)


_FILTERCONFIGPERROUTE = _descriptor.Descriptor(
  name='FilterConfigPerRoute',
  full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036R\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=515,
)

DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
DESCRIPTOR.message_types_by_name['FilterConfigPerRoute'] = _FILTERCONFIGPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)

FilterConfigPerRoute = _reflection.GeneratedProtocolMessageType('FilterConfigPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIGPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.FilterConfigPerRoute)
  })
_sym_db.RegisterMessage(FilterConfigPerRoute)


DESCRIPTOR._options = None
_FILTERCONFIG.fields_by_name['content_type']._options = None
_FILTERCONFIG._options = None
_FILTERCONFIGPERROUTE._options = None
# @@protoc_insertion_point(module_scope)
