# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/buffer/v3/buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/buffer/v3/buffer.proto',
  package='envoy.extensions.filters.http.buffer.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\013BufferProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/buffer/v3/buffer.proto\x12\'envoy.extensions.filters.http.buffer.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8a\x01\n\x06\x42uffer\x12H\n\x11max_request_bytes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x04*\x02 \x00\xfa\x42\x05\x8a\x01\x02\x10\x01:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.buffer.v2.BufferJ\x04\x08\x02\x10\x03\"\xc5\x01\n\x0e\x42ufferPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\x06\x62uffer\x18\x02 \x01(\x0b\x32/.envoy.extensions.filters.http.buffer.v3.BufferB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.buffer.v2.BufferPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\x42N\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\x0b\x42ufferProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BUFFER = _descriptor.Descriptor(
  name='Buffer',
  full_name='envoy.extensions.filters.http.buffer.v3.Buffer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.extensions.filters.http.buffer.v3.Buffer.max_request_bytes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.buffer.v2.Buffer',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=359,
)


_BUFFERPERROUTE = _descriptor.Descriptor(
  name='BufferPerRoute',
  full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.buffer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.filter.http.buffer.v2.BufferPerRoute',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.buffer.v3.BufferPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=362,
  serialized_end=559,
)

_BUFFER.fields_by_name['max_request_bytes'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BUFFERPERROUTE.fields_by_name['buffer'].message_type = _BUFFER
_BUFFERPERROUTE.oneofs_by_name['override'].fields.append(
  _BUFFERPERROUTE.fields_by_name['disabled'])
_BUFFERPERROUTE.fields_by_name['disabled'].containing_oneof = _BUFFERPERROUTE.oneofs_by_name['override']
_BUFFERPERROUTE.oneofs_by_name['override'].fields.append(
  _BUFFERPERROUTE.fields_by_name['buffer'])
_BUFFERPERROUTE.fields_by_name['buffer'].containing_oneof = _BUFFERPERROUTE.oneofs_by_name['override']
DESCRIPTOR.message_types_by_name['Buffer'] = _BUFFER
DESCRIPTOR.message_types_by_name['BufferPerRoute'] = _BUFFERPERROUTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Buffer = _reflection.GeneratedProtocolMessageType('Buffer', (_message.Message,), {
  'DESCRIPTOR' : _BUFFER,
  '__module__' : 'envoy.extensions.filters.http.buffer.v3.buffer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.buffer.v3.Buffer)
  })
_sym_db.RegisterMessage(Buffer)

BufferPerRoute = _reflection.GeneratedProtocolMessageType('BufferPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.buffer.v3.buffer_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.buffer.v3.BufferPerRoute)
  })
_sym_db.RegisterMessage(BufferPerRoute)


DESCRIPTOR._options = None
_BUFFER.fields_by_name['max_request_bytes']._options = None
_BUFFER._options = None
_BUFFERPERROUTE.oneofs_by_name['override']._options = None
_BUFFERPERROUTE.fields_by_name['disabled']._options = None
_BUFFERPERROUTE.fields_by_name['buffer']._options = None
_BUFFERPERROUTE._options = None
# @@protoc_insertion_point(module_scope)
