# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/ext_proc/v3alpha/external_processor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.extensions.filters.http.ext_proc.v3alpha import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/ext_proc/v3alpha/external_processor.proto',
  package='envoy.service.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n,io.envoyproxy.envoy.service.ext_proc.v3alphaB\026ExternalProcessorProtoP\001\210\001\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/service/ext_proc/v3alpha/external_processor.proto\x12\x1e\x65nvoy.service.ext_proc.v3alpha\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x44\x65nvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe2\x03\n\x11ProcessingRequest\x12\x12\n\nasync_mode\x18\x01 \x01(\x08\x12\x46\n\x0frequest_headers\x18\x02 \x01(\x0b\x32+.envoy.service.ext_proc.v3alpha.HttpHeadersH\x00\x12G\n\x10response_headers\x18\x03 \x01(\x0b\x32+.envoy.service.ext_proc.v3alpha.HttpHeadersH\x00\x12@\n\x0crequest_body\x18\x04 \x01(\x0b\x32(.envoy.service.ext_proc.v3alpha.HttpBodyH\x00\x12\x41\n\rresponse_body\x18\x05 \x01(\x0b\x32(.envoy.service.ext_proc.v3alpha.HttpBodyH\x00\x12H\n\x10request_trailers\x18\x06 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.HttpTrailersH\x00\x12I\n\x11response_trailers\x18\x07 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.HttpTrailersH\x00\x42\x0e\n\x07request\x12\x03\xf8\x42\x01\"\xc3\x05\n\x12ProcessingResponse\x12J\n\x0frequest_headers\x18\x01 \x01(\x0b\x32/.envoy.service.ext_proc.v3alpha.HeadersResponseH\x00\x12K\n\x10response_headers\x18\x02 \x01(\x0b\x32/.envoy.service.ext_proc.v3alpha.HeadersResponseH\x00\x12\x44\n\x0crequest_body\x18\x03 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyResponseH\x00\x12\x45\n\rresponse_body\x18\x04 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyResponseH\x00\x12L\n\x10request_trailers\x18\x05 \x01(\x0b\x32\x30.envoy.service.ext_proc.v3alpha.TrailersResponseH\x00\x12M\n\x11response_trailers\x18\x06 \x01(\x0b\x32\x30.envoy.service.ext_proc.v3alpha.TrailersResponseH\x00\x12O\n\x12immediate_response\x18\x07 \x01(\x0b\x32\x31.envoy.service.ext_proc.v3alpha.ImmediateResponseH\x00\x12\x31\n\x10\x64ynamic_metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12U\n\rmode_override\x18\t \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingModeB\x0f\n\x08response\x12\x03\xf8\x42\x01\"\xf3\x01\n\x0bHttpHeaders\x12\x30\n\x07headers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12O\n\nattributes\x18\x02 \x03(\x0b\x32;.envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry\x12\x15\n\rend_of_stream\x18\x03 \x01(\x08\x1aJ\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:\x02\x38\x01\"/\n\x08HttpBody\x12\x0c\n\x04\x62ody\x18\x01 \x01(\x0c\x12\x15\n\rend_of_stream\x18\x02 \x01(\x08\"A\n\x0cHttpTrailers\x12\x31\n\x08trailers\x18\x01 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\"S\n\x0fHeadersResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.CommonResponse\"[\n\x10TrailersResponse\x12G\n\x0fheader_mutation\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\"P\n\x0c\x42odyResponse\x12@\n\x08response\x18\x01 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.CommonResponse\"\xff\x02\n\x0e\x43ommonResponse\x12W\n\x06status\x18\x01 \x01(\x0e\x32=.envoy.service.ext_proc.v3alpha.CommonResponse.ResponseStatusB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12G\n\x0fheader_mutation\x18\x02 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\x12\x43\n\rbody_mutation\x18\x03 \x01(\x0b\x32,.envoy.service.ext_proc.v3alpha.BodyMutation\x12\x31\n\x08trailers\x18\x04 \x01(\x0b\x32\x1f.envoy.config.core.v3.HeaderMap\x12\x19\n\x11\x63lear_route_cache\x18\x05 \x01(\x08\"8\n\x0eResponseStatus\x12\x0c\n\x08\x43ONTINUE\x10\x00\x12\x18\n\x14\x43ONTINUE_AND_REPLACE\x10\x01\"\xe9\x01\n\x11ImmediateResponse\x12\x33\n\x06status\x18\x01 \x01(\x0b\x32\x19.envoy.type.v3.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12?\n\x07headers\x18\x02 \x01(\x0b\x32..envoy.service.ext_proc.v3alpha.HeaderMutation\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12?\n\x0bgrpc_status\x18\x04 \x01(\x0b\x32*.envoy.service.ext_proc.v3alpha.GrpcStatus\x12\x0f\n\x07\x64\x65tails\x18\x05 \x01(\t\"\x1c\n\nGrpcStatus\x12\x0e\n\x06status\x18\x01 \x01(\r\"f\n\x0eHeaderMutation\x12<\n\x0bset_headers\x18\x01 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOption\x12\x16\n\x0eremove_headers\x18\x02 \x03(\t\"@\n\x0c\x42odyMutation\x12\x0e\n\x04\x62ody\x18\x01 \x01(\x0cH\x00\x12\x14\n\nclear_body\x18\x02 \x01(\x08H\x00\x42\n\n\x08mutation2\x8b\x01\n\x11\x45xternalProcessor\x12v\n\x07Process\x12\x31.envoy.service.ext_proc.v3alpha.ProcessingRequest\x1a\x32.envoy.service.ext_proc.v3alpha.ProcessingResponse\"\x00(\x01\x30\x01\x42[\n,io.envoyproxy.envoy.service.ext_proc.v3alphaB\x16\x45xternalProcessorProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_COMMONRESPONSE_RESPONSESTATUS = _descriptor.EnumDescriptor(
  name='ResponseStatus',
  full_name='envoy.service.ext_proc.v3alpha.CommonResponse.ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTINUE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTINUE_AND_REPLACE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2458,
  serialized_end=2514,
)
_sym_db.RegisterEnumDescriptor(_COMMONRESPONSE_RESPONSESTATUS)


_PROCESSINGREQUEST = _descriptor.Descriptor(
  name='ProcessingRequest',
  full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.async_mode', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_headers', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request_trailers', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.response_trailers', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='envoy.service.ext_proc.v3alpha.ProcessingRequest.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=314,
  serialized_end=796,
)


_PROCESSINGRESPONSE = _descriptor.Descriptor(
  name='ProcessingResponse',
  full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_body', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.request_trailers', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_trailers', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response_trailers', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='immediate_response', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.immediate_response', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_metadata', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.dynamic_metadata', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode_override', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.mode_override', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.ProcessingResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=799,
  serialized_end=1506,
)


_HTTPHEADERS_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1752,
)

_HTTPHEADERS = _descriptor.Descriptor(
  name='HttpHeaders',
  full_name='envoy.service.ext_proc.v3alpha.HttpHeaders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_of_stream', full_name='envoy.service.ext_proc.v3alpha.HttpHeaders.end_of_stream', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPHEADERS_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1509,
  serialized_end=1752,
)


_HTTPBODY = _descriptor.Descriptor(
  name='HttpBody',
  full_name='envoy.service.ext_proc.v3alpha.HttpBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.HttpBody.body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_of_stream', full_name='envoy.service.ext_proc.v3alpha.HttpBody.end_of_stream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1754,
  serialized_end=1801,
)


_HTTPTRAILERS = _descriptor.Descriptor(
  name='HttpTrailers',
  full_name='envoy.service.ext_proc.v3alpha.HttpTrailers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.service.ext_proc.v3alpha.HttpTrailers.trailers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1803,
  serialized_end=1868,
)


_HEADERSRESPONSE = _descriptor.Descriptor(
  name='HeadersResponse',
  full_name='envoy.service.ext_proc.v3alpha.HeadersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.HeadersResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1953,
)


_TRAILERSRESPONSE = _descriptor.Descriptor(
  name='TrailersResponse',
  full_name='envoy.service.ext_proc.v3alpha.TrailersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header_mutation', full_name='envoy.service.ext_proc.v3alpha.TrailersResponse.header_mutation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2046,
)


_BODYRESPONSE = _descriptor.Descriptor(
  name='BodyResponse',
  full_name='envoy.service.ext_proc.v3alpha.BodyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='envoy.service.ext_proc.v3alpha.BodyResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2048,
  serialized_end=2128,
)


_COMMONRESPONSE = _descriptor.Descriptor(
  name='CommonResponse',
  full_name='envoy.service.ext_proc.v3alpha.CommonResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_mutation', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.header_mutation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body_mutation', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.body_mutation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trailers', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.trailers', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.service.ext_proc.v3alpha.CommonResponse.clear_route_cache', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMMONRESPONSE_RESPONSESTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2131,
  serialized_end=2514,
)


_IMMEDIATERESPONSE = _descriptor.Descriptor(
  name='ImmediateResponse',
  full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.body', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_status', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.grpc_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='envoy.service.ext_proc.v3alpha.ImmediateResponse.details', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2517,
  serialized_end=2750,
)


_GRPCSTATUS = _descriptor.Descriptor(
  name='GrpcStatus',
  full_name='envoy.service.ext_proc.v3alpha.GrpcStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.ext_proc.v3alpha.GrpcStatus.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2752,
  serialized_end=2780,
)


_HEADERMUTATION = _descriptor.Descriptor(
  name='HeaderMutation',
  full_name='envoy.service.ext_proc.v3alpha.HeaderMutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_headers', full_name='envoy.service.ext_proc.v3alpha.HeaderMutation.set_headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_headers', full_name='envoy.service.ext_proc.v3alpha.HeaderMutation.remove_headers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2782,
  serialized_end=2884,
)


_BODYMUTATION = _descriptor.Descriptor(
  name='BodyMutation',
  full_name='envoy.service.ext_proc.v3alpha.BodyMutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.body', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_body', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.clear_body', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mutation', full_name='envoy.service.ext_proc.v3alpha.BodyMutation.mutation',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2886,
  serialized_end=2950,
)

_PROCESSINGREQUEST.fields_by_name['request_headers'].message_type = _HTTPHEADERS
_PROCESSINGREQUEST.fields_by_name['response_headers'].message_type = _HTTPHEADERS
_PROCESSINGREQUEST.fields_by_name['request_body'].message_type = _HTTPBODY
_PROCESSINGREQUEST.fields_by_name['response_body'].message_type = _HTTPBODY
_PROCESSINGREQUEST.fields_by_name['request_trailers'].message_type = _HTTPTRAILERS
_PROCESSINGREQUEST.fields_by_name['response_trailers'].message_type = _HTTPTRAILERS
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_headers'])
_PROCESSINGREQUEST.fields_by_name['request_headers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_headers'])
_PROCESSINGREQUEST.fields_by_name['response_headers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_body'])
_PROCESSINGREQUEST.fields_by_name['request_body'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_body'])
_PROCESSINGREQUEST.fields_by_name['response_body'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['request_trailers'])
_PROCESSINGREQUEST.fields_by_name['request_trailers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGREQUEST.oneofs_by_name['request'].fields.append(
  _PROCESSINGREQUEST.fields_by_name['response_trailers'])
_PROCESSINGREQUEST.fields_by_name['response_trailers'].containing_oneof = _PROCESSINGREQUEST.oneofs_by_name['request']
_PROCESSINGRESPONSE.fields_by_name['request_headers'].message_type = _HEADERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_headers'].message_type = _HEADERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['request_body'].message_type = _BODYRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_body'].message_type = _BODYRESPONSE
_PROCESSINGRESPONSE.fields_by_name['request_trailers'].message_type = _TRAILERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['response_trailers'].message_type = _TRAILERSRESPONSE
_PROCESSINGRESPONSE.fields_by_name['immediate_response'].message_type = _IMMEDIATERESPONSE
_PROCESSINGRESPONSE.fields_by_name['dynamic_metadata'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PROCESSINGRESPONSE.fields_by_name['mode_override'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_headers'])
_PROCESSINGRESPONSE.fields_by_name['request_headers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_headers'])
_PROCESSINGRESPONSE.fields_by_name['response_headers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_body'])
_PROCESSINGRESPONSE.fields_by_name['request_body'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_body'])
_PROCESSINGRESPONSE.fields_by_name['response_body'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['request_trailers'])
_PROCESSINGRESPONSE.fields_by_name['request_trailers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['response_trailers'])
_PROCESSINGRESPONSE.fields_by_name['response_trailers'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_PROCESSINGRESPONSE.oneofs_by_name['response'].fields.append(
  _PROCESSINGRESPONSE.fields_by_name['immediate_response'])
_PROCESSINGRESPONSE.fields_by_name['immediate_response'].containing_oneof = _PROCESSINGRESPONSE.oneofs_by_name['response']
_HTTPHEADERS_ATTRIBUTESENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_HTTPHEADERS_ATTRIBUTESENTRY.containing_type = _HTTPHEADERS
_HTTPHEADERS.fields_by_name['headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HTTPHEADERS.fields_by_name['attributes'].message_type = _HTTPHEADERS_ATTRIBUTESENTRY
_HTTPTRAILERS.fields_by_name['trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_HEADERSRESPONSE.fields_by_name['response'].message_type = _COMMONRESPONSE
_TRAILERSRESPONSE.fields_by_name['header_mutation'].message_type = _HEADERMUTATION
_BODYRESPONSE.fields_by_name['response'].message_type = _COMMONRESPONSE
_COMMONRESPONSE.fields_by_name['status'].enum_type = _COMMONRESPONSE_RESPONSESTATUS
_COMMONRESPONSE.fields_by_name['header_mutation'].message_type = _HEADERMUTATION
_COMMONRESPONSE.fields_by_name['body_mutation'].message_type = _BODYMUTATION
_COMMONRESPONSE.fields_by_name['trailers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERMAP
_COMMONRESPONSE_RESPONSESTATUS.containing_type = _COMMONRESPONSE
_IMMEDIATERESPONSE.fields_by_name['status'].message_type = envoy_dot_type_dot_v3_dot_http__status__pb2._HTTPSTATUS
_IMMEDIATERESPONSE.fields_by_name['headers'].message_type = _HEADERMUTATION
_IMMEDIATERESPONSE.fields_by_name['grpc_status'].message_type = _GRPCSTATUS
_HEADERMUTATION.fields_by_name['set_headers'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_BODYMUTATION.oneofs_by_name['mutation'].fields.append(
  _BODYMUTATION.fields_by_name['body'])
_BODYMUTATION.fields_by_name['body'].containing_oneof = _BODYMUTATION.oneofs_by_name['mutation']
_BODYMUTATION.oneofs_by_name['mutation'].fields.append(
  _BODYMUTATION.fields_by_name['clear_body'])
_BODYMUTATION.fields_by_name['clear_body'].containing_oneof = _BODYMUTATION.oneofs_by_name['mutation']
DESCRIPTOR.message_types_by_name['ProcessingRequest'] = _PROCESSINGREQUEST
DESCRIPTOR.message_types_by_name['ProcessingResponse'] = _PROCESSINGRESPONSE
DESCRIPTOR.message_types_by_name['HttpHeaders'] = _HTTPHEADERS
DESCRIPTOR.message_types_by_name['HttpBody'] = _HTTPBODY
DESCRIPTOR.message_types_by_name['HttpTrailers'] = _HTTPTRAILERS
DESCRIPTOR.message_types_by_name['HeadersResponse'] = _HEADERSRESPONSE
DESCRIPTOR.message_types_by_name['TrailersResponse'] = _TRAILERSRESPONSE
DESCRIPTOR.message_types_by_name['BodyResponse'] = _BODYRESPONSE
DESCRIPTOR.message_types_by_name['CommonResponse'] = _COMMONRESPONSE
DESCRIPTOR.message_types_by_name['ImmediateResponse'] = _IMMEDIATERESPONSE
DESCRIPTOR.message_types_by_name['GrpcStatus'] = _GRPCSTATUS
DESCRIPTOR.message_types_by_name['HeaderMutation'] = _HEADERMUTATION
DESCRIPTOR.message_types_by_name['BodyMutation'] = _BODYMUTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessingRequest = _reflection.GeneratedProtocolMessageType('ProcessingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGREQUEST,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ProcessingRequest)
  })
_sym_db.RegisterMessage(ProcessingRequest)

ProcessingResponse = _reflection.GeneratedProtocolMessageType('ProcessingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSINGRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ProcessingResponse)
  })
_sym_db.RegisterMessage(ProcessingResponse)

HttpHeaders = _reflection.GeneratedProtocolMessageType('HttpHeaders', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HTTPHEADERS_ATTRIBUTESENTRY,
    '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpHeaders.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _HTTPHEADERS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpHeaders)
  })
_sym_db.RegisterMessage(HttpHeaders)
_sym_db.RegisterMessage(HttpHeaders.AttributesEntry)

HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)

HttpTrailers = _reflection.GeneratedProtocolMessageType('HttpTrailers', (_message.Message,), {
  'DESCRIPTOR' : _HTTPTRAILERS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HttpTrailers)
  })
_sym_db.RegisterMessage(HttpTrailers)

HeadersResponse = _reflection.GeneratedProtocolMessageType('HeadersResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEADERSRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HeadersResponse)
  })
_sym_db.RegisterMessage(HeadersResponse)

TrailersResponse = _reflection.GeneratedProtocolMessageType('TrailersResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRAILERSRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.TrailersResponse)
  })
_sym_db.RegisterMessage(TrailersResponse)

BodyResponse = _reflection.GeneratedProtocolMessageType('BodyResponse', (_message.Message,), {
  'DESCRIPTOR' : _BODYRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.BodyResponse)
  })
_sym_db.RegisterMessage(BodyResponse)

CommonResponse = _reflection.GeneratedProtocolMessageType('CommonResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMONRESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.CommonResponse)
  })
_sym_db.RegisterMessage(CommonResponse)

ImmediateResponse = _reflection.GeneratedProtocolMessageType('ImmediateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMMEDIATERESPONSE,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.ImmediateResponse)
  })
_sym_db.RegisterMessage(ImmediateResponse)

GrpcStatus = _reflection.GeneratedProtocolMessageType('GrpcStatus', (_message.Message,), {
  'DESCRIPTOR' : _GRPCSTATUS,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.GrpcStatus)
  })
_sym_db.RegisterMessage(GrpcStatus)

HeaderMutation = _reflection.GeneratedProtocolMessageType('HeaderMutation', (_message.Message,), {
  'DESCRIPTOR' : _HEADERMUTATION,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.HeaderMutation)
  })
_sym_db.RegisterMessage(HeaderMutation)

BodyMutation = _reflection.GeneratedProtocolMessageType('BodyMutation', (_message.Message,), {
  'DESCRIPTOR' : _BODYMUTATION,
  '__module__' : 'envoy.service.ext_proc.v3alpha.external_processor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.ext_proc.v3alpha.BodyMutation)
  })
_sym_db.RegisterMessage(BodyMutation)


DESCRIPTOR._options = None
_PROCESSINGREQUEST.oneofs_by_name['request']._options = None
_PROCESSINGRESPONSE.oneofs_by_name['response']._options = None
_HTTPHEADERS_ATTRIBUTESENTRY._options = None
_COMMONRESPONSE.fields_by_name['status']._options = None
_IMMEDIATERESPONSE.fields_by_name['status']._options = None

_EXTERNALPROCESSOR = _descriptor.ServiceDescriptor(
  name='ExternalProcessor',
  full_name='envoy.service.ext_proc.v3alpha.ExternalProcessor',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2953,
  serialized_end=3092,
  methods=[
  _descriptor.MethodDescriptor(
    name='Process',
    full_name='envoy.service.ext_proc.v3alpha.ExternalProcessor.Process',
    index=0,
    containing_service=None,
    input_type=_PROCESSINGREQUEST,
    output_type=_PROCESSINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALPROCESSOR)

DESCRIPTOR.services_by_name['ExternalProcessor'] = _EXTERNALPROCESSOR

# @@protoc_insertion_point(module_scope)
