# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/squash/v3/squash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/squash/v3/squash.proto',
  package='envoy.extensions.filters.http.squash.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.filters.http.squash.v3B\013SquashProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/filters/http/squash/v3/squash.proto\x12\'envoy.extensions.filters.http.squash.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x06Squash\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x13\x61ttachment_template\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x0frequest_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12\x61ttachment_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x16\x61ttachment_poll_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.squash.v2.SquashBN\n5io.envoyproxy.envoy.extensions.filters.http.squash.v3B\x0bSquashProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SQUASH = _descriptor.Descriptor(
  name='Squash',
  full_name='envoy.extensions.filters.http.squash.v3.Squash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.http.squash.v3.Squash.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_template', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_timeout', full_name='envoy.extensions.filters.http.squash.v3.Squash.request_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_timeout', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_timeout', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachment_poll_period', full_name='envoy.extensions.filters.http.squash.v3.Squash.attachment_poll_period', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.config.filter.http.squash.v2.Squash',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=555,
)

_SQUASH.fields_by_name['attachment_template'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SQUASH.fields_by_name['request_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SQUASH.fields_by_name['attachment_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SQUASH.fields_by_name['attachment_poll_period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['Squash'] = _SQUASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Squash = _reflection.GeneratedProtocolMessageType('Squash', (_message.Message,), {
  'DESCRIPTOR' : _SQUASH,
  '__module__' : 'envoy.extensions.filters.http.squash.v3.squash_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.squash.v3.Squash)
  })
_sym_db.RegisterMessage(Squash)


DESCRIPTOR._options = None
_SQUASH.fields_by_name['cluster']._options = None
_SQUASH._options = None
# @@protoc_insertion_point(module_scope)
