# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.thrift_proxy.v3 import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto',
  package='envoy.extensions.filters.network.thrift_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\020ThriftProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x03\n\x0bThriftProxy\x12\\\n\ttransport\x18\x02 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x03 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12Z\n\x0croute_config\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.filters.network.thrift_proxy.v3.RouteConfiguration\x12V\n\x0ethrift_filters\x18\x05 \x03(\x0b\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter\x12\x1b\n\x13payload_passthrough\x18\x06 \x01(\x08:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy\"\xb7\x01\n\x0cThriftFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:E\x9a\xc5\x88\x1e@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xa1\x02\n\x15ThriftProtocolOptions\x12\\\n\ttransport\x18\x01 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x02 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:N\x9a\xc5\x88\x1eI\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions*I\n\rTransportType\x12\x12\n\x0e\x41UTO_TRANSPORT\x10\x00\x12\n\n\x06\x46RAMED\x10\x01\x12\x0c\n\x08UNFRAMED\x10\x02\x12\n\n\x06HEADER\x10\x03*W\n\x0cProtocolType\x12\x11\n\rAUTO_PROTOCOL\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x0e\n\nLAX_BINARY\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x12\x0b\n\x07TWITTER\x10\x04\x42\\\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\x10ThriftProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_TRANSPORTTYPE = _descriptor.EnumDescriptor(
  name='TransportType',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.TransportType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_TRANSPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRAMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNFRAMED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1290,
  serialized_end=1363,
)
_sym_db.RegisterEnumDescriptor(_TRANSPORTTYPE)

TransportType = enum_type_wrapper.EnumTypeWrapper(_TRANSPORTTYPE)
_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AUTO_PROTOCOL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAX_BINARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPACT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TWITTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1365,
  serialized_end=1452,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOLTYPE)

ProtocolType = enum_type_wrapper.EnumTypeWrapper(_PROTOCOLTYPE)
AUTO_TRANSPORT = 0
FRAMED = 1
UNFRAMED = 2
HEADER = 3
AUTO_PROTOCOL = 0
BINARY = 1
LAX_BINARY = 2
COMPACT = 3
TWITTER = 4



_THRIFTPROXY = _descriptor.Descriptor(
  name='ThriftProxy',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.transport', index=0,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.protocol', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.stat_prefix', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.route_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thrift_filters', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.thrift_filters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_passthrough', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy.payload_passthrough', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=810,
)


_THRIFTFILTER = _descriptor.Descriptor(
  name='ThriftFilter',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=813,
  serialized_end=996,
)


_THRIFTPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='ThriftProtocolOptions',
  full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transport', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions.transport', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions.protocol', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=999,
  serialized_end=1288,
)

_THRIFTPROXY.fields_by_name['transport'].enum_type = _TRANSPORTTYPE
_THRIFTPROXY.fields_by_name['protocol'].enum_type = _PROTOCOLTYPE
_THRIFTPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2._ROUTECONFIGURATION
_THRIFTPROXY.fields_by_name['thrift_filters'].message_type = _THRIFTFILTER
_THRIFTFILTER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_THRIFTFILTER.oneofs_by_name['config_type'].fields.append(
  _THRIFTFILTER.fields_by_name['typed_config'])
_THRIFTFILTER.fields_by_name['typed_config'].containing_oneof = _THRIFTFILTER.oneofs_by_name['config_type']
_THRIFTPROTOCOLOPTIONS.fields_by_name['transport'].enum_type = _TRANSPORTTYPE
_THRIFTPROTOCOLOPTIONS.fields_by_name['protocol'].enum_type = _PROTOCOLTYPE
DESCRIPTOR.message_types_by_name['ThriftProxy'] = _THRIFTPROXY
DESCRIPTOR.message_types_by_name['ThriftFilter'] = _THRIFTFILTER
DESCRIPTOR.message_types_by_name['ThriftProtocolOptions'] = _THRIFTPROTOCOLOPTIONS
DESCRIPTOR.enum_types_by_name['TransportType'] = _TRANSPORTTYPE
DESCRIPTOR.enum_types_by_name['ProtocolType'] = _PROTOCOLTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ThriftProxy = _reflection.GeneratedProtocolMessageType('ThriftProxy', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTPROXY,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftProxy)
  })
_sym_db.RegisterMessage(ThriftProxy)

ThriftFilter = _reflection.GeneratedProtocolMessageType('ThriftFilter', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTFILTER,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter)
  })
_sym_db.RegisterMessage(ThriftFilter)

ThriftProtocolOptions = _reflection.GeneratedProtocolMessageType('ThriftProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _THRIFTPROTOCOLOPTIONS,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v3.ThriftProtocolOptions)
  })
_sym_db.RegisterMessage(ThriftProtocolOptions)


DESCRIPTOR._options = None
_THRIFTPROXY.fields_by_name['transport']._options = None
_THRIFTPROXY.fields_by_name['protocol']._options = None
_THRIFTPROXY.fields_by_name['stat_prefix']._options = None
_THRIFTPROXY._options = None
_THRIFTFILTER.fields_by_name['name']._options = None
_THRIFTFILTER._options = None
_THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._options = None
_THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._options = None
_THRIFTPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)
