# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/tracing/v2/custom_tag.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.metadata.v2 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/tracing/v2/custom_tag.proto',
  package='envoy.type.tracing.v2',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.type.tracing.v2B\016CustomTagProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/type/tracing/v2/custom_tag.proto\x12\x15\x65nvoy.type.tracing.v2\x1a%envoy/type/metadata/v2/metadata.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe3\x04\n\tCustomTag\x12\x14\n\x03tag\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12;\n\x07literal\x18\x02 \x01(\x0b\x32(.envoy.type.tracing.v2.CustomTag.LiteralH\x00\x12\x43\n\x0b\x65nvironment\x18\x03 \x01(\x0b\x32,.envoy.type.tracing.v2.CustomTag.EnvironmentH\x00\x12\x41\n\x0erequest_header\x18\x04 \x01(\x0b\x32\'.envoy.type.tracing.v2.CustomTag.HeaderH\x00\x12=\n\x08metadata\x18\x05 \x01(\x0b\x32).envoy.type.tracing.v2.CustomTag.MetadataH\x00\x1a!\n\x07Literal\x12\x16\n\x05value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a;\n\x0b\x45nvironment\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a<\n\x06Header\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08 \x01\xc0\x01\x01\xc8\x01\x00\x12\x15\n\rdefault_value\x18\x02 \x01(\t\x1a\x90\x01\n\x08Metadata\x12\x32\n\x04kind\x18\x01 \x01(\x0b\x32$.envoy.type.metadata.v2.MetadataKind\x12\x39\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v2.MetadataKey\x12\x15\n\rdefault_value\x18\x03 \x01(\tB\x0b\n\x04type\x12\x03\xf8\x42\x01\x42?\n#io.envoyproxy.envoy.type.tracing.v2B\x0e\x43ustomTagProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CUSTOMTAG_LITERAL = _descriptor.Descriptor(
  name='Literal',
  full_name='envoy.type.tracing.v2.CustomTag.Literal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.type.tracing.v2.CustomTag.Literal.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=489,
)

_CUSTOMTAG_ENVIRONMENT = _descriptor.Descriptor(
  name='Environment',
  full_name='envoy.type.tracing.v2.CustomTag.Environment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.type.tracing.v2.CustomTag.Environment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Environment.default_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=550,
)

_CUSTOMTAG_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='envoy.type.tracing.v2.CustomTag.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.type.tracing.v2.CustomTag.Header.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010 \001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Header.default_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=612,
)

_CUSTOMTAG_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='envoy.type.tracing.v2.CustomTag.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='envoy.type.tracing.v2.CustomTag.Metadata.kind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_key', full_name='envoy.type.tracing.v2.CustomTag.Metadata.metadata_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_value', full_name='envoy.type.tracing.v2.CustomTag.Metadata.default_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=759,
)

_CUSTOMTAG = _descriptor.Descriptor(
  name='CustomTag',
  full_name='envoy.type.tracing.v2.CustomTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='envoy.type.tracing.v2.CustomTag.tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='literal', full_name='envoy.type.tracing.v2.CustomTag.literal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='envoy.type.tracing.v2.CustomTag.environment', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_header', full_name='envoy.type.tracing.v2.CustomTag.request_header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.type.tracing.v2.CustomTag.metadata', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMTAG_LITERAL, _CUSTOMTAG_ENVIRONMENT, _CUSTOMTAG_HEADER, _CUSTOMTAG_METADATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type', full_name='envoy.type.tracing.v2.CustomTag.type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=161,
  serialized_end=772,
)

_CUSTOMTAG_LITERAL.containing_type = _CUSTOMTAG
_CUSTOMTAG_ENVIRONMENT.containing_type = _CUSTOMTAG
_CUSTOMTAG_HEADER.containing_type = _CUSTOMTAG
_CUSTOMTAG_METADATA.fields_by_name['kind'].message_type = envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2._METADATAKIND
_CUSTOMTAG_METADATA.fields_by_name['metadata_key'].message_type = envoy_dot_type_dot_metadata_dot_v2_dot_metadata__pb2._METADATAKEY
_CUSTOMTAG_METADATA.containing_type = _CUSTOMTAG
_CUSTOMTAG.fields_by_name['literal'].message_type = _CUSTOMTAG_LITERAL
_CUSTOMTAG.fields_by_name['environment'].message_type = _CUSTOMTAG_ENVIRONMENT
_CUSTOMTAG.fields_by_name['request_header'].message_type = _CUSTOMTAG_HEADER
_CUSTOMTAG.fields_by_name['metadata'].message_type = _CUSTOMTAG_METADATA
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['literal'])
_CUSTOMTAG.fields_by_name['literal'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['environment'])
_CUSTOMTAG.fields_by_name['environment'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['request_header'])
_CUSTOMTAG.fields_by_name['request_header'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
_CUSTOMTAG.oneofs_by_name['type'].fields.append(
  _CUSTOMTAG.fields_by_name['metadata'])
_CUSTOMTAG.fields_by_name['metadata'].containing_oneof = _CUSTOMTAG.oneofs_by_name['type']
DESCRIPTOR.message_types_by_name['CustomTag'] = _CUSTOMTAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomTag = _reflection.GeneratedProtocolMessageType('CustomTag', (_message.Message,), {

  'Literal' : _reflection.GeneratedProtocolMessageType('Literal', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_LITERAL,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Literal)
    })
  ,

  'Environment' : _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_ENVIRONMENT,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Environment)
    })
  ,

  'Header' : _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_HEADER,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Header)
    })
  ,

  'Metadata' : _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
    'DESCRIPTOR' : _CUSTOMTAG_METADATA,
    '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag.Metadata)
    })
  ,
  'DESCRIPTOR' : _CUSTOMTAG,
  '__module__' : 'envoy.type.tracing.v2.custom_tag_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.tracing.v2.CustomTag)
  })
_sym_db.RegisterMessage(CustomTag)
_sym_db.RegisterMessage(CustomTag.Literal)
_sym_db.RegisterMessage(CustomTag.Environment)
_sym_db.RegisterMessage(CustomTag.Header)
_sym_db.RegisterMessage(CustomTag.Metadata)


DESCRIPTOR._options = None
_CUSTOMTAG_LITERAL.fields_by_name['value']._options = None
_CUSTOMTAG_ENVIRONMENT.fields_by_name['name']._options = None
_CUSTOMTAG_HEADER.fields_by_name['name']._options = None
_CUSTOMTAG.oneofs_by_name['type']._options = None
_CUSTOMTAG.fields_by_name['tag']._options = None
# @@protoc_insertion_point(module_scope)
