# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v3/trace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.trace.v3 import datadog_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2
from envoy.config.trace.v3 import dynamic_ot_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2
from envoy.config.trace.v3 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2
from envoy.config.trace.v3 import lightstep_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2
from envoy.config.trace.v3 import opencensus_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2
from envoy.config.trace.v3 import service_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_service__pb2
from envoy.config.trace.v3 import zipkin_pb2 as envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2

from envoy.config.trace.v3.datadog_pb2 import *
from envoy.config.trace.v3.dynamic_ot_pb2 import *
from envoy.config.trace.v3.http_tracer_pb2 import *
from envoy.config.trace.v3.lightstep_pb2 import *
from envoy.config.trace.v3.opencensus_pb2 import *
from envoy.config.trace.v3.service_pb2 import *
from envoy.config.trace.v3.zipkin_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/trace/v3/trace.proto',
  package='envoy.config.trace.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.config.trace.v3B\nTraceProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!envoy/config/trace/v3/trace.proto\x12\x15\x65nvoy.config.trace.v3\x1a#envoy/config/trace/v3/datadog.proto\x1a&envoy/config/trace/v3/dynamic_ot.proto\x1a\'envoy/config/trace/v3/http_tracer.proto\x1a%envoy/config/trace/v3/lightstep.proto\x1a&envoy/config/trace/v3/opencensus.proto\x1a#envoy/config/trace/v3/service.proto\x1a\"envoy/config/trace/v3/zipkin.protoB3\n#io.envoyproxy.envoy.config.trace.v3B\nTraceProtoP\x01P\x00P\x01P\x02P\x03P\x04P\x05P\x06\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_service__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_config_dot_trace_dot_v3_dot_datadog__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_dynamic__ot__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_http__tracer__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_lightstep__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_opencensus__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_service__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v3_dot_zipkin__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
