# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cache/v3alpha/cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/cache/v3alpha/cache.proto',
  package='envoy.extensions.filters.http.cache.v3alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.extensions.filters.http.cache.v3alphaB\nCacheProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/extensions/filters/http/cache/v3alpha/cache.proto\x12+envoy.extensions.filters.http.cache.v3alpha\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf2\x04\n\x0b\x43\x61\x63heConfig\x12\x34\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01\x12\x42\n\x14\x61llowed_vary_headers\x18\x02 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x65\n\x12key_creator_params\x18\x03 \x01(\x0b\x32I.envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams\x12\x16\n\x0emax_body_bytes\x18\x04 \x01(\r\x1a\xae\x02\n\x10KeyCreatorParams\x12\x16\n\x0e\x65xclude_scheme\x18\x01 \x01(\x08\x12\x14\n\x0c\x65xclude_host\x18\x02 \x01(\x08\x12O\n\x19query_parameters_included\x18\x03 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher\x12O\n\x19query_parameters_excluded\x18\x04 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.cache.v2alpha.CacheConfigBY\n9io.envoyproxy.envoy.extensions.filters.http.cache.v3alphaB\nCacheProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CACHECONFIG_KEYCREATORPARAMS = _descriptor.Descriptor(
  name='KeyCreatorParams',
  full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exclude_scheme', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.exclude_scheme', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exclude_host', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.exclude_host', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameters_included', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.query_parameters_included', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_parameters_excluded', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams.query_parameters_excluded', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036E\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=872,
)

_CACHECONFIG = _descriptor.Descriptor(
  name='CacheConfig',
  full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.typed_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\242\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_vary_headers', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.allowed_vary_headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_creator_params', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.key_creator_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_body_bytes', full_name='envoy.extensions.filters.http.cache.v3alpha.CacheConfig.max_body_bytes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CACHECONFIG_KEYCREATORPARAMS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.filter.http.cache.v2alpha.CacheConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=931,
)

_CACHECONFIG_KEYCREATORPARAMS.fields_by_name['query_parameters_included'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._QUERYPARAMETERMATCHER
_CACHECONFIG_KEYCREATORPARAMS.fields_by_name['query_parameters_excluded'].message_type = envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2._QUERYPARAMETERMATCHER
_CACHECONFIG_KEYCREATORPARAMS.containing_type = _CACHECONFIG
_CACHECONFIG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_CACHECONFIG.fields_by_name['allowed_vary_headers'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_CACHECONFIG.fields_by_name['key_creator_params'].message_type = _CACHECONFIG_KEYCREATORPARAMS
DESCRIPTOR.message_types_by_name['CacheConfig'] = _CACHECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CacheConfig = _reflection.GeneratedProtocolMessageType('CacheConfig', (_message.Message,), {

  'KeyCreatorParams' : _reflection.GeneratedProtocolMessageType('KeyCreatorParams', (_message.Message,), {
    'DESCRIPTOR' : _CACHECONFIG_KEYCREATORPARAMS,
    '__module__' : 'envoy.extensions.filters.http.cache.v3alpha.cache_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cache.v3alpha.CacheConfig.KeyCreatorParams)
    })
  ,
  'DESCRIPTOR' : _CACHECONFIG,
  '__module__' : 'envoy.extensions.filters.http.cache.v3alpha.cache_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cache.v3alpha.CacheConfig)
  })
_sym_db.RegisterMessage(CacheConfig)
_sym_db.RegisterMessage(CacheConfig.KeyCreatorParams)


DESCRIPTOR._options = None
_CACHECONFIG_KEYCREATORPARAMS._options = None
_CACHECONFIG.fields_by_name['typed_config']._options = None
_CACHECONFIG._options = None
# @@protoc_insertion_point(module_scope)
