# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/listener/udp_listener_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/listener/udp_listener_config.proto',
  package='envoy.api.v2.listener',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.listenerB\026UdpListenerConfigProtoP\001\252\002\027Envoy.Api.V2.ListenerNS\352\002\027Envoy.Api.V2.ListenerNS\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/api/v2/listener/udp_listener_config.proto\x12\x15\x65nvoy.api.v2.listener\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x9a\x01\n\x11UdpListenerConfig\x12\x19\n\x11udp_listener_name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\"\x1c\n\x1a\x41\x63tiveRawUdpListenerConfigB\x9b\x01\n#io.envoyproxy.envoy.api.v2.listenerB\x16UdpListenerConfigProtoP\x01\xaa\x02\x17\x45nvoy.Api.V2.ListenerNS\xea\x02\x17\x45nvoy.Api.V2.ListenerNS\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_UDPLISTENERCONFIG = _descriptor.Descriptor(
  name='UdpListenerConfig',
  full_name='envoy.api.v2.listener.UdpListenerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='udp_listener_name', full_name='envoy.api.v2.listener.UdpListenerConfig.udp_listener_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.listener.UdpListenerConfig.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.listener.UdpListenerConfig.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.listener.UdpListenerConfig.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=195,
  serialized_end=349,
)


_ACTIVERAWUDPLISTENERCONFIG = _descriptor.Descriptor(
  name='ActiveRawUdpListenerConfig',
  full_name='envoy.api.v2.listener.ActiveRawUdpListenerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=351,
  serialized_end=379,
)

_UDPLISTENERCONFIG.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_UDPLISTENERCONFIG.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_UDPLISTENERCONFIG.oneofs_by_name['config_type'].fields.append(
  _UDPLISTENERCONFIG.fields_by_name['config'])
_UDPLISTENERCONFIG.fields_by_name['config'].containing_oneof = _UDPLISTENERCONFIG.oneofs_by_name['config_type']
_UDPLISTENERCONFIG.oneofs_by_name['config_type'].fields.append(
  _UDPLISTENERCONFIG.fields_by_name['typed_config'])
_UDPLISTENERCONFIG.fields_by_name['typed_config'].containing_oneof = _UDPLISTENERCONFIG.oneofs_by_name['config_type']
DESCRIPTOR.message_types_by_name['UdpListenerConfig'] = _UDPLISTENERCONFIG
DESCRIPTOR.message_types_by_name['ActiveRawUdpListenerConfig'] = _ACTIVERAWUDPLISTENERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpListenerConfig = _reflection.GeneratedProtocolMessageType('UdpListenerConfig', (_message.Message,), {
  'DESCRIPTOR' : _UDPLISTENERCONFIG,
  '__module__' : 'envoy.api.v2.listener.udp_listener_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.listener.UdpListenerConfig)
  })
_sym_db.RegisterMessage(UdpListenerConfig)

ActiveRawUdpListenerConfig = _reflection.GeneratedProtocolMessageType('ActiveRawUdpListenerConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVERAWUDPLISTENERCONFIG,
  '__module__' : 'envoy.api.v2.listener.udp_listener_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.listener.ActiveRawUdpListenerConfig)
  })
_sym_db.RegisterMessage(ActiveRawUdpListenerConfig)


DESCRIPTOR._options = None
_UDPLISTENERCONFIG.fields_by_name['config']._options = None
# @@protoc_insertion_point(module_scope)
