# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.filters.network.dubbo_proxy.v4alpha import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto',
  package='envoy.extensions.filters.network.dubbo_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v4alphaB\017DubboProxyProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFenvoy/extensions/filters/network/dubbo_proxy/v4alpha/dubbo_proxy.proto\x12\x34\x65nvoy.extensions.filters.network.dubbo_proxy.v4alpha\x1a@envoy/extensions/filters/network/dubbo_proxy/v4alpha/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfb\x03\n\nDubboProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x63\n\rprotocol_type\x18\x02 \x01(\x0e\x32\x42.envoy.extensions.filters.network.dubbo_proxy.v4alpha.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12m\n\x12serialization_type\x18\x03 \x01(\x0e\x32G.envoy.extensions.filters.network.dubbo_proxy.v4alpha.SerializationTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12^\n\x0croute_config\x18\x04 \x03(\x0b\x32H.envoy.extensions.filters.network.dubbo_proxy.v4alpha.RouteConfiguration\x12X\n\rdubbo_filters\x18\x05 \x03(\x0b\x32\x41.envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.network.dubbo_proxy.v3.DubboProxy\"\x8e\x01\n\x0b\x44ubboFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.network.dubbo_proxy.v3.DubboFilter*\x19\n\x0cProtocolType\x12\t\n\x05\x44ubbo\x10\x00*!\n\x11SerializationType\x12\x0c\n\x08Hessian2\x10\x00\x42_\nBio.envoyproxy.envoy.extensions.filters.network.dubbo_proxy.v4alphaB\x0f\x44ubboProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_PROTOCOLTYPE = _descriptor.EnumDescriptor(
  name='ProtocolType',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.ProtocolType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Dubbo', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=967,
  serialized_end=992,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOLTYPE)

ProtocolType = enum_type_wrapper.EnumTypeWrapper(_PROTOCOLTYPE)
_SERIALIZATIONTYPE = _descriptor.EnumDescriptor(
  name='SerializationType',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.SerializationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Hessian2', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=994,
  serialized_end=1027,
)
_sym_db.RegisterEnumDescriptor(_SERIALIZATIONTYPE)

SerializationType = enum_type_wrapper.EnumTypeWrapper(_SERIALIZATIONTYPE)
Dubbo = 0
Hessian2 = 0



_DUBBOPROXY = _descriptor.Descriptor(
  name='DubboProxy',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.protocol_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialization_type', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.serialization_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_config', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.route_config', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dubbo_filters', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy.dubbo_filters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.network.dubbo_proxy.v3.DubboProxy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=820,
)


_DUBBOFILTER = _descriptor.Descriptor(
  name='DubboFilter',
  full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.network.dubbo_proxy.v3.DubboFilter',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=965,
)

_DUBBOPROXY.fields_by_name['protocol_type'].enum_type = _PROTOCOLTYPE
_DUBBOPROXY.fields_by_name['serialization_type'].enum_type = _SERIALIZATIONTYPE
_DUBBOPROXY.fields_by_name['route_config'].message_type = envoy_dot_extensions_dot_filters_dot_network_dot_dubbo__proxy_dot_v4alpha_dot_route__pb2._ROUTECONFIGURATION
_DUBBOPROXY.fields_by_name['dubbo_filters'].message_type = _DUBBOFILTER
_DUBBOFILTER.fields_by_name['config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['DubboProxy'] = _DUBBOPROXY
DESCRIPTOR.message_types_by_name['DubboFilter'] = _DUBBOFILTER
DESCRIPTOR.enum_types_by_name['ProtocolType'] = _PROTOCOLTYPE
DESCRIPTOR.enum_types_by_name['SerializationType'] = _SERIALIZATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DubboProxy = _reflection.GeneratedProtocolMessageType('DubboProxy', (_message.Message,), {
  'DESCRIPTOR' : _DUBBOPROXY,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v4alpha.dubbo_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboProxy)
  })
_sym_db.RegisterMessage(DubboProxy)

DubboFilter = _reflection.GeneratedProtocolMessageType('DubboFilter', (_message.Message,), {
  'DESCRIPTOR' : _DUBBOFILTER,
  '__module__' : 'envoy.extensions.filters.network.dubbo_proxy.v4alpha.dubbo_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.dubbo_proxy.v4alpha.DubboFilter)
  })
_sym_db.RegisterMessage(DubboFilter)


DESCRIPTOR._options = None
_DUBBOPROXY.fields_by_name['stat_prefix']._options = None
_DUBBOPROXY.fields_by_name['protocol_type']._options = None
_DUBBOPROXY.fields_by_name['serialization_type']._options = None
_DUBBOPROXY._options = None
_DUBBOFILTER.fields_by_name['name']._options = None
_DUBBOFILTER._options = None
# @@protoc_insertion_point(module_scope)
