# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v4alpha/quic_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v4alpha/quic_config.proto',
  package='envoy.config.listener.v4alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.listener.v4alphaB\017QuicConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/config/listener/v4alpha/quic_config.proto\x12\x1d\x65nvoy.config.listener.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xb6\x02\n\x13QuicProtocolOptions\x12<\n\x16max_concurrent_streams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0cidle_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18\x63rypto_handshake_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12>\n\x07\x65nabled\x18\x04 \x01(\x0b\x32-.envoy.config.core.v4alpha.RuntimeFeatureFlag:3\x9a\xc5\x88\x1e.\n,envoy.config.listener.v3.QuicProtocolOptionsBH\n+io.envoyproxy.envoy.config.listener.v4alphaB\x0fQuicConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_QUICPROTOCOLOPTIONS = _descriptor.Descriptor(
  name='QuicProtocolOptions',
  full_name='envoy.config.listener.v4alpha.QuicProtocolOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_concurrent_streams', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.max_concurrent_streams', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.idle_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crypto_handshake_timeout', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.crypto_handshake_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.config.listener.v4alpha.QuicProtocolOptions.enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.listener.v3.QuicProtocolOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=561,
)

_QUICPROTOCOLOPTIONS.fields_by_name['max_concurrent_streams'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_QUICPROTOCOLOPTIONS.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_QUICPROTOCOLOPTIONS.fields_by_name['crypto_handshake_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_QUICPROTOCOLOPTIONS.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['QuicProtocolOptions'] = _QUICPROTOCOLOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuicProtocolOptions = _reflection.GeneratedProtocolMessageType('QuicProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _QUICPROTOCOLOPTIONS,
  '__module__' : 'envoy.config.listener.v4alpha.quic_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v4alpha.QuicProtocolOptions)
  })
_sym_db.RegisterMessage(QuicProtocolOptions)


DESCRIPTOR._options = None
_QUICPROTOCOLOPTIONS._options = None
# @@protoc_insertion_point(module_scope)
