# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/auth/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/auth/common.proto',
  package='envoy.api.v2.auth',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.authB\013CommonProtoP\001\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/api/v2/auth/common.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x02\n\rTlsParameters\x12\\\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\\\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04\"\xae\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\x18\x01\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x42\r\n\x0b\x63onfig_type\"\xfd\x02\n\x0eTlsCertificate\x12\x38\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x43\n\x14private_key_provider\x18\x06 \x01(\x0b\x32%.envoy.api.v2.auth.PrivateKeyProvider\x12\x37\n\x08password\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x32\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12\x43\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSource\"S\n\x14TlsSessionTicketKeys\x12;\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01\"\xaa\x05\n\x1c\x43\x65rtificateValidationContext\x12\x31\n\ntrusted_ca\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 ,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 @(_\x12#\n\x17verify_subject_alt_name\x18\x04 \x03(\tB\x02\x18\x01\x12\x42\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x37\n\x13require_ocsp_staple\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x03\x63rl\x18\x07 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12r\n\x18trust_chain_verification\x18\n \x01(\x0e\x32\x46.envoy.api.v2.auth.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01\x42i\n\x1fio.envoyproxy.envoy.api.v2.authB\x0b\x43ommonProtoP\x01\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_TLSPARAMETERS_TLSPROTOCOL = _descriptor.EnumDescriptor(
  name='TlsProtocol',
  full_name='envoy.api.v2.auth.TlsParameters.TlsProtocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TLS_AUTO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_0', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_1', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_2', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TLSv1_3', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=577,
  serialized_end=656,
)
_sym_db.RegisterEnumDescriptor(_TLSPARAMETERS_TLSPROTOCOL)

_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION = _descriptor.EnumDescriptor(
  name='TrustChainVerification',
  full_name='envoy.api.v2.auth.CertificateValidationContext.TrustChainVerification',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_TRUST_CHAIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCEPT_UNTRUSTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1917,
  serialized_end=1987,
)
_sym_db.RegisterEnumDescriptor(_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION)


_TLSPARAMETERS = _descriptor.Descriptor(
  name='TlsParameters',
  full_name='envoy.api.v2.auth.TlsParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls_minimum_protocol_version', full_name='envoy.api.v2.auth.TlsParameters.tls_minimum_protocol_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_maximum_protocol_version', full_name='envoy.api.v2.auth.TlsParameters.tls_maximum_protocol_version', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cipher_suites', full_name='envoy.api.v2.auth.TlsParameters.cipher_suites', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ecdh_curves', full_name='envoy.api.v2.auth.TlsParameters.ecdh_curves', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TLSPARAMETERS_TLSPROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=656,
)


_PRIVATEKEYPROVIDER = _descriptor.Descriptor(
  name='PrivateKeyProvider',
  full_name='envoy.api.v2.auth.PrivateKeyProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.api.v2.auth.PrivateKeyProvider.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.auth.PrivateKeyProvider.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.auth.PrivateKeyProvider.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.auth.PrivateKeyProvider.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=659,
  serialized_end=833,
)


_TLSCERTIFICATE = _descriptor.Descriptor(
  name='TlsCertificate',
  full_name='envoy.api.v2.auth.TlsCertificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificate_chain', full_name='envoy.api.v2.auth.TlsCertificate.certificate_chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.api.v2.auth.TlsCertificate.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key_provider', full_name='envoy.api.v2.auth.TlsCertificate.private_key_provider', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='envoy.api.v2.auth.TlsCertificate.password', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_staple', full_name='envoy.api.v2.auth.TlsCertificate.ocsp_staple', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_certificate_timestamp', full_name='envoy.api.v2.auth.TlsCertificate.signed_certificate_timestamp', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=836,
  serialized_end=1217,
)


_TLSSESSIONTICKETKEYS = _descriptor.Descriptor(
  name='TlsSessionTicketKeys',
  full_name='envoy.api.v2.auth.TlsSessionTicketKeys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='envoy.api.v2.auth.TlsSessionTicketKeys.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1302,
)


_CERTIFICATEVALIDATIONCONTEXT = _descriptor.Descriptor(
  name='CertificateValidationContext',
  full_name='envoy.api.v2.auth.CertificateValidationContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trusted_ca', full_name='envoy.api.v2.auth.CertificateValidationContext.trusted_ca', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_spki', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_certificate_spki', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004 ,(,', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_certificate_hash', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_certificate_hash', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\222\001\010\"\006r\004 @(_', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verify_subject_alt_name', full_name='envoy.api.v2.auth.CertificateValidationContext.verify_subject_alt_name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_subject_alt_names', full_name='envoy.api.v2.auth.CertificateValidationContext.match_subject_alt_names', index=4,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_ocsp_staple', full_name='envoy.api.v2.auth.CertificateValidationContext.require_ocsp_staple', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='require_signed_certificate_timestamp', full_name='envoy.api.v2.auth.CertificateValidationContext.require_signed_certificate_timestamp', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crl', full_name='envoy.api.v2.auth.CertificateValidationContext.crl', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_expired_certificate', full_name='envoy.api.v2.auth.CertificateValidationContext.allow_expired_certificate', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trust_chain_verification', full_name='envoy.api.v2.auth.CertificateValidationContext.trust_chain_verification', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1987,
)

_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version'].enum_type = _TLSPARAMETERS_TLSPROTOCOL
_TLSPARAMETERS_TLSPROTOCOL.containing_type = _TLSPARAMETERS
_PRIVATEKEYPROVIDER.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['config'])
_PRIVATEKEYPROVIDER.fields_by_name['config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_PRIVATEKEYPROVIDER.oneofs_by_name['config_type'].fields.append(
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config'])
_PRIVATEKEYPROVIDER.fields_by_name['typed_config'].containing_oneof = _PRIVATEKEYPROVIDER.oneofs_by_name['config_type']
_TLSCERTIFICATE.fields_by_name['certificate_chain'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['private_key_provider'].message_type = _PRIVATEKEYPROVIDER
_TLSCERTIFICATE.fields_by_name['password'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['ocsp_staple'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSCERTIFICATE.fields_by_name['signed_certificate_timestamp'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_TLSSESSIONTICKETKEYS.fields_by_name['keys'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._STRINGMATCHER
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_ocsp_staple'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['require_signed_certificate_timestamp'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['crl'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification'].enum_type = _CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION
_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION.containing_type = _CERTIFICATEVALIDATIONCONTEXT
DESCRIPTOR.message_types_by_name['TlsParameters'] = _TLSPARAMETERS
DESCRIPTOR.message_types_by_name['PrivateKeyProvider'] = _PRIVATEKEYPROVIDER
DESCRIPTOR.message_types_by_name['TlsCertificate'] = _TLSCERTIFICATE
DESCRIPTOR.message_types_by_name['TlsSessionTicketKeys'] = _TLSSESSIONTICKETKEYS
DESCRIPTOR.message_types_by_name['CertificateValidationContext'] = _CERTIFICATEVALIDATIONCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TlsParameters = _reflection.GeneratedProtocolMessageType('TlsParameters', (_message.Message,), {
  'DESCRIPTOR' : _TLSPARAMETERS,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsParameters)
  })
_sym_db.RegisterMessage(TlsParameters)

PrivateKeyProvider = _reflection.GeneratedProtocolMessageType('PrivateKeyProvider', (_message.Message,), {
  'DESCRIPTOR' : _PRIVATEKEYPROVIDER,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.PrivateKeyProvider)
  })
_sym_db.RegisterMessage(PrivateKeyProvider)

TlsCertificate = _reflection.GeneratedProtocolMessageType('TlsCertificate', (_message.Message,), {
  'DESCRIPTOR' : _TLSCERTIFICATE,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsCertificate)
  })
_sym_db.RegisterMessage(TlsCertificate)

TlsSessionTicketKeys = _reflection.GeneratedProtocolMessageType('TlsSessionTicketKeys', (_message.Message,), {
  'DESCRIPTOR' : _TLSSESSIONTICKETKEYS,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.TlsSessionTicketKeys)
  })
_sym_db.RegisterMessage(TlsSessionTicketKeys)

CertificateValidationContext = _reflection.GeneratedProtocolMessageType('CertificateValidationContext', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATEVALIDATIONCONTEXT,
  '__module__' : 'envoy.api.v2.auth.common_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.auth.CertificateValidationContext)
  })
_sym_db.RegisterMessage(CertificateValidationContext)


DESCRIPTOR._options = None
_TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
_TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['config']._options = None
_PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
_TLSCERTIFICATE.fields_by_name['private_key']._options = None
_TLSCERTIFICATE.fields_by_name['password']._options = None
_TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_subject_alt_name']._options = None
_CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
# @@protoc_insertion_point(module_scope)
