# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/clusters/redis/v3/redis_cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/clusters/redis/v3/redis_cluster.proto',
  package='envoy.extensions.clusters.redis.v3',
  syntax='proto3',
  serialized_options=b'\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\021RedisClusterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6envoy/extensions/clusters/redis/v3/redis_cluster.proto\x12\"envoy.extensions.clusters.redis.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9f\x03\n\x12RedisClusterConfig\x12\x41\n\x14\x63luster_refresh_rate\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17\x63luster_refresh_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12<\n\x19redirect_refresh_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x1aredirect_refresh_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\x19\x66\x61ilure_refresh_threshold\x18\x05 \x01(\r\x12\'\n\x1fhost_degraded_refresh_threshold\x18\x06 \x01(\r:4\x9a\xc5\x88\x1e/\n-envoy.config.cluster.redis.RedisClusterConfigBO\n0io.envoyproxy.envoy.extensions.clusters.redis.v3B\x11RedisClusterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_REDISCLUSTERCONFIG = _descriptor.Descriptor(
  name='RedisClusterConfig',
  full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_refresh_rate', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.cluster_refresh_rate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_refresh_timeout', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.cluster_refresh_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_refresh_interval', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.redirect_refresh_interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.redirect_refresh_threshold', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.failure_refresh_threshold', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_degraded_refresh_threshold', full_name='envoy.extensions.clusters.redis.v3.RedisClusterConfig.host_degraded_refresh_threshold', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.cluster.redis.RedisClusterConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=665,
)

_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['redirect_refresh_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_REDISCLUSTERCONFIG.fields_by_name['redirect_refresh_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['RedisClusterConfig'] = _REDISCLUSTERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RedisClusterConfig = _reflection.GeneratedProtocolMessageType('RedisClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _REDISCLUSTERCONFIG,
  '__module__' : 'envoy.extensions.clusters.redis.v3.redis_cluster_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.clusters.redis.v3.RedisClusterConfig)
  })
_sym_db.RegisterMessage(RedisClusterConfig)


DESCRIPTOR._options = None
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_rate']._options = None
_REDISCLUSTERCONFIG.fields_by_name['cluster_refresh_timeout']._options = None
_REDISCLUSTERCONFIG._options = None
# @@protoc_insertion_point(module_scope)
