# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/ratelimit/v3/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import ratelimit_unit_pb2 as envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2
from envoy.type.v3 import token_bucket_pb2 as envoy_dot_type_dot_v3_dot_token__bucket__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/common/ratelimit/v3/ratelimit.proto',
  package='envoy.extensions.common.ratelimit.v3',
  syntax='proto3',
  serialized_options=b'\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\016RatelimitProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4envoy/extensions/common/ratelimit/v3/ratelimit.proto\x12$envoy.extensions.common.ratelimit.v3\x1a\"envoy/type/v3/ratelimit_unit.proto\x1a envoy/type/v3/token_bucket.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd6\x03\n\x13RateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12Z\n\x05limit\x18\x02 \x01(\x0b\x32K.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride\x1an\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry\x1a\x64\n\x11RateLimitOverride\x12\x19\n\x11requests_per_unit\x18\x01 \x01(\r\x12\x34\n\x04unit\x18\x02 \x01(\x0e\x32\x1c.envoy.type.v3.RateLimitUnitB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:1\x9a\xc5\x88\x1e,\n*envoy.api.v2.ratelimit.RateLimitDescriptor\"\xb2\x01\n\x18LocalRateLimitDescriptor\x12Z\n\x07\x65ntries\x18\x01 \x03(\x0b\x32?.envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12:\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x1a.envoy.type.v3.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42N\n2io.envoyproxy.envoy.extensions.common.ratelimit.v3B\x0eRatelimitProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_token__bucket__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMITDESCRIPTOR_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.api.v2.ratelimit.RateLimitDescriptor.Entry',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=573,
)

_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE = _descriptor.Descriptor(
  name='RateLimitOverride',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests_per_unit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride.requests_per_unit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride.unit', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=675,
)

_RATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='RateLimitDescriptor',
  full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITDESCRIPTOR_ENTRY, _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036,\n*envoy.api.v2.ratelimit.RateLimitDescriptor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=726,
)


_LOCALRATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='LocalRateLimitDescriptor',
  full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_bucket', full_name='envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor.token_bucket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=907,
)

_RATELIMITDESCRIPTOR_ENTRY.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit'].enum_type = envoy_dot_type_dot_v3_dot_ratelimit__unit__pb2._RATELIMITUNIT
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
_RATELIMITDESCRIPTOR.fields_by_name['limit'].message_type = _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE
_LOCALRATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
_LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket'].message_type = envoy_dot_type_dot_v3_dot_token__bucket__pb2._TOKENBUCKET
DESCRIPTOR.message_types_by_name['RateLimitDescriptor'] = _RATELIMITDESCRIPTOR
DESCRIPTOR.message_types_by_name['LocalRateLimitDescriptor'] = _LOCALRATELIMITDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitDescriptor = _reflection.GeneratedProtocolMessageType('RateLimitDescriptor', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_ENTRY,
    '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.Entry)
    })
  ,

  'RateLimitOverride' : _reflection.GeneratedProtocolMessageType('RateLimitOverride', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_RATELIMITOVERRIDE,
    '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor.RateLimitOverride)
    })
  ,
  'DESCRIPTOR' : _RATELIMITDESCRIPTOR,
  '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.RateLimitDescriptor)
  })
_sym_db.RegisterMessage(RateLimitDescriptor)
_sym_db.RegisterMessage(RateLimitDescriptor.Entry)
_sym_db.RegisterMessage(RateLimitDescriptor.RateLimitOverride)

LocalRateLimitDescriptor = _reflection.GeneratedProtocolMessageType('LocalRateLimitDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _LOCALRATELIMITDESCRIPTOR,
  '__module__' : 'envoy.extensions.common.ratelimit.v3.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.common.ratelimit.v3.LocalRateLimitDescriptor)
  })
_sym_db.RegisterMessage(LocalRateLimitDescriptor)


DESCRIPTOR._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
_RATELIMITDESCRIPTOR_ENTRY._options = None
_RATELIMITDESCRIPTOR_RATELIMITOVERRIDE.fields_by_name['unit']._options = None
_RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
_RATELIMITDESCRIPTOR._options = None
_LOCALRATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
_LOCALRATELIMITDESCRIPTOR.fields_by_name['token_bucket']._options = None
# @@protoc_insertion_point(module_scope)
