# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicemanagement/v1/resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import config_change_pb2 as google_dot_api_dot_config__change__pb2
from google.api import metric_pb2 as google_dot_api_dot_metric__pb2
from google.api import service_pb2 as google_dot_api_dot_service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicemanagement/v1/resources.proto',
  package='google.api.servicemanagement.v1',
  syntax='proto3',
  serialized_options=b'\n#com.google.api.servicemanagement.v1B\016ResourcesProtoP\001ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\242\002\004GASM\252\002!Google.Cloud.ServiceManagement.V1\312\002!Google\\Cloud\\ServiceManagement\\V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/google/api/servicemanagement/v1/resources.proto\x12\x1fgoogle.api.servicemanagement.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/api/config_change.proto\x1a\x17google/api/metric.proto\x1a\x18google/api/service.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\"C\n\x0eManagedService\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x1b\n\x13producer_project_id\x18\x03 \x01(\t\"\x91\x03\n\x11OperationMetadata\x12\x16\n\x0eresource_names\x18\x01 \x03(\t\x12\x46\n\x05steps\x18\x02 \x03(\x0b\x32\x37.google.api.servicemanagement.v1.OperationMetadata.Step\x12\x1b\n\x13progress_percentage\x18\x03 \x01(\x05\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x66\n\x04Step\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12I\n\x06status\x18\x04 \x01(\x0e\x32\x39.google.api.servicemanagement.v1.OperationMetadata.Status\"g\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44ONE\x10\x01\x12\x0f\n\x0bNOT_STARTED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\r\n\tCANCELLED\x10\x05\"\x8f\x01\n\nDiagnostic\x12\x10\n\x08location\x18\x01 \x01(\t\x12>\n\x04kind\x18\x02 \x01(\x0e\x32\x30.google.api.servicemanagement.v1.Diagnostic.Kind\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x1e\n\x04Kind\x12\x0b\n\x07WARNING\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"V\n\x0c\x43onfigSource\x12\n\n\x02id\x18\x05 \x01(\t\x12:\n\x05\x66iles\x18\x02 \x03(\x0b\x32+.google.api.servicemanagement.v1.ConfigFile\"\x95\x02\n\nConfigFile\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x15\n\rfile_contents\x18\x03 \x01(\x0c\x12G\n\tfile_type\x18\x04 \x01(\x0e\x32\x34.google.api.servicemanagement.v1.ConfigFile.FileType\"\x93\x01\n\x08\x46ileType\x12\x19\n\x15\x46ILE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13SERVICE_CONFIG_YAML\x10\x01\x12\x11\n\rOPEN_API_JSON\x10\x02\x12\x11\n\rOPEN_API_YAML\x10\x03\x12\x1d\n\x19\x46ILE_DESCRIPTOR_SET_PROTO\x10\x04\x12\x0e\n\nPROTO_FILE\x10\x06\"\x19\n\tConfigRef\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x0c\x43hangeReport\x12\x30\n\x0e\x63onfig_changes\x18\x01 \x03(\x0b\x32\x18.google.api.ConfigChange\"\xf4\x05\n\x07Rollout\x12\x12\n\nrollout_id\x18\x01 \x01(\t\x12/\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12\x46\n\x06status\x18\x04 \x01(\x0e\x32\x36.google.api.servicemanagement.v1.Rollout.RolloutStatus\x12\x63\n\x18traffic_percent_strategy\x18\x05 \x01(\x0b\x32?.google.api.servicemanagement.v1.Rollout.TrafficPercentStrategyH\x00\x12\x62\n\x17\x64\x65lete_service_strategy\x18\xc8\x01 \x01(\x0b\x32>.google.api.servicemanagement.v1.Rollout.DeleteServiceStrategyH\x00\x12\x14\n\x0cservice_name\x18\x08 \x01(\t\x1a\xb3\x01\n\x16TrafficPercentStrategy\x12\x65\n\x0bpercentages\x18\x01 \x03(\x0b\x32P.google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry\x1a\x32\n\x10PercentagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x17\n\x15\x44\x65leteServiceStrategy\"\x8d\x01\n\rRolloutStatus\x12\x1e\n\x1aROLLOUT_STATUS_UNSPECIFIED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\r\n\tCANCELLED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07PENDING\x10\x05\x12\x16\n\x12\x46\x41ILED_ROLLED_BACK\x10\x06\x42\n\n\x08strategyB\xd8\x01\n#com.google.api.servicemanagement.v1B\x0eResourcesProtoP\x01ZPgoogle.golang.org/genproto/googleapis/api/servicemanagement/v1;servicemanagement\xa2\x02\x04GASM\xaa\x02!Google.Cloud.ServiceManagement.V1\xca\x02!Google\\Cloud\\ServiceManagement\\V1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_config__change__pb2.DESCRIPTOR,google_dot_api_dot_metric__pb2.DESCRIPTOR,google_dot_api_dot_service__pb2.DESCRIPTOR,google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])



_OPERATIONMETADATA_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='google.api.servicemanagement.v1.OperationMetadata.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_STARTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=751,
  serialized_end=854,
)
_sym_db.RegisterEnumDescriptor(_OPERATIONMETADATA_STATUS)

_DIAGNOSTIC_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='google.api.servicemanagement.v1.Diagnostic.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=970,
  serialized_end=1000,
)
_sym_db.RegisterEnumDescriptor(_DIAGNOSTIC_KIND)

_CONFIGFILE_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='google.api.servicemanagement.v1.ConfigFile.FileType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_CONFIG_YAML', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_API_JSON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN_API_YAML', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE_DESCRIPTOR_SET_PROTO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTO_FILE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1221,
  serialized_end=1368,
)
_sym_db.RegisterEnumDescriptor(_CONFIGFILE_FILETYPE)

_ROLLOUT_ROLLOUTSTATUS = _descriptor.EnumDescriptor(
  name='RolloutStatus',
  full_name='google.api.servicemanagement.v1.Rollout.RolloutStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ROLLOUT_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_PROGRESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_ROLLED_BACK', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2067,
  serialized_end=2208,
)
_sym_db.RegisterEnumDescriptor(_ROLLOUT_ROLLOUTSTATUS)


_MANAGEDSERVICE = _descriptor.Descriptor(
  name='ManagedService',
  full_name='google.api.servicemanagement.v1.ManagedService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.ManagedService.service_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_project_id', full_name='google.api.servicemanagement.v1.ManagedService.producer_project_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=450,
)


_OPERATIONMETADATA_STEP = _descriptor.Descriptor(
  name='Step',
  full_name='google.api.servicemanagement.v1.OperationMetadata.Step',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='google.api.servicemanagement.v1.OperationMetadata.Step.description', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.api.servicemanagement.v1.OperationMetadata.Step.status', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=749,
)

_OPERATIONMETADATA = _descriptor.Descriptor(
  name='OperationMetadata',
  full_name='google.api.servicemanagement.v1.OperationMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='google.api.servicemanagement.v1.OperationMetadata.resource_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steps', full_name='google.api.servicemanagement.v1.OperationMetadata.steps', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress_percentage', full_name='google.api.servicemanagement.v1.OperationMetadata.progress_percentage', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.api.servicemanagement.v1.OperationMetadata.start_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPERATIONMETADATA_STEP, ],
  enum_types=[
    _OPERATIONMETADATA_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=854,
)


_DIAGNOSTIC = _descriptor.Descriptor(
  name='Diagnostic',
  full_name='google.api.servicemanagement.v1.Diagnostic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.servicemanagement.v1.Diagnostic.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='google.api.servicemanagement.v1.Diagnostic.kind', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='google.api.servicemanagement.v1.Diagnostic.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DIAGNOSTIC_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=1000,
)


_CONFIGSOURCE = _descriptor.Descriptor(
  name='ConfigSource',
  full_name='google.api.servicemanagement.v1.ConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.servicemanagement.v1.ConfigSource.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='files', full_name='google.api.servicemanagement.v1.ConfigSource.files', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1088,
)


_CONFIGFILE = _descriptor.Descriptor(
  name='ConfigFile',
  full_name='google.api.servicemanagement.v1.ConfigFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_path', full_name='google.api.servicemanagement.v1.ConfigFile.file_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_contents', full_name='google.api.servicemanagement.v1.ConfigFile.file_contents', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='google.api.servicemanagement.v1.ConfigFile.file_type', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGFILE_FILETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1368,
)


_CONFIGREF = _descriptor.Descriptor(
  name='ConfigRef',
  full_name='google.api.servicemanagement.v1.ConfigRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.servicemanagement.v1.ConfigRef.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1370,
  serialized_end=1395,
)


_CHANGEREPORT = _descriptor.Descriptor(
  name='ChangeReport',
  full_name='google.api.servicemanagement.v1.ChangeReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_changes', full_name='google.api.servicemanagement.v1.ChangeReport.config_changes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1397,
  serialized_end=1461,
)


_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY = _descriptor.Descriptor(
  name='PercentagesEntry',
  full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2039,
)

_ROLLOUT_TRAFFICPERCENTSTRATEGY = _descriptor.Descriptor(
  name='TrafficPercentStrategy',
  full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentages', full_name='google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.percentages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1860,
  serialized_end=2039,
)

_ROLLOUT_DELETESERVICESTRATEGY = _descriptor.Descriptor(
  name='DeleteServiceStrategy',
  full_name='google.api.servicemanagement.v1.Rollout.DeleteServiceStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2064,
)

_ROLLOUT = _descriptor.Descriptor(
  name='Rollout',
  full_name='google.api.servicemanagement.v1.Rollout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rollout_id', full_name='google.api.servicemanagement.v1.Rollout.rollout_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='google.api.servicemanagement.v1.Rollout.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_by', full_name='google.api.servicemanagement.v1.Rollout.created_by', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.api.servicemanagement.v1.Rollout.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_percent_strategy', full_name='google.api.servicemanagement.v1.Rollout.traffic_percent_strategy', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_service_strategy', full_name='google.api.servicemanagement.v1.Rollout.delete_service_strategy', index=5,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicemanagement.v1.Rollout.service_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROLLOUT_TRAFFICPERCENTSTRATEGY, _ROLLOUT_DELETESERVICESTRATEGY, ],
  enum_types=[
    _ROLLOUT_ROLLOUTSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='strategy', full_name='google.api.servicemanagement.v1.Rollout.strategy',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1464,
  serialized_end=2220,
)

_OPERATIONMETADATA_STEP.fields_by_name['status'].enum_type = _OPERATIONMETADATA_STATUS
_OPERATIONMETADATA_STEP.containing_type = _OPERATIONMETADATA
_OPERATIONMETADATA.fields_by_name['steps'].message_type = _OPERATIONMETADATA_STEP
_OPERATIONMETADATA.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATIONMETADATA_STATUS.containing_type = _OPERATIONMETADATA
_DIAGNOSTIC.fields_by_name['kind'].enum_type = _DIAGNOSTIC_KIND
_DIAGNOSTIC_KIND.containing_type = _DIAGNOSTIC
_CONFIGSOURCE.fields_by_name['files'].message_type = _CONFIGFILE
_CONFIGFILE.fields_by_name['file_type'].enum_type = _CONFIGFILE_FILETYPE
_CONFIGFILE_FILETYPE.containing_type = _CONFIGFILE
_CHANGEREPORT.fields_by_name['config_changes'].message_type = google_dot_api_dot_config__change__pb2._CONFIGCHANGE
_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY.containing_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY
_ROLLOUT_TRAFFICPERCENTSTRATEGY.fields_by_name['percentages'].message_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY
_ROLLOUT_TRAFFICPERCENTSTRATEGY.containing_type = _ROLLOUT
_ROLLOUT_DELETESERVICESTRATEGY.containing_type = _ROLLOUT
_ROLLOUT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROLLOUT.fields_by_name['status'].enum_type = _ROLLOUT_ROLLOUTSTATUS
_ROLLOUT.fields_by_name['traffic_percent_strategy'].message_type = _ROLLOUT_TRAFFICPERCENTSTRATEGY
_ROLLOUT.fields_by_name['delete_service_strategy'].message_type = _ROLLOUT_DELETESERVICESTRATEGY
_ROLLOUT_ROLLOUTSTATUS.containing_type = _ROLLOUT
_ROLLOUT.oneofs_by_name['strategy'].fields.append(
  _ROLLOUT.fields_by_name['traffic_percent_strategy'])
_ROLLOUT.fields_by_name['traffic_percent_strategy'].containing_oneof = _ROLLOUT.oneofs_by_name['strategy']
_ROLLOUT.oneofs_by_name['strategy'].fields.append(
  _ROLLOUT.fields_by_name['delete_service_strategy'])
_ROLLOUT.fields_by_name['delete_service_strategy'].containing_oneof = _ROLLOUT.oneofs_by_name['strategy']
DESCRIPTOR.message_types_by_name['ManagedService'] = _MANAGEDSERVICE
DESCRIPTOR.message_types_by_name['OperationMetadata'] = _OPERATIONMETADATA
DESCRIPTOR.message_types_by_name['Diagnostic'] = _DIAGNOSTIC
DESCRIPTOR.message_types_by_name['ConfigSource'] = _CONFIGSOURCE
DESCRIPTOR.message_types_by_name['ConfigFile'] = _CONFIGFILE
DESCRIPTOR.message_types_by_name['ConfigRef'] = _CONFIGREF
DESCRIPTOR.message_types_by_name['ChangeReport'] = _CHANGEREPORT
DESCRIPTOR.message_types_by_name['Rollout'] = _ROLLOUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ManagedService = _reflection.GeneratedProtocolMessageType('ManagedService', (_message.Message,), {
  'DESCRIPTOR' : _MANAGEDSERVICE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ManagedService)
  })
_sym_db.RegisterMessage(ManagedService)

OperationMetadata = _reflection.GeneratedProtocolMessageType('OperationMetadata', (_message.Message,), {

  'Step' : _reflection.GeneratedProtocolMessageType('Step', (_message.Message,), {
    'DESCRIPTOR' : _OPERATIONMETADATA_STEP,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.OperationMetadata.Step)
    })
  ,
  'DESCRIPTOR' : _OPERATIONMETADATA,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.OperationMetadata)
  })
_sym_db.RegisterMessage(OperationMetadata)
_sym_db.RegisterMessage(OperationMetadata.Step)

Diagnostic = _reflection.GeneratedProtocolMessageType('Diagnostic', (_message.Message,), {
  'DESCRIPTOR' : _DIAGNOSTIC,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Diagnostic)
  })
_sym_db.RegisterMessage(Diagnostic)

ConfigSource = _reflection.GeneratedProtocolMessageType('ConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGSOURCE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigSource)
  })
_sym_db.RegisterMessage(ConfigSource)

ConfigFile = _reflection.GeneratedProtocolMessageType('ConfigFile', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGFILE,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigFile)
  })
_sym_db.RegisterMessage(ConfigFile)

ConfigRef = _reflection.GeneratedProtocolMessageType('ConfigRef', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGREF,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ConfigRef)
  })
_sym_db.RegisterMessage(ConfigRef)

ChangeReport = _reflection.GeneratedProtocolMessageType('ChangeReport', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEREPORT,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.ChangeReport)
  })
_sym_db.RegisterMessage(ChangeReport)

Rollout = _reflection.GeneratedProtocolMessageType('Rollout', (_message.Message,), {

  'TrafficPercentStrategy' : _reflection.GeneratedProtocolMessageType('TrafficPercentStrategy', (_message.Message,), {

    'PercentagesEntry' : _reflection.GeneratedProtocolMessageType('PercentagesEntry', (_message.Message,), {
      'DESCRIPTOR' : _ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY,
      '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
      # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy.PercentagesEntry)
      })
    ,
    'DESCRIPTOR' : _ROLLOUT_TRAFFICPERCENTSTRATEGY,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.TrafficPercentStrategy)
    })
  ,

  'DeleteServiceStrategy' : _reflection.GeneratedProtocolMessageType('DeleteServiceStrategy', (_message.Message,), {
    'DESCRIPTOR' : _ROLLOUT_DELETESERVICESTRATEGY,
    '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout.DeleteServiceStrategy)
    })
  ,
  'DESCRIPTOR' : _ROLLOUT,
  '__module__' : 'google.api.servicemanagement.v1.resources_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicemanagement.v1.Rollout)
  })
_sym_db.RegisterMessage(Rollout)
_sym_db.RegisterMessage(Rollout.TrafficPercentStrategy)
_sym_db.RegisterMessage(Rollout.TrafficPercentStrategy.PercentagesEntry)
_sym_db.RegisterMessage(Rollout.DeleteServiceStrategy)


DESCRIPTOR._options = None
_ROLLOUT_TRAFFICPERCENTSTRATEGY_PERCENTAGESENTRY._options = None
# @@protoc_insertion_point(module_scope)
