# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/data/orca/v1/orca_load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/data/orca/v1/orca_load_report.proto',
  package='udpa.data.orca.v1',
  syntax='proto3',
  serialized_options=b'\n!com.github.udpa.udpa.data.orca.v1B\023OrcaLoadReportProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(udpa/data/orca/v1/orca_load_report.proto\x12\x11udpa.data.orca.v1\x1a\x17validate/validate.proto\"\xae\x03\n\x0eOrcaLoadReport\x12\x35\n\x0f\x63pu_utilization\x18\x01 \x01(\x01\x42\x1c\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\xfa\x42\x0b\x12\t\x19\x00\x00\x00\x00\x00\x00\xf0?\x12\x35\n\x0fmem_utilization\x18\x02 \x01(\x01\x42\x1c\xfa\x42\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\xfa\x42\x0b\x12\t\x19\x00\x00\x00\x00\x00\x00\xf0?\x12\x0b\n\x03rps\x18\x03 \x01(\x04\x12H\n\x0crequest_cost\x18\x04 \x03(\x0b\x32\x32.udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry\x12o\n\x0butilization\x18\x05 \x03(\x0b\x32\x32.udpa.data.orca.v1.OrcaLoadReport.UtilizationEntryB&\xfa\x42\x10\x9a\x01\r*\x0b\x12\t)\x00\x00\x00\x00\x00\x00\x00\x00\xfa\x42\x10\x9a\x01\r*\x0b\x12\t\x19\x00\x00\x00\x00\x00\x00\xf0?\x1a\x32\n\x10RequestCostEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x32\n\x10UtilizationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x42:\n!com.github.udpa.udpa.data.orca.v1B\x13OrcaLoadReportProtoP\x01\x62\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,])




_ORCALOADREPORT_REQUESTCOSTENTRY = _descriptor.Descriptor(
  name='RequestCostEntry',
  full_name='udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=467,
)

_ORCALOADREPORT_UTILIZATIONENTRY = _descriptor.Descriptor(
  name='UtilizationEntry',
  full_name='udpa.data.orca.v1.OrcaLoadReport.UtilizationEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='udpa.data.orca.v1.OrcaLoadReport.UtilizationEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='udpa.data.orca.v1.OrcaLoadReport.UtilizationEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=519,
)

_ORCALOADREPORT = _descriptor.Descriptor(
  name='OrcaLoadReport',
  full_name='udpa.data.orca.v1.OrcaLoadReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu_utilization', full_name='udpa.data.orca.v1.OrcaLoadReport.cpu_utilization', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\022\t)\000\000\000\000\000\000\000\000\372B\013\022\t\031\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mem_utilization', full_name='udpa.data.orca.v1.OrcaLoadReport.mem_utilization', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\013\022\t)\000\000\000\000\000\000\000\000\372B\013\022\t\031\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rps', full_name='udpa.data.orca.v1.OrcaLoadReport.rps', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_cost', full_name='udpa.data.orca.v1.OrcaLoadReport.request_cost', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='utilization', full_name='udpa.data.orca.v1.OrcaLoadReport.utilization', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\020\232\001\r*\013\022\t)\000\000\000\000\000\000\000\000\372B\020\232\001\r*\013\022\t\031\000\000\000\000\000\000\360?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ORCALOADREPORT_REQUESTCOSTENTRY, _ORCALOADREPORT_UTILIZATIONENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=519,
)

_ORCALOADREPORT_REQUESTCOSTENTRY.containing_type = _ORCALOADREPORT
_ORCALOADREPORT_UTILIZATIONENTRY.containing_type = _ORCALOADREPORT
_ORCALOADREPORT.fields_by_name['request_cost'].message_type = _ORCALOADREPORT_REQUESTCOSTENTRY
_ORCALOADREPORT.fields_by_name['utilization'].message_type = _ORCALOADREPORT_UTILIZATIONENTRY
DESCRIPTOR.message_types_by_name['OrcaLoadReport'] = _ORCALOADREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrcaLoadReport = _reflection.GeneratedProtocolMessageType('OrcaLoadReport', (_message.Message,), {

  'RequestCostEntry' : _reflection.GeneratedProtocolMessageType('RequestCostEntry', (_message.Message,), {
    'DESCRIPTOR' : _ORCALOADREPORT_REQUESTCOSTENTRY,
    '__module__' : 'udpa.data.orca.v1.orca_load_report_pb2'
    # @@protoc_insertion_point(class_scope:udpa.data.orca.v1.OrcaLoadReport.RequestCostEntry)
    })
  ,

  'UtilizationEntry' : _reflection.GeneratedProtocolMessageType('UtilizationEntry', (_message.Message,), {
    'DESCRIPTOR' : _ORCALOADREPORT_UTILIZATIONENTRY,
    '__module__' : 'udpa.data.orca.v1.orca_load_report_pb2'
    # @@protoc_insertion_point(class_scope:udpa.data.orca.v1.OrcaLoadReport.UtilizationEntry)
    })
  ,
  'DESCRIPTOR' : _ORCALOADREPORT,
  '__module__' : 'udpa.data.orca.v1.orca_load_report_pb2'
  # @@protoc_insertion_point(class_scope:udpa.data.orca.v1.OrcaLoadReport)
  })
_sym_db.RegisterMessage(OrcaLoadReport)
_sym_db.RegisterMessage(OrcaLoadReport.RequestCostEntry)
_sym_db.RegisterMessage(OrcaLoadReport.UtilizationEntry)


DESCRIPTOR._options = None
_ORCALOADREPORT_REQUESTCOSTENTRY._options = None
_ORCALOADREPORT_UTILIZATIONENTRY._options = None
_ORCALOADREPORT.fields_by_name['cpu_utilization']._options = None
_ORCALOADREPORT.fields_by_name['mem_utilization']._options = None
_ORCALOADREPORT.fields_by_name['utilization']._options = None
# @@protoc_insertion_point(module_scope)
