# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencensus/proto/agent/metrics/v1/metrics_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencensus.proto.agent.common.v1 import common_pb2 as opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2
from opencensus.proto.metrics.v1 import metrics_pb2 as opencensus_dot_proto_dot_metrics_dot_v1_dot_metrics__pb2
from opencensus.proto.resource.v1 import resource_pb2 as opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencensus/proto/agent/metrics/v1/metrics_service.proto',
  package='opencensus.proto.agent.metrics.v1',
  syntax='proto3',
  serialized_options=b'\n$io.opencensus.proto.agent.metrics.v1B\023MetricsServiceProtoP\001ZJgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/metrics/v1\352\002!OpenCensus.Proto.Agent.Metrics.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7opencensus/proto/agent/metrics/v1/metrics_service.proto\x12!opencensus.proto.agent.metrics.v1\x1a-opencensus/proto/agent/common/v1/common.proto\x1a)opencensus/proto/metrics/v1/metrics.proto\x1a+opencensus/proto/resource/v1/resource.proto\"\xc3\x01\n\x1b\x45xportMetricsServiceRequest\x12\x34\n\x04node\x18\x01 \x01(\x0b\x32&.opencensus.proto.agent.common.v1.Node\x12\x34\n\x07metrics\x18\x02 \x03(\x0b\x32#.opencensus.proto.metrics.v1.Metric\x12\x38\n\x08resource\x18\x03 \x01(\x0b\x32&.opencensus.proto.resource.v1.Resource\"\x1e\n\x1c\x45xportMetricsServiceResponse2\xa2\x01\n\x0eMetricsService\x12\x8f\x01\n\x06\x45xport\x12>.opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest\x1a?.opencensus.proto.agent.metrics.v1.ExportMetricsServiceResponse\"\x00(\x01\x30\x01\x42\xad\x01\n$io.opencensus.proto.agent.metrics.v1B\x13MetricsServiceProtoP\x01ZJgithub.com/census-instrumentation/opencensus-proto/gen-go/agent/metrics/v1\xea\x02!OpenCensus.Proto.Agent.Metrics.V1b\x06proto3'
  ,
  dependencies=[opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,opencensus_dot_proto_dot_metrics_dot_v1_dot_metrics__pb2.DESCRIPTOR,opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2.DESCRIPTOR,])




_EXPORTMETRICSSERVICEREQUEST = _descriptor.Descriptor(
  name='ExportMetricsServiceRequest',
  full_name='opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=425,
)


_EXPORTMETRICSSERVICERESPONSE = _descriptor.Descriptor(
  name='ExportMetricsServiceResponse',
  full_name='opencensus.proto.agent.metrics.v1.ExportMetricsServiceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=457,
)

_EXPORTMETRICSSERVICEREQUEST.fields_by_name['node'].message_type = opencensus_dot_proto_dot_agent_dot_common_dot_v1_dot_common__pb2._NODE
_EXPORTMETRICSSERVICEREQUEST.fields_by_name['metrics'].message_type = opencensus_dot_proto_dot_metrics_dot_v1_dot_metrics__pb2._METRIC
_EXPORTMETRICSSERVICEREQUEST.fields_by_name['resource'].message_type = opencensus_dot_proto_dot_resource_dot_v1_dot_resource__pb2._RESOURCE
DESCRIPTOR.message_types_by_name['ExportMetricsServiceRequest'] = _EXPORTMETRICSSERVICEREQUEST
DESCRIPTOR.message_types_by_name['ExportMetricsServiceResponse'] = _EXPORTMETRICSSERVICERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportMetricsServiceRequest = _reflection.GeneratedProtocolMessageType('ExportMetricsServiceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTMETRICSSERVICEREQUEST,
  '__module__' : 'opencensus.proto.agent.metrics.v1.metrics_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.metrics.v1.ExportMetricsServiceRequest)
  })
_sym_db.RegisterMessage(ExportMetricsServiceRequest)

ExportMetricsServiceResponse = _reflection.GeneratedProtocolMessageType('ExportMetricsServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTMETRICSSERVICERESPONSE,
  '__module__' : 'opencensus.proto.agent.metrics.v1.metrics_service_pb2'
  # @@protoc_insertion_point(class_scope:opencensus.proto.agent.metrics.v1.ExportMetricsServiceResponse)
  })
_sym_db.RegisterMessage(ExportMetricsServiceResponse)


DESCRIPTOR._options = None

_METRICSSERVICE = _descriptor.ServiceDescriptor(
  name='MetricsService',
  full_name='opencensus.proto.agent.metrics.v1.MetricsService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=460,
  serialized_end=622,
  methods=[
  _descriptor.MethodDescriptor(
    name='Export',
    full_name='opencensus.proto.agent.metrics.v1.MetricsService.Export',
    index=0,
    containing_service=None,
    input_type=_EXPORTMETRICSSERVICEREQUEST,
    output_type=_EXPORTMETRICSSERVICERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METRICSSERVICE)

DESCRIPTOR.services_by_name['MetricsService'] = _METRICSSERVICE

# @@protoc_insertion_point(module_scope)
