# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/brotli/compressor/v3/brotli.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/compression/brotli/compressor/v3/brotli.proto',
  package='envoy.extensions.compression.brotli.compressor.v3',
  syntax='proto3',
  serialized_options=b'\n?io.envoyproxy.envoy.extensions.compression.brotli.compressor.v3B\013BrotliProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>envoy/extensions/compression/brotli/compressor/v3/brotli.proto\x12\x31\x65nvoy.extensions.compression.brotli.compressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xcf\x03\n\x06\x42rotli\x12\x36\n\x07quality\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x0b\x12\x65\n\x0c\x65ncoder_mode\x18\x02 \x01(\x0e\x32\x45.envoy.extensions.compression.brotli.compressor.v3.Brotli.EncoderModeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x18(\n\x12\x41\n\x10input_block_bits\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x18(\x10\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \x12(\n disable_literal_context_modeling\x18\x06 \x01(\x08\";\n\x0b\x45ncoderMode\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0b\n\x07GENERIC\x10\x01\x12\x08\n\x04TEXT\x10\x02\x12\x08\n\x04\x46ONT\x10\x03\x42X\n?io.envoyproxy.envoy.extensions.compression.brotli.compressor.v3B\x0b\x42rotliProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_BROTLI_ENCODERMODE = _descriptor.EnumDescriptor(
  name='EncoderMode',
  full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.EncoderMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FONT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=610,
  serialized_end=669,
)
_sym_db.RegisterEnumDescriptor(_BROTLI_ENCODERMODE)


_BROTLI = _descriptor.Descriptor(
  name='Brotli',
  full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quality', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.quality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002\030\013', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoder_mode', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.encoder_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.window_bits', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\030(\n', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_block_bits', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.input_block_bits', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\030(\020', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.chunk_size', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_literal_context_modeling', full_name='envoy.extensions.compression.brotli.compressor.v3.Brotli.disable_literal_context_modeling', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BROTLI_ENCODERMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=669,
)

_BROTLI.fields_by_name['quality'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BROTLI.fields_by_name['encoder_mode'].enum_type = _BROTLI_ENCODERMODE
_BROTLI.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BROTLI.fields_by_name['input_block_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BROTLI.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_BROTLI_ENCODERMODE.containing_type = _BROTLI
DESCRIPTOR.message_types_by_name['Brotli'] = _BROTLI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Brotli = _reflection.GeneratedProtocolMessageType('Brotli', (_message.Message,), {
  'DESCRIPTOR' : _BROTLI,
  '__module__' : 'envoy.extensions.compression.brotli.compressor.v3.brotli_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.compression.brotli.compressor.v3.Brotli)
  })
_sym_db.RegisterMessage(Brotli)


DESCRIPTOR._options = None
_BROTLI.fields_by_name['quality']._options = None
_BROTLI.fields_by_name['encoder_mode']._options = None
_BROTLI.fields_by_name['window_bits']._options = None
_BROTLI.fields_by_name['input_block_bits']._options = None
_BROTLI.fields_by_name['chunk_size']._options = None
# @@protoc_insertion_point(module_scope)
