# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/tracers/xray/v4alpha/xray.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import address_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2
from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/tracers/xray/v4alpha/xray.proto',
  package='envoy.extensions.tracers.xray.v4alpha',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.extensions.tracers.xray.v4alphaB\tXrayProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0envoy/extensions/tracers/xray/v4alpha/xray.proto\x12%envoy.extensions.tracers.xray.v4alpha\x1a\'envoy/config/core/v4alpha/address.proto\x1a$envoy/config/core/v4alpha/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb5\x03\n\nXRayConfig\x12\x41\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32(.envoy.config.core.v4alpha.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x45\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSource\x12W\n\x0esegment_fields\x18\x04 \x01(\x0b\x32?.envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields\x1a|\n\rSegmentFields\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12$\n\x03\x61ws\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:5\x9a\xc5\x88\x1e\x30\n.envoy.config.trace.v3.XRayConfig.SegmentFields:\'\x9a\xc5\x88\x1e\"\n envoy.config.trace.v3.XRayConfigBJ\n3io.envoyproxy.envoy.extensions.tracers.xray.v4alphaB\tXrayProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_XRAYCONFIG_SEGMENTFIELDS = _descriptor.Descriptor(
  name='SegmentFields',
  full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields.origin', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields.aws', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.trace.v3.XRayConfig.SegmentFields',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=688,
)

_XRAYCONFIG = _descriptor.Descriptor(
  name='XRayConfig',
  full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='daemon_endpoint', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.daemon_endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_name', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.segment_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_rule_manifest', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.sampling_rule_manifest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='segment_fields', full_name='envoy.extensions.tracers.xray.v4alpha.XRayConfig.segment_fields', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_XRAYCONFIG_SEGMENTFIELDS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.config.trace.v3.XRayConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=729,
)

_XRAYCONFIG_SEGMENTFIELDS.fields_by_name['aws'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_XRAYCONFIG_SEGMENTFIELDS.containing_type = _XRAYCONFIG
_XRAYCONFIG.fields_by_name['daemon_endpoint'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._SOCKETADDRESS
_XRAYCONFIG.fields_by_name['sampling_rule_manifest'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_XRAYCONFIG.fields_by_name['segment_fields'].message_type = _XRAYCONFIG_SEGMENTFIELDS
DESCRIPTOR.message_types_by_name['XRayConfig'] = _XRAYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

XRayConfig = _reflection.GeneratedProtocolMessageType('XRayConfig', (_message.Message,), {

  'SegmentFields' : _reflection.GeneratedProtocolMessageType('SegmentFields', (_message.Message,), {
    'DESCRIPTOR' : _XRAYCONFIG_SEGMENTFIELDS,
    '__module__' : 'envoy.extensions.tracers.xray.v4alpha.xray_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.xray.v4alpha.XRayConfig.SegmentFields)
    })
  ,
  'DESCRIPTOR' : _XRAYCONFIG,
  '__module__' : 'envoy.extensions.tracers.xray.v4alpha.xray_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.xray.v4alpha.XRayConfig)
  })
_sym_db.RegisterMessage(XRayConfig)
_sym_db.RegisterMessage(XRayConfig.SegmentFields)


DESCRIPTOR._options = None
_XRAYCONFIG_SEGMENTFIELDS._options = None
_XRAYCONFIG.fields_by_name['segment_name']._options = None
_XRAYCONFIG._options = None
# @@protoc_insertion_point(module_scope)
