# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/ratelimit/ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/ratelimit/ratelimit.proto',
  package='envoy.api.v2.ratelimit',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.api.v2.ratelimitB\016RatelimitProtoP\001\362\230\376\217\005&\022$envoy.extensions.common.ratelimit.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&envoy/api/v2/ratelimit/ratelimit.proto\x12\x16\x65nvoy.api.v2.ratelimit\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9a\x01\n\x13RateLimitDescriptor\x12L\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x31.envoy.api.v2.ratelimit.RateLimitDescriptor.EntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x35\n\x05\x45ntry\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x05value\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42l\n$io.envoyproxy.envoy.api.v2.ratelimitB\x0eRatelimitProtoP\x01\xf2\x98\xfe\x8f\x05&\x12$envoy.extensions.common.ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RATELIMITDESCRIPTOR_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.Entry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=309,
)

_RATELIMITDESCRIPTOR = _descriptor.Descriptor(
  name='RateLimitDescriptor',
  full_name='envoy.api.v2.ratelimit.RateLimitDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='envoy.api.v2.ratelimit.RateLimitDescriptor.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RATELIMITDESCRIPTOR_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=309,
)

_RATELIMITDESCRIPTOR_ENTRY.containing_type = _RATELIMITDESCRIPTOR
_RATELIMITDESCRIPTOR.fields_by_name['entries'].message_type = _RATELIMITDESCRIPTOR_ENTRY
DESCRIPTOR.message_types_by_name['RateLimitDescriptor'] = _RATELIMITDESCRIPTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RateLimitDescriptor = _reflection.GeneratedProtocolMessageType('RateLimitDescriptor', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _RATELIMITDESCRIPTOR_ENTRY,
    '__module__' : 'envoy.api.v2.ratelimit.ratelimit_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.ratelimit.RateLimitDescriptor.Entry)
    })
  ,
  'DESCRIPTOR' : _RATELIMITDESCRIPTOR,
  '__module__' : 'envoy.api.v2.ratelimit.ratelimit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.ratelimit.RateLimitDescriptor)
  })
_sym_db.RegisterMessage(RateLimitDescriptor)
_sym_db.RegisterMessage(RateLimitDescriptor.Entry)


DESCRIPTOR._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['key']._options = None
_RATELIMITDESCRIPTOR_ENTRY.fields_by_name['value']._options = None
_RATELIMITDESCRIPTOR.fields_by_name['entries']._options = None
# @@protoc_insertion_point(module_scope)
