# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/socket_option.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/socket_option.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\021SocketOptionProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/config/core/v3/socket_option.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x0cSocketOption\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\x03\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12\x13\n\tbuf_value\x18\x05 \x01(\x0cH\x00\x12G\n\x05state\x18\x06 \x01(\x0e\x32..envoy.config.core.v3.SocketOption.SocketStateB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x0bSocketState\x12\x11\n\rSTATE_PREBIND\x10\x00\x12\x0f\n\x0bSTATE_BOUND\x10\x01\x12\x13\n\x0fSTATE_LISTENING\x10\x02:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.SocketOptionB\x0c\n\x05value\x12\x03\xf8\x42\x01\x42\x41\n\"io.envoyproxy.envoy.config.core.v3B\x11SocketOptionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_SOCKETOPTION_SOCKETSTATE = _descriptor.EnumDescriptor(
  name='SocketState',
  full_name='envoy.config.core.v3.SocketOption.SocketState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_PREBIND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_BOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_LISTENING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=339,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_SOCKETOPTION_SOCKETSTATE)


_SOCKETOPTION = _descriptor.Descriptor(
  name='SocketOption',
  full_name='envoy.config.core.v3.SocketOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='envoy.config.core.v3.SocketOption.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='envoy.config.core.v3.SocketOption.level', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.SocketOption.name', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='envoy.config.core.v3.SocketOption.int_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buf_value', full_name='envoy.config.core.v3.SocketOption.buf_value', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='envoy.config.core.v3.SocketOption.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOCKETOPTION_SOCKETSTATE,
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.SocketOption',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='envoy.config.core.v3.SocketOption.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=158,
  serialized_end=462,
)

_SOCKETOPTION.fields_by_name['state'].enum_type = _SOCKETOPTION_SOCKETSTATE
_SOCKETOPTION_SOCKETSTATE.containing_type = _SOCKETOPTION
_SOCKETOPTION.oneofs_by_name['value'].fields.append(
  _SOCKETOPTION.fields_by_name['int_value'])
_SOCKETOPTION.fields_by_name['int_value'].containing_oneof = _SOCKETOPTION.oneofs_by_name['value']
_SOCKETOPTION.oneofs_by_name['value'].fields.append(
  _SOCKETOPTION.fields_by_name['buf_value'])
_SOCKETOPTION.fields_by_name['buf_value'].containing_oneof = _SOCKETOPTION.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['SocketOption'] = _SOCKETOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SocketOption = _reflection.GeneratedProtocolMessageType('SocketOption', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTION,
  '__module__' : 'envoy.config.core.v3.socket_option_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.SocketOption)
  })
_sym_db.RegisterMessage(SocketOption)


DESCRIPTOR._options = None
_SOCKETOPTION.oneofs_by_name['value']._options = None
_SOCKETOPTION.fields_by_name['state']._options = None
_SOCKETOPTION._options = None
# @@protoc_insertion_point(module_scope)
