# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/event_reporting/v2alpha/event_reporting_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/event_reporting/v2alpha/event_reporting_service.proto',
  package='envoy.service.event_reporting.v2alpha',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\032EventReportingServiceProtoP\001\210\001\001\362\230\376\217\005\"\022 envoy.service.event_reporting.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/service/event_reporting/v2alpha/event_reporting_service.proto\x12%envoy.service.event_reporting.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x13StreamEventsRequest\x12Y\n\nidentifier\x18\x01 \x01(\x0b\x32\x45.envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier\x12.\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x16\n\x14StreamEventsResponse2\xa7\x01\n\x15\x45ventReportingService\x12\x8d\x01\n\x0cStreamEvents\x12:.envoy.service.event_reporting.v2alpha.StreamEventsRequest\x1a;.envoy.service.event_reporting.v2alpha.StreamEventsResponse\"\x00(\x01\x30\x01\x42\x86\x01\n3io.envoyproxy.envoy.service.event_reporting.v2alphaB\x1a\x45ventReportingServiceProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\"\x12 envoy.service.event_reporting.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMEVENTSREQUEST_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=479,
)

_STREAMEVENTSREQUEST = _descriptor.Descriptor(
  name='StreamEventsRequest',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='envoy.service.event_reporting.v2alpha.StreamEventsRequest.events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEVENTSREQUEST_IDENTIFIER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=479,
)


_STREAMEVENTSRESPONSE = _descriptor.Descriptor(
  name='StreamEventsResponse',
  full_name='envoy.service.event_reporting.v2alpha.StreamEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=503,
)

_STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_STREAMEVENTSREQUEST_IDENTIFIER.containing_type = _STREAMEVENTSREQUEST
_STREAMEVENTSREQUEST.fields_by_name['identifier'].message_type = _STREAMEVENTSREQUEST_IDENTIFIER
_STREAMEVENTSREQUEST.fields_by_name['events'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['StreamEventsRequest'] = _STREAMEVENTSREQUEST
DESCRIPTOR.message_types_by_name['StreamEventsResponse'] = _STREAMEVENTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamEventsRequest = _reflection.GeneratedProtocolMessageType('StreamEventsRequest', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEVENTSREQUEST_IDENTIFIER,
    '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsRequest.Identifier)
    })
  ,
  'DESCRIPTOR' : _STREAMEVENTSREQUEST,
  '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsRequest)
  })
_sym_db.RegisterMessage(StreamEventsRequest)
_sym_db.RegisterMessage(StreamEventsRequest.Identifier)

StreamEventsResponse = _reflection.GeneratedProtocolMessageType('StreamEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEVENTSRESPONSE,
  '__module__' : 'envoy.service.event_reporting.v2alpha.event_reporting_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.event_reporting.v2alpha.StreamEventsResponse)
  })
_sym_db.RegisterMessage(StreamEventsResponse)


DESCRIPTOR._options = None
_STREAMEVENTSREQUEST_IDENTIFIER.fields_by_name['node']._options = None
_STREAMEVENTSREQUEST.fields_by_name['events']._options = None

_EVENTREPORTINGSERVICE = _descriptor.ServiceDescriptor(
  name='EventReportingService',
  full_name='envoy.service.event_reporting.v2alpha.EventReportingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=506,
  serialized_end=673,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamEvents',
    full_name='envoy.service.event_reporting.v2alpha.EventReportingService.StreamEvents',
    index=0,
    containing_service=None,
    input_type=_STREAMEVENTSREQUEST,
    output_type=_STREAMEVENTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EVENTREPORTINGSERVICE)

DESCRIPTOR.services_by_name['EventReportingService'] = _EVENTREPORTINGSERVICE

# @@protoc_insertion_point(module_scope)
