# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import http_uri_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto',
  package='envoy.extensions.filters.http.jwt_authn.v4alpha',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v4alphaB\013ConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/extensions/filters/http/jwt_authn/v4alpha/config.proto\x12/envoy.extensions.filters.http.jwt_authn.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a(envoy/config/core/v4alpha/http_uri.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xfc\x03\n\x0bJwtProvider\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\x12R\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32;.envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwksH\x00\x12;\n\nlocal_jwks\x18\x04 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12P\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12+\n\x16\x66orward_payload_header\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\t\x12\x1a\n\x12\x63lock_skew_seconds\x18\n \x01(\r:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.http.jwt_authn.v3.JwtProviderB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"\xb3\x01\n\nRemoteJwks\x12\x34\n\x08http_uri\x18\x01 \x01(\x0b\x32\".envoy.config.core.v4alpha.HttpUri\x12\x31\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration:<\x9a\xc5\x88\x1e\x37\n5envoy.extensions.filters.http.jwt_authn.v3.RemoteJwks\"\x88\x01\n\tJwtHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12!\n\x0cvalue_prefix\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:;\x9a\xc5\x88\x1e\x36\n4envoy.extensions.filters.http.jwt_authn.v3.JwtHeader\"\x8a\x01\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.jwt_authn.v3.ProviderWithAudiences\"\x91\x04\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12h\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x46.envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiencesH\x00\x12]\n\x0crequires_any\x18\x03 \x01(\x0b\x32\x45.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrListH\x00\x12^\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x46.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementB\x0f\n\rrequires_type\"\xbf\x01\n\x14JwtRequirementOrList\x12_\n\x0crequirements\x18\x01 \x03(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementOrList\"\xc1\x01\n\x15JwtRequirementAndList\x12_\n\x0crequirements\x18\x01 \x03(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementAndList\"\xa3\x02\n\x0fRequirementRule\x12?\n\x05match\x18\x01 \x01(\x0b\x32&.envoy.config.route.v4alpha.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12S\n\x08requires\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementH\x00\x12#\n\x10requirement_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.http.jwt_authn.v3.RequirementRuleB\x12\n\x10requirement_type\"\xbf\x02\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12`\n\x08requires\x18\x03 \x03(\x0b\x32N.envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry\x1ap\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement:\x02\x38\x01:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule\"\xe5\x05\n\x11JwtAuthentication\x12\x64\n\tproviders\x18\x01 \x03(\x0b\x32Q.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry\x12O\n\x05rules\x18\x02 \x03(\x0b\x32@.envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule\x12\\\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32@.envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x12o\n\x0frequirement_map\x18\x05 \x03(\x0b\x32V.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry\x1an\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12K\n\x05value\x18\x02 \x01(\x0b\x32<.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider:\x02\x38\x01\x1av\n\x13RequirementMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication\"\xb2\x01\n\x0ePerRouteConfig\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12#\n\x10requirement_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:@\x9a\xc5\x88\x1e;\n9envoy.extensions.filters.http.jwt_authn.v3.PerRouteConfigB\x1c\n\x15requirement_specifier\x12\x03\xf8\x42\x01\x42V\n=io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v4alphaB\x0b\x43onfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_JWTPROVIDER = _descriptor.Descriptor(
  name='JwtProvider',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_jwks', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.remote_jwks', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_jwks', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.local_jwks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_headers', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.from_headers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_params', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.from_params', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_payload_header', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.forward_payload_header', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_in_metadata', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.payload_in_metadata', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_skew_seconds', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.clock_skew_seconds', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.http.jwt_authn.v3.JwtProvider',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='jwks_source_specifier', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider.jwks_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=397,
  serialized_end=905,
)


_REMOTEJWKS = _descriptor.Descriptor(
  name='RemoteJwks',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_uri', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks.http_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_duration', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks.cache_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0367\n5envoy.extensions.filters.http.jwt_authn.v3.RemoteJwks',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1087,
)


_JWTHEADER = _descriptor.Descriptor(
  name='JwtHeader',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_prefix', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader.value_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0366\n4envoy.extensions.filters.http.jwt_authn.v3.JwtHeader',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1090,
  serialized_end=1226,
)


_PROVIDERWITHAUDIENCES = _descriptor.Descriptor(
  name='ProviderWithAudiences',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.jwt_authn.v3.ProviderWithAudiences',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1367,
)


_JWTREQUIREMENT = _descriptor.Descriptor(
  name='JwtRequirement',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_and_audiences', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.provider_and_audiences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_any', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_any', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_all', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_all', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing_or_failed', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.allow_missing_or_failed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.allow_missing', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.jwt_authn.v3.JwtRequirement',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requires_type', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement.requires_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1370,
  serialized_end=1899,
)


_JWTREQUIREMENTORLIST = _descriptor.Descriptor(
  name='JwtRequirementOrList',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementOrList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=2093,
)


_JWTREQUIREMENTANDLIST = _descriptor.Descriptor(
  name='JwtRequirementAndList',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementAndList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2289,
)


_REQUIREMENTRULE = _descriptor.Descriptor(
  name='RequirementRule',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requirement_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.http.jwt_authn.v3.RequirementRule',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requirement_type', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule.requirement_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2292,
  serialized_end=2583,
)


_FILTERSTATERULE_REQUIRESENTRY = _descriptor.Descriptor(
  name='RequiresEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2838,
)

_FILTERSTATERULE = _descriptor.Descriptor(
  name='FilterStateRule',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.requires', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTERSTATERULE_REQUIRESENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2586,
  serialized_end=2905,
)


_JWTAUTHENTICATION_PROVIDERSENTRY = _descriptor.Descriptor(
  name='ProvidersEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3350,
  serialized_end=3460,
)

_JWTAUTHENTICATION_REQUIREMENTMAPENTRY = _descriptor.Descriptor(
  name='RequirementMapEntry',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3462,
  serialized_end=3580,
)

_JWTAUTHENTICATION = _descriptor.Descriptor(
  name='JwtAuthentication',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_rules', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.filter_state_rules', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bypass_cors_preflight', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.bypass_cors_preflight', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_map', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.requirement_map', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JWTAUTHENTICATION_PROVIDERSENTRY, _JWTAUTHENTICATION_REQUIREMENTMAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2908,
  serialized_end=3649,
)


_PERROUTECONFIG = _descriptor.Descriptor(
  name='PerRouteConfig',
  full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requirement_name', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.requirement_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.extensions.filters.http.jwt_authn.v3.PerRouteConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requirement_specifier', full_name='envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig.requirement_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=3652,
  serialized_end=3830,
)

_JWTPROVIDER.fields_by_name['remote_jwks'].message_type = _REMOTEJWKS
_JWTPROVIDER.fields_by_name['local_jwks'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_JWTPROVIDER.fields_by_name['from_headers'].message_type = _JWTHEADER
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['remote_jwks'])
_JWTPROVIDER.fields_by_name['remote_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['local_jwks'])
_JWTPROVIDER.fields_by_name['local_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_REMOTEJWKS.fields_by_name['http_uri'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_http__uri__pb2._HTTPURI
_REMOTEJWKS.fields_by_name['cache_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].message_type = _PROVIDERWITHAUDIENCES
_JWTREQUIREMENT.fields_by_name['requires_any'].message_type = _JWTREQUIREMENTORLIST
_JWTREQUIREMENT.fields_by_name['requires_all'].message_type = _JWTREQUIREMENTANDLIST
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.fields_by_name['allow_missing'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_name'])
_JWTREQUIREMENT.fields_by_name['provider_name'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_and_audiences'])
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_any'])
_JWTREQUIREMENT.fields_by_name['requires_any'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_all'])
_JWTREQUIREMENT.fields_by_name['requires_all'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'])
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing'])
_JWTREQUIREMENT.fields_by_name['allow_missing'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENTORLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_JWTREQUIREMENTANDLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.fields_by_name['match'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._ROUTEMATCH
_REQUIREMENTRULE.fields_by_name['requires'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.oneofs_by_name['requirement_type'].fields.append(
  _REQUIREMENTRULE.fields_by_name['requires'])
_REQUIREMENTRULE.fields_by_name['requires'].containing_oneof = _REQUIREMENTRULE.oneofs_by_name['requirement_type']
_REQUIREMENTRULE.oneofs_by_name['requirement_type'].fields.append(
  _REQUIREMENTRULE.fields_by_name['requirement_name'])
_REQUIREMENTRULE.fields_by_name['requirement_name'].containing_oneof = _REQUIREMENTRULE.oneofs_by_name['requirement_type']
_FILTERSTATERULE_REQUIRESENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.containing_type = _FILTERSTATERULE
_FILTERSTATERULE.fields_by_name['requires'].message_type = _FILTERSTATERULE_REQUIRESENTRY
_JWTAUTHENTICATION_PROVIDERSENTRY.fields_by_name['value'].message_type = _JWTPROVIDER
_JWTAUTHENTICATION_PROVIDERSENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION.fields_by_name['providers'].message_type = _JWTAUTHENTICATION_PROVIDERSENTRY
_JWTAUTHENTICATION.fields_by_name['rules'].message_type = _REQUIREMENTRULE
_JWTAUTHENTICATION.fields_by_name['filter_state_rules'].message_type = _FILTERSTATERULE
_JWTAUTHENTICATION.fields_by_name['requirement_map'].message_type = _JWTAUTHENTICATION_REQUIREMENTMAPENTRY
_PERROUTECONFIG.oneofs_by_name['requirement_specifier'].fields.append(
  _PERROUTECONFIG.fields_by_name['disabled'])
_PERROUTECONFIG.fields_by_name['disabled'].containing_oneof = _PERROUTECONFIG.oneofs_by_name['requirement_specifier']
_PERROUTECONFIG.oneofs_by_name['requirement_specifier'].fields.append(
  _PERROUTECONFIG.fields_by_name['requirement_name'])
_PERROUTECONFIG.fields_by_name['requirement_name'].containing_oneof = _PERROUTECONFIG.oneofs_by_name['requirement_specifier']
DESCRIPTOR.message_types_by_name['JwtProvider'] = _JWTPROVIDER
DESCRIPTOR.message_types_by_name['RemoteJwks'] = _REMOTEJWKS
DESCRIPTOR.message_types_by_name['JwtHeader'] = _JWTHEADER
DESCRIPTOR.message_types_by_name['ProviderWithAudiences'] = _PROVIDERWITHAUDIENCES
DESCRIPTOR.message_types_by_name['JwtRequirement'] = _JWTREQUIREMENT
DESCRIPTOR.message_types_by_name['JwtRequirementOrList'] = _JWTREQUIREMENTORLIST
DESCRIPTOR.message_types_by_name['JwtRequirementAndList'] = _JWTREQUIREMENTANDLIST
DESCRIPTOR.message_types_by_name['RequirementRule'] = _REQUIREMENTRULE
DESCRIPTOR.message_types_by_name['FilterStateRule'] = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtAuthentication'] = _JWTAUTHENTICATION
DESCRIPTOR.message_types_by_name['PerRouteConfig'] = _PERROUTECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JwtProvider = _reflection.GeneratedProtocolMessageType('JwtProvider', (_message.Message,), {
  'DESCRIPTOR' : _JWTPROVIDER,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtProvider)
  })
_sym_db.RegisterMessage(JwtProvider)

RemoteJwks = _reflection.GeneratedProtocolMessageType('RemoteJwks', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEJWKS,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.RemoteJwks)
  })
_sym_db.RegisterMessage(RemoteJwks)

JwtHeader = _reflection.GeneratedProtocolMessageType('JwtHeader', (_message.Message,), {
  'DESCRIPTOR' : _JWTHEADER,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtHeader)
  })
_sym_db.RegisterMessage(JwtHeader)

ProviderWithAudiences = _reflection.GeneratedProtocolMessageType('ProviderWithAudiences', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERWITHAUDIENCES,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.ProviderWithAudiences)
  })
_sym_db.RegisterMessage(ProviderWithAudiences)

JwtRequirement = _reflection.GeneratedProtocolMessageType('JwtRequirement', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENT,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirement)
  })
_sym_db.RegisterMessage(JwtRequirement)

JwtRequirementOrList = _reflection.GeneratedProtocolMessageType('JwtRequirementOrList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTORLIST,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementOrList)
  })
_sym_db.RegisterMessage(JwtRequirementOrList)

JwtRequirementAndList = _reflection.GeneratedProtocolMessageType('JwtRequirementAndList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTANDLIST,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtRequirementAndList)
  })
_sym_db.RegisterMessage(JwtRequirementAndList)

RequirementRule = _reflection.GeneratedProtocolMessageType('RequirementRule', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENTRULE,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.RequirementRule)
  })
_sym_db.RegisterMessage(RequirementRule)

FilterStateRule = _reflection.GeneratedProtocolMessageType('FilterStateRule', (_message.Message,), {

  'RequiresEntry' : _reflection.GeneratedProtocolMessageType('RequiresEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTERSTATERULE_REQUIRESENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule.RequiresEntry)
    })
  ,
  'DESCRIPTOR' : _FILTERSTATERULE,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.FilterStateRule)
  })
_sym_db.RegisterMessage(FilterStateRule)
_sym_db.RegisterMessage(FilterStateRule.RequiresEntry)

JwtAuthentication = _reflection.GeneratedProtocolMessageType('JwtAuthentication', (_message.Message,), {

  'ProvidersEntry' : _reflection.GeneratedProtocolMessageType('ProvidersEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_PROVIDERSENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.ProvidersEntry)
    })
  ,

  'RequirementMapEntry' : _reflection.GeneratedProtocolMessageType('RequirementMapEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_REQUIREMENTMAPENTRY,
    '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication.RequirementMapEntry)
    })
  ,
  'DESCRIPTOR' : _JWTAUTHENTICATION,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.JwtAuthentication)
  })
_sym_db.RegisterMessage(JwtAuthentication)
_sym_db.RegisterMessage(JwtAuthentication.ProvidersEntry)
_sym_db.RegisterMessage(JwtAuthentication.RequirementMapEntry)

PerRouteConfig = _reflection.GeneratedProtocolMessageType('PerRouteConfig', (_message.Message,), {
  'DESCRIPTOR' : _PERROUTECONFIG,
  '__module__' : 'envoy.extensions.filters.http.jwt_authn.v4alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.jwt_authn.v4alpha.PerRouteConfig)
  })
_sym_db.RegisterMessage(PerRouteConfig)


DESCRIPTOR._options = None
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier']._options = None
_JWTPROVIDER.fields_by_name['forward_payload_header']._options = None
_JWTPROVIDER._options = None
_REMOTEJWKS._options = None
_JWTHEADER.fields_by_name['name']._options = None
_JWTHEADER.fields_by_name['value_prefix']._options = None
_JWTHEADER._options = None
_PROVIDERWITHAUDIENCES._options = None
_JWTREQUIREMENT._options = None
_JWTREQUIREMENTORLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTORLIST._options = None
_JWTREQUIREMENTANDLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTANDLIST._options = None
_REQUIREMENTRULE.fields_by_name['match']._options = None
_REQUIREMENTRULE.fields_by_name['requirement_name']._options = None
_REQUIREMENTRULE._options = None
_FILTERSTATERULE_REQUIRESENTRY._options = None
_FILTERSTATERULE.fields_by_name['name']._options = None
_FILTERSTATERULE._options = None
_JWTAUTHENTICATION_PROVIDERSENTRY._options = None
_JWTAUTHENTICATION_REQUIREMENTMAPENTRY._options = None
_JWTAUTHENTICATION._options = None
_PERROUTECONFIG.oneofs_by_name['requirement_specifier']._options = None
_PERROUTECONFIG.fields_by_name['disabled']._options = None
_PERROUTECONFIG.fields_by_name['requirement_name']._options = None
_PERROUTECONFIG._options = None
# @@protoc_insertion_point(module_scope)
