# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto',
  package='envoy.extensions.filters.http.grpc_json_transcoder.v3',
  syntax='proto3',
  serialized_options=b'\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\017TranscoderProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFenvoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto\x12\x35\x65nvoy.extensions.filters.http.grpc_json_transcoder.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc9\x07\n\x12GrpcJsonTranscoder\x12\x1a\n\x10proto_descriptor\x18\x01 \x01(\tH\x00\x12\x1e\n\x14proto_descriptor_bin\x18\x04 \x01(\x0cH\x00\x12\x10\n\x08services\x18\x02 \x03(\t\x12m\n\rprint_options\x18\x03 \x01(\x0b\x32V.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions\x12$\n\x1cmatch_incoming_request_route\x18\x05 \x01(\x08\x12 \n\x18ignored_query_parameters\x18\x06 \x03(\t\x12\x14\n\x0c\x61uto_mapping\x18\x07 \x01(\x08\x12\'\n\x1fignore_unknown_query_parameters\x18\x08 \x01(\x08\x12\x1b\n\x13\x63onvert_grpc_status\x18\t \x01(\x08\x12~\n\x11url_unescape_spec\x18\n \x01(\x0e\x32Y.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpecB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12&\n\x1estrict_http_request_validation\x18\x0b \x01(\x08\x1a\xe4\x01\n\x0cPrintOptions\x12\x16\n\x0e\x61\x64\x64_whitespace\x18\x01 \x01(\x08\x12%\n\x1d\x61lways_print_primitive_fields\x18\x02 \x01(\x08\x12\"\n\x1a\x61lways_print_enums_as_ints\x18\x03 \x01(\x08\x12\"\n\x1apreserve_proto_field_names\x18\x04 \x01(\x08:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions\"j\n\x0fUrlUnescapeSpec\x12\"\n\x1e\x41LL_CHARACTERS_EXCEPT_RESERVED\x10\x00\x12\x1f\n\x1b\x41LL_CHARACTERS_EXCEPT_SLASH\x10\x01\x12\x12\n\x0e\x41LL_CHARACTERS\x10\x02:@\x9a\xc5\x88\x1e;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoderB\x15\n\x0e\x64\x65scriptor_set\x12\x03\xf8\x42\x01\x42`\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\x0fTranscoderProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GRPCJSONTRANSCODER_URLUNESCAPESPEC = _descriptor.EnumDescriptor(
  name='UrlUnescapeSpec',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpec',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS_EXCEPT_RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS_EXCEPT_SLASH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHARACTERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=995,
  serialized_end=1101,
)
_sym_db.RegisterEnumDescriptor(_GRPCJSONTRANSCODER_URLUNESCAPESPEC)


_GRPCJSONTRANSCODER_PRINTOPTIONS = _descriptor.Descriptor(
  name='PrintOptions',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_whitespace', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.add_whitespace', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_print_primitive_fields', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.always_print_primitive_fields', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_print_enums_as_ints', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.always_print_enums_as_ints', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preserve_proto_field_names', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions.preserve_proto_field_names', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=765,
  serialized_end=993,
)

_GRPCJSONTRANSCODER = _descriptor.Descriptor(
  name='GrpcJsonTranscoder',
  full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proto_descriptor', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.proto_descriptor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_descriptor_bin', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.proto_descriptor_bin', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='services', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.services', index=2,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_options', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.print_options', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='match_incoming_request_route', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.match_incoming_request_route', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignored_query_parameters', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.ignored_query_parameters', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_mapping', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.auto_mapping', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore_unknown_query_parameters', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.ignore_unknown_query_parameters', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convert_grpc_status', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.convert_grpc_status', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_unescape_spec', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.url_unescape_spec', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strict_http_request_validation', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.strict_http_request_validation', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCJSONTRANSCODER_PRINTOPTIONS, ],
  enum_types=[
    _GRPCJSONTRANSCODER_URLUNESCAPESPEC,
  ],
  serialized_options=b'\232\305\210\036;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='descriptor_set', full_name='envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.descriptor_set',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=221,
  serialized_end=1190,
)

_GRPCJSONTRANSCODER_PRINTOPTIONS.containing_type = _GRPCJSONTRANSCODER
_GRPCJSONTRANSCODER.fields_by_name['print_options'].message_type = _GRPCJSONTRANSCODER_PRINTOPTIONS
_GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec'].enum_type = _GRPCJSONTRANSCODER_URLUNESCAPESPEC
_GRPCJSONTRANSCODER_URLUNESCAPESPEC.containing_type = _GRPCJSONTRANSCODER
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set'].fields.append(
  _GRPCJSONTRANSCODER.fields_by_name['proto_descriptor'])
_GRPCJSONTRANSCODER.fields_by_name['proto_descriptor'].containing_oneof = _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set'].fields.append(
  _GRPCJSONTRANSCODER.fields_by_name['proto_descriptor_bin'])
_GRPCJSONTRANSCODER.fields_by_name['proto_descriptor_bin'].containing_oneof = _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']
DESCRIPTOR.message_types_by_name['GrpcJsonTranscoder'] = _GRPCJSONTRANSCODER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GrpcJsonTranscoder = _reflection.GeneratedProtocolMessageType('GrpcJsonTranscoder', (_message.Message,), {

  'PrintOptions' : _reflection.GeneratedProtocolMessageType('PrintOptions', (_message.Message,), {
    'DESCRIPTOR' : _GRPCJSONTRANSCODER_PRINTOPTIONS,
    '__module__' : 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions)
    })
  ,
  'DESCRIPTOR' : _GRPCJSONTRANSCODER,
  '__module__' : 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder)
  })
_sym_db.RegisterMessage(GrpcJsonTranscoder)
_sym_db.RegisterMessage(GrpcJsonTranscoder.PrintOptions)


DESCRIPTOR._options = None
_GRPCJSONTRANSCODER_PRINTOPTIONS._options = None
_GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._options = None
_GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._options = None
_GRPCJSONTRANSCODER._options = None
# @@protoc_insertion_point(module_scope)
