# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/core/grpc_service.proto',
  package='envoy.api.v2.core',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.coreB\020GrpcServiceProtoP\001\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/api/v2/core/grpc_service.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x12\n\x0bGrpcService\x12>\n\nenvoy_grpc\x18\x01 \x01(\x0b\x32(.envoy.api.v2.core.GrpcService.EnvoyGrpcH\x00\x12@\n\x0bgoogle_grpc\x18\x02 \x01(\x0b\x32).envoy.api.v2.core.GrpcService.GoogleGrpcH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x10initial_metadata\x18\x05 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a*\n\tEnvoyGrpc\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\xcc\x0f\n\nGoogleGrpc\x12\x1b\n\ntarget_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12Y\n\x13\x63hannel_credentials\x18\x02 \x01(\x0b\x32<.envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials\x12S\n\x10\x63\x61ll_credentials\x18\x03 \x03(\x0b\x32\x39.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials\x12\x1c\n\x0bstat_prefix\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12 \n\x18\x63redentials_factory_name\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xb2\x01\n\x0eSslCredentials\x12\x31\n\nroot_certs\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x31\n\ncert_chain\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x1a\x18\n\x16GoogleLocalCredentials\x1a\x97\x02\n\x12\x43hannelCredentials\x12S\n\x0fssl_credentials\x18\x01 \x01(\x0b\x32\x38.envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentialsH\x00\x12\x30\n\x0egoogle_default\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12]\n\x11local_credentials\x18\x03 \x01(\x0b\x32@.envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentialsH\x00\x42\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\x9e\t\n\x0f\x43\x61llCredentials\x12\x16\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tH\x00\x12\x37\n\x15google_compute_engine\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x14google_refresh_token\x18\x03 \x01(\tH\x00\x12\x82\x01\n\x1aservice_account_jwt_access\x18\x04 \x01(\x0b\x32\\.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentialsH\x00\x12\x64\n\ngoogle_iam\x18\x05 \x01(\x0b\x32N.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentialsH\x00\x12n\n\x0b\x66rom_plugin\x18\x06 \x01(\x0b\x32W.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginH\x00\x12[\n\x0bsts_service\x18\x07 \x01(\x0b\x32\x44.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsServiceH\x00\x1aV\n\"ServiceAccountJWTAccessCredentials\x12\x10\n\x08json_key\x18\x01 \x01(\t\x12\x1e\n\x16token_lifetime_seconds\x18\x02 \x01(\x04\x1aO\n\x14GoogleIAMCredentials\x12\x1b\n\x13\x61uthorization_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthority_selector\x18\x02 \x01(\t\x1a\x99\x01\n\x1dMetadataCredentialsFromPlugin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\xff\x01\n\nStsService\x12\"\n\x1atoken_exchange_service_uri\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1c\n\x14requested_token_type\x18\x05 \x01(\t\x12#\n\x12subject_token_path\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x12subject_token_type\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x18\n\x10\x61\x63tor_token_path\x18\x08 \x01(\t\x12\x18\n\x10\x61\x63tor_token_type\x18\t \x01(\tB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x42\x17\n\x10target_specifier\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05\x42Y\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10GrpcServiceProtoP\x01\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_GRPCSERVICE_ENVOYGRPC = _descriptor.Descriptor(
  name='EnvoyGrpc',
  full_name='envoy.api.v2.core.GrpcService.EnvoyGrpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.api.v2.core.GrpcService.EnvoyGrpc.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=619,
)

_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS = _descriptor.Descriptor(
  name='SslCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_certs', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.root_certs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert_chain', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.cert_chain', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=947,
  serialized_end=1125,
)

_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS = _descriptor.Descriptor(
  name='GoogleLocalCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1151,
)

_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS = _descriptor.Descriptor(
  name='ChannelCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssl_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.ssl_credentials', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_default', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.google_default', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.local_credentials', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential_specifier', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.credential_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1154,
  serialized_end=1433,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS = _descriptor.Descriptor(
  name='ServiceAccountJWTAccessCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_key', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials.json_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_lifetime_seconds', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials.token_lifetime_seconds', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2094,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS = _descriptor.Descriptor(
  name='GoogleIAMCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorization_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials.authorization_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_selector', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials.authority_selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2175,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN = _descriptor.Descriptor(
  name='MetadataCredentialsFromPlugin',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2178,
  serialized_end=2331,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE = _descriptor.Descriptor(
  name='StsService',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_exchange_service_uri', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.token_exchange_service_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audience', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.audience', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.scope', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.requested_token_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_token_path', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.subject_token_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.subject_token_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_token_path', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.actor_token_path', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.actor_token_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2334,
  serialized_end=2589,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS = _descriptor.Descriptor(
  name='CallCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_compute_engine', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_compute_engine', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_refresh_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_refresh_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_jwt_access', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.service_account_jwt_access', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_iam', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_iam', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_plugin', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.from_plugin', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sts_service', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.sts_service', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential_specifier', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.credential_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1436,
  serialized_end=2618,
)

_GRPCSERVICE_GOOGLEGRPC = _descriptor.Descriptor(
  name='GoogleGrpc',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_uri', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.target_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.channel_credentials', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.call_credentials', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.stat_prefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credentials_factory_name', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.credentials_factory_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=2618,
)

_GRPCSERVICE = _descriptor.Descriptor(
  name='GrpcService',
  full_name='envoy.api.v2.core.GrpcService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='envoy_grpc', full_name='envoy.api.v2.core.GrpcService.envoy_grpc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_grpc', full_name='envoy.api.v2.core.GrpcService.google_grpc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.api.v2.core.GrpcService.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_metadata', full_name='envoy.api.v2.core.GrpcService.initial_metadata', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_ENVOYGRPC, _GRPCSERVICE_GOOGLEGRPC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target_specifier', full_name='envoy.api.v2.core.GrpcService.target_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=330,
  serialized_end=2649,
)

_GRPCSERVICE_ENVOYGRPC.containing_type = _GRPCSERVICE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['root_certs'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['cert_chain'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['access_token'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['access_token'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_refresh_token'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_refresh_token'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['channel_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['call_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GRPCSERVICE_GOOGLEGRPC.containing_type = _GRPCSERVICE
_GRPCSERVICE.fields_by_name['envoy_grpc'].message_type = _GRPCSERVICE_ENVOYGRPC
_GRPCSERVICE.fields_by_name['google_grpc'].message_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GRPCSERVICE.fields_by_name['initial_metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_GRPCSERVICE.oneofs_by_name['target_specifier'].fields.append(
  _GRPCSERVICE.fields_by_name['envoy_grpc'])
_GRPCSERVICE.fields_by_name['envoy_grpc'].containing_oneof = _GRPCSERVICE.oneofs_by_name['target_specifier']
_GRPCSERVICE.oneofs_by_name['target_specifier'].fields.append(
  _GRPCSERVICE.fields_by_name['google_grpc'])
_GRPCSERVICE.fields_by_name['google_grpc'].containing_oneof = _GRPCSERVICE.oneofs_by_name['target_specifier']
DESCRIPTOR.message_types_by_name['GrpcService'] = _GRPCSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GrpcService = _reflection.GeneratedProtocolMessageType('GrpcService', (_message.Message,), {

  'EnvoyGrpc' : _reflection.GeneratedProtocolMessageType('EnvoyGrpc', (_message.Message,), {
    'DESCRIPTOR' : _GRPCSERVICE_ENVOYGRPC,
    '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.EnvoyGrpc)
    })
  ,

  'GoogleGrpc' : _reflection.GeneratedProtocolMessageType('GoogleGrpc', (_message.Message,), {

    'SslCredentials' : _reflection.GeneratedProtocolMessageType('SslCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials)
      })
    ,

    'GoogleLocalCredentials' : _reflection.GeneratedProtocolMessageType('GoogleLocalCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials)
      })
    ,

    'ChannelCredentials' : _reflection.GeneratedProtocolMessageType('ChannelCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials)
      })
    ,

    'CallCredentials' : _reflection.GeneratedProtocolMessageType('CallCredentials', (_message.Message,), {

      'ServiceAccountJWTAccessCredentials' : _reflection.GeneratedProtocolMessageType('ServiceAccountJWTAccessCredentials', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials)
        })
      ,

      'GoogleIAMCredentials' : _reflection.GeneratedProtocolMessageType('GoogleIAMCredentials', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials)
        })
      ,

      'MetadataCredentialsFromPlugin' : _reflection.GeneratedProtocolMessageType('MetadataCredentialsFromPlugin', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin)
        })
      ,

      'StsService' : _reflection.GeneratedProtocolMessageType('StsService', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService)
        })
      ,
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials)
      })
    ,
    'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC,
    '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc)
    })
  ,
  'DESCRIPTOR' : _GRPCSERVICE,
  '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService)
  })
_sym_db.RegisterMessage(GrpcService)
_sym_db.RegisterMessage(GrpcService.EnvoyGrpc)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.SslCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.GoogleLocalCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.ChannelCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.StsService)


DESCRIPTOR._options = None
_GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._options = None
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._options = None
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._options = None
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._options = None
_GRPCSERVICE.oneofs_by_name['target_specifier']._options = None
# @@protoc_insertion_point(module_scope)
